/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 03580
 |             NATIONAL HOUSEHOLD SURVEY ON DRUG ABUSE, 2001
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 03580-0001-statasetup.do)
 |
 **************************************************************************/

set mem 300m  /* Allocating 300 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "National Household Survey on Drug Abuse, 2001, Dataset 0001"

#delimit ;
label define CIGEVER   1 "Yes" 2 "No" ;
label define CIGOFRSM  1 "Definitely Yes" 2 "Probably Yes" 3 "Probably Not"
                       4 "Definitely Not" 94 "DON'T KNOW" 97 "REFUSED"
                       99 "LEGITIMATE SKIP" ;
label define CIGWILYR  1 "Definitely Yes" 2 "Probably Yes" 3 "Probably Not"
                       4 "Definitely Not" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 99 "LEGITIMATE SKIP" ;
label define CIGTRY    985 "BAD DATA Logically assigned"
                       991 "NEVER USED CIGARETTES" 994 "DON'T KNOW"
                       997 "REFUSED" ;
label define CIGYFU    9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assn"
                       9991 "NEVER USED CIGARETTES" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define CIGMFU    1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assn"
                       91 "NEVER USED CIGARETTES" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CIGREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in the lifetime LOG ASSN"
                       14 "Used more than 12 months ago LOG ASSN"
                       19 "Used more than 30 days ago LOG ASSN"
                       91 "NEVER USED CIGARETTES" ;
label define CIG30USE  85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CG30EST   1 "1 or 2 days" 2 "3 to 5 days" 3 "6 to 9 days"
                       4 "10 to 19 days" 5 "20 to 29 days" 6 "All 30 days"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CIG30AV   1 "Less than one cigarette per day"
                       2 "1 cigarette per day" 3 "2 to 5 cigarettes per day"
                       4 "6 to 15 cigarettes per day (about 1/2 pack)"
                       5 "16 to 25 cigarettes per day (about 1 pack)"
                       6 "26 to 35 cigarettes per day (about 1 1/2 packs)"
                       7 "More than 35 cigs per day (abt 2 packs or more)"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIG30BR2  101 "Basic" 102 "Benson & Hedges" 103 "Cambridge"
                       104 "Camel" 105 "Capri" 106 "Carlton" 107 "Doral"
                       109 "GPC" 110 "Kent" 111 "Kool" 112 "Marlboro"
                       113 "Merit" 114 "Misty" 115 "Monarch" 116 "Montclair"
                       117 "More" 118 "Newport" 119 "Pall Mall"
                       120 "Parliament" 121 "Private Label" 122 "Salem"
                       123 "Vantage" 124 "Viceroy" 125 "Virginia Slims"
                       126 "Winston" 127 "Alpine" 130 "Best Value"
                       132 "Bugler (roll-your-own)" 137 "Eve" 140 "Lark"
                       142 "Lucky Strike" 144 "Maverick" 145 "Max" 146 "Now"
                       147 "Old Gold" 148 "Players" 149 "Pyramid"
                       152 "Saratoga" 157 "Tareyton"
                       158 "Top (roll-your-own)" 160 "True"
                       161 "American Spirit" 162 "Austin" 163 "Bali Hai"
                       166 "Bidis; brand unspecified" 171 "Checkers"
                       172 "Cimmarron" 173 "Clove; brand unspecified"
                       174 "Daves" 175 "Djarum cigarettes"
                       176 "Drum rolling tobacco" 178 "Dunhill cigarettes"
                       179 "Eagle" 183 "First Class"
                       185 "Generic cigarettes; brand unspecified"
                       188 "Gunsmoke" 189 "Hi-Value" 190 "Jacks"
                       193 "Kamel Red" 196 "Mainstreet" 404 "Black & Mild"
                       423 "Swisher Sweets" 445 "Corona; brand unspecified"
                       1001 "Nat Sherman cigarettes" 1011 "Sampoerna"
                       1018 "USA Gold" 1020 "Waves" 1022 "Bailey"
                       1025 "Ultra Buy" 1027 "Mustang" 1029 "Tourney"
                       1037 "DTC" 1044 "Worth" 1048 "Carnival" 1050 "USA"
                       1064 "Seneca; company unspecified"
                       1069 "Zig-Zag (roll-your-own)" 1082 "Tahoe"
                       1083 "Liggett Select" 1093 "Roger" 1094 "Shield"
                       1105 "Sixty-1" 1113 "Sweet Dreams" 1115 "Montana"
                       1117 "American" 1118 "Kingsport" 1120 "Durant"
                       1123 "CT" 1999 "Other cigarette brand or unspecified"
                       3999 "Other snuff brand or unspecified"
                       4999 "Other cigar/cigarillo brand or unspecified"
                       5999 "Other pipe tobacco brand or unspecified"
                       7999 "Not a tobacco product"
                       8999 "Tobacco replacement or tobacco-like product"
                       9000 "Did not confirm after 3 passes thru brand Qs"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED CIGARETTES"
                       9993 "DID NOT USE CIGARETTES IN THE PAST 30 DAYS"
                       9994 "DON'T KNOW" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define CIG30TYP  1 "Lights" 2 "Ultra Lights" 3 "Full Flavor"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIG30MEN  1 "Menthol" 2 "Regular"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIG30RO2  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIGDLYMO  1 "Yes" 2 "No"
                       5 "Yes LOGICALLY ASSIGNED (from skip pattern)"
                       91 "NEVER USED CIGARETTES" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIGAGE    985 "BAD DATA Logically assigned"
                       991 "NEVER USED CIGARETTES" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (NEVER USED CIGS EVERYDAY)" ;
label define CIG100LF  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       5 "Yes LOGICALLY ASSIGNED (from skip pattern)"
                       91 "NEVER USED CIGARETTES" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SNFEVER   1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED" ;
label define SNUFTRY   985 "BAD DATA Logically assigned"
                       991 "NEVER USED SNUFF" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define SNUFYFU   9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED SNUFF" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define SNUFMFU   1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED SNUFF"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNFREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in the lifetime LOG ASSN"
                       14 "Used more than 12 months ago LOG ASSN"
                       19 "Used more than 30 days ago LOG ASSN"
                       91 "NEVER USED SNUFF" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SNF30USE  85 "BAD DATA Logically assigned" 91 "NEVER USED SNUFF"
                       93 "DID NOT USE SNUFF IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SN30EST   1 "1 or 2 days" 2 "3 to 5 days" 3 "6 to 9 days"
                       4 "10 to 19 days" 5 "20 to 29 days" 6 "All 30 days"
                       91 "NEVER USED SNUFF"
                       93 "DID NOT USE SNUFF IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNF30BR2  208 "Red Man" 301 "Copenhagen" 302 "Gold River"
                       303 "Happy Days" 304 "Hawken" 305 "Kodiak"
                       306 "Redwood" 307 "Silver Creek" 308 "Skoal"
                       309 "Timber Wolf" 312 "Cougar" 316 "Red Seal"
                       317 "Rooster" 321 "W. Garrett snuff"
                       1999 "Other cigarette brand or unspecified"
                       2999 "Other chewing tobacco brand or unspecified"
                       3999 "Other snuff brand or unspecified"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED SNUFF"
                       9993 "DID NOT USE SNUFF IN THE PAST 30 DAYS"
                       9994 "DON'T KNOW" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define CHEWEVER  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED" ;
label define CHEWTRY   985 "BAD DATA Logically assigned"
                       991 "NEVER USED CHEWING TOBACCO" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define CHEWYFU   9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED CHEWING TOBACCO" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define CHEWMFU   1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CHEWING TOBACCO" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CHEWREC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in the lifetime LOG ASSN"
                       14 "Used more than 12 months ago LOG ASSN"
                       19 "Used more than 30 days ago LOG ASSN"
                       91 "NEVER USED CHEWING TOBACCO" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CHW30USE  91 "NEVER USED CHEWING TOBACCO"
                       93 "DID NOT USE CHEWING TOBACCO PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CH30EST   1 "1 or 2 days" 2 "3 to 5 days" 4 "10 to 19 days"
                       91 "NEVER USED CHEWING TOBACCO"
                       93 "DID NOT USE CHEWING TOBACCO IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CHW30BR2  201 "Beech-Nut" 202 "Chattanooga Chew"
                       203 "Day's Work" 204 "Granger" 205 "H.B. Scott"
                       206 "Levi Garrett" 207 "Red Fox" 208 "Red Man"
                       209 "Taylors Pride" 211 "Work Horse" 220 "Lancaster"
                       301 "Copenhagen" 305 "Kodiak" 308 "Skoal"
                       309 "Timber Wolf" 317 "Rooster"
                       2999 "Other chewing tobacco brand or unspecified"
                       3999 "Other snuff brand or unspecified"
                       7999 "Not a tobacco product"
                       9000 "Did not confirm after 3 passes thru brand Qs"
                       9991 "NEVER USED CHEWING TOBACCO"
                       9993 "DID NOT USE CHEWING TOBACCO IN THE PAST 30 DAYS"
                       9994 "DON'T KNOW" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define SLTTRY    985 "BAD DATA Logically assigned"
                       991 "NEVER USED SMOKELESS TOBACCO" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define SLTYFU    9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED SMOKELESS TOBACCO" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define SLTMFU    1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SMOKELESS TOBACCO" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SLTREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in the lifetime LOG ASSN"
                       14 "Used more than 12 months ago LOG ASSN"
                       19 "Used more than 30 days ago LOG ASSN"
                       91 "NEVER USED SMOKELESS TOBACCO" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SLT30BR2  201 "Beech-Nut" 202 "Chattanooga Chew"
                       203 "Day's Work" 204 "Granger" 205 "H.B. Scott"
                       206 "Levi Garrett" 208 "Red Man" 209 "Taylors Pride"
                       220 "Lancaster" 301 "Copenhagen" 302 "Gold River"
                       303 "Happy Days" 304 "Hawken" 305 "Kodiak"
                       306 "Redwood" 307 "Silver Creek" 308 "Skoal"
                       309 "Timber Wolf" 312 "Cougar" 316 "Red Seal"
                       317 "Rooster" 321 "W. Garrett snuff"
                       1999 "Other cigarette brand or unspecified"
                       2999 "Other chewing tobacco brand or unspecified"
                       3999 "Other snuff brand or unspecified"
                       7999 "Not a tobacco product"
                       9000 "Did not confirm after 3 passes thru brand Qs"
                       9991 "NEVER USED SMOKELESS TOBACCO"
                       9993 "DID NOT USE SMOKELESS TOBACCO IN THE PAST 30 DAYS"
                       9994 "DON'T KNOW" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define SLT30FAV  1 "Brand reported from CHW30BR2"
                       2 "Brand reported from SNF30BR2"
                       91 "NEVER USED SMOKELESS TOBACCO"
                       93 "DID NOT USE SMOKELESS TOBACCO IN THE PAST 30 DAYS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIGAREVR  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED" ;
label define CIGARTRY  985 "BAD DATA Logically assigned"
                       991 "NEVER USED CIGARS" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define CIGARYFU  9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assn"
                       9991 "NEVER USED CIGARS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define CIGARMFU  1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assn"
                       91 "NEVER USED CIGARS" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CIGARREC  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in the lifetime LOG ASSN"
                       14 "Used more than 12 months ago LOG ASSN"
                       19 "Used more than 30 days ago LOG ASSN"
                       91 "NEVER USED CIGARS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CGR30USE  91 "NEVER USED CIGARS"
                       93 "DID NOT USE CIGARS IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CI30EST   1 "1 or 2 days" 2 "3 to 5 days" 3 "6 to 9 days"
                       4 "10 to 19 days" 5 "20 to 29 days" 6 "All 30 days"
                       91 "NEVER USED CIGARS"
                       93 "DID NOT USE CIGARS PAST 30 DAYS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CGR30BR2  112 "Marlboro" 118 "Newport" 401 "Antonio y Cleopatra"
                       402 "Backwoods" 403 "Bering" 404 "Black & Mild"
                       405 "Captain Black" 406 "Casa Silva" 407 "Cuesta-Rey"
                       408 "Dutch Masters" 409 "El Producto"
                       410 "Erik Filter" 411 "Garcia y Vega" 412 "Havatampa"
                       413 "King Edward" 414 "La Corona" 415 "Little Nippers"
                       416 "Macanudos" 417 "Muriel" 418 "Partagas"
                       419 "Phillies" 420 "Rigoletto" 421 "Robert Burns"
                       422 "Roi-Tan" 423 "Swisher Sweets"
                       424 "Tijuana Smalls" 426 "White Owl"
                       427 "William Penn" 428 "Winchester" 429 "Al Capone"
                       431 "Arturo Fuente" 432 "Ashton" 441 "Cherry Blend"
                       442 "Churchill; brand unspecified" 443 "Cohiba"
                       444 "Cojimar" 448 "Cuban; brand unspecified"
                       451 "Davidoff" 452 "Don Diego" 457 "Don Thomas"
                       458 "Dunhill cigars" 461 "Fonseca" 464 "H. Upmann"
                       465 "Habana/Havana; brand unspecified"
                       469 "Hoya De Monterrey" 476 "La Gloria Cubana"
                       484 "Middleton Cherry Blend" 486 "Montecristo"
                       488 "Optimo" 490 "Padron" 491 "Parodi Cella"
                       492 "Primetime" 494 "Punch" 496 "Romeo y Julieta"
                       501 "Prince Albert tobacco"
                       1999 "Other cigarette brand or unspecified"
                       4005 "Thompson" 4016 "Dominican; brand unspecified"
                       4041 "Miami Suites" 4050 "Fuente" 4083 "C.A.O"
                       4999 "Other cigar/cigarillo brand or unspecified"
                       5999 "Other pipe tobacco brand or unspecified"
                       7999 "Not a tobacco product" 9991 "NEVER USED CIGARS"
                       9993 "DID NOT USE CIGARS IN THE PAST 30 DAYS"
                       9994 "DON'T KNOW" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define PIPEVER   1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED" ;
label define PIPE30DY  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED PIPE TOBACCO" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ALCEVER   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" ;
label define ALCTRY    985 "BAD DATA Logically assigned"
                       991 "NEVER USED ALCOHOL" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define ALCYFU    9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assn"
                       9991 "NEVER USED ALCOHOL" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define ALCMFU    1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assn"
                       91 "NEVER USED ALCOHOL" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ALCREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in the lifetime LOG ASSN"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ALCYRTOT  985 "BAD DATA Logically assigned"
                       991 "NEVER USED ALCOHOL"
                       993 "DID NOT USE ALCOHOL IN THE PAST 12 MONTHS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define ALTOTFG   1 "Trimmed to 365 days (no further editing)"
                       2 "Trimmed relative to the 30-day freq"
                       3 "Trimmed relative to estimated 30-day freq"
                       98 "BLANK (NO ANSWER)" ;
label define ALFQFLG   1 "Trimmed to be consistent with mo/yr of 1st use"
                       98 "BLANK (NO ANSWER)" ;
label define ALBSTWAY  1 "Prefer to answer in days per week"
                       2 "Prefer to answer in days per month"
                       3 "Prefer to answer in days per year"
                       11 "Prefer to ans in days per wk LOG ASSN"
                       12 "Prefer to ans in days per mo LOG ASSN"
                       13 "Prefer to ans in days per yr LOG ASSN"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ALDAYPYR  985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       991 "NEVER USED ALCOHOL"
                       993 "DID NOT USE ALCOHOL IN THE PAST 12 MONTHS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ALDAYPMO  85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALDAYPWK  85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCDAYS   85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define AL30EST   1 "1 or 2 days" 2 "3 to 5 days" 3 "6 to 9 days"
                       4 "10 to 19 days" 5 "20 to 29 days" 6 "All 30 days"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALDYSFG   1 "Edited for consistency with ALCYRTOT or DR5DAY"
                       98 "BLANK (NO ANSWER)" ;
label define NODR30A   975 "AT LEAST 5 Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED ALCOHOL"
                       993 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define DR5DAY    80 "NO OCCAS OF 5+ DRINKS PST 30 DAYS Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MJEVER    1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED" ;
label define MJAGE     985 "BAD DATA Logically assigned"
                       991 "NEVER USED MARIJUANA" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define MJYFU     9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED MARIJUANA" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define MJMFU     1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define MJREC     1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in the lifetime LOG ASSN"
                       91 "NEVER USED MARIJUANA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define MJYRTOT   985 "BAD DATA Logically assigned"
                       991 "NEVER USED MARIJUANA"
                       993 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define MRTOTFG   1 "Trimmed to 365 days (no further editing)"
                       2 "Trimmed relative to the 30-day freq"
                       98 "BLANK (NO ANSWER)" ;
label define MJFQFLG   1 "Trimmed to be consistent with mo/yr of 1st use"
                       98 "BLANK (NO ANSWER)" ;
label define MRBSTWAY  1 "Prefer to answer in days per week"
                       2 "Prefer to answer in days per month"
                       3 "Prefer to answer in days per year"
                       11 "Prefer to ans in days per wk LOG ASSN"
                       12 "Prefer to ans in days per mo LOG ASSN"
                       13 "Prefer to ans in days per yr LOG ASSN"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MRDAYPYR  985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       991 "NEVER USED MARIJUANA"
                       993 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define MRDAYPMO  85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MRDAYPWK  85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MJDAY30A  85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MR30EST   1 "1 or 2 days" 2 "3 to 5 days" 3 "6 to 9 days"
                       4 "10 to 19 days" 5 "20 to 29 days" 6 "All 30 days"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define COCEVER   1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED" ;
label define COCAGE    985 "BAD DATA Logically assigned"
                       991 "NEVER USED COCAINE" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define COCYFU    9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assn"
                       9991 "NEVER USED COCAINE" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define COCMFU    1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assn"
                       91 "NEVER USED COCAINE" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define COCREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in the lifetime LOG ASSN"
                       11 "Used in the past 30 days LOGICALLY ASSIGNED"
                       12 "Used >30 days ago but within pst 12 mos LOG ASSN"
                       91 "NEVER USED COCAINE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define COCYRTOT  985 "BAD DATA Logically assigned"
                       991 "NEVER USED COCAINE"
                       993 "DID NOT USE COCAINE IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define CCTOTFG   2 "Trimmed relative to the 30-day freq"
                       98 "BLANK (NO ANSWER)" ;
label define CCFQFLG   1 "Trimmed to be consistent with mo/yr of 1st use"
                       98 "BLANK (NO ANSWER)" ;
label define CCBSTWAY  1 "Prefer to answer in days per week"
                       2 "Prefer to answer in days per month"
                       3 "Prefer to answer in days per year"
                       11 "Prefer to ans in days per wk LOG ASSN"
                       12 "Prefer to ans in days per mo LOG ASSN"
                       13 "Prefer to ans in days per yr LOG ASSN"
                       21 "Prefer to ans in days per wk (CRBSTWAY=1,11)"
                       22 "Prefer to ans in days per mo (CRBSTWAY=2,12)"
                       23 "Prefer to ans in days per yr (CRBSTWAY=3,13)"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CCDAYPYR  989 "LEGITIMATE SKIP Logically assigned"
                       991 "NEVER USED COCAINE"
                       993 "DID NOT USE COCAINE IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define CCDAYPMO  89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CCDAYPWK  85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define COCUS30A  85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CC30EST   91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CRKEVER   1 "Yes" 2 "No" 91 "NEVER USED COCAINE (COCEVER=2)"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CRKAGE    985 "BAD DATA Logically assigned"
                       991 "NEVER USED CRACK" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define CRKYFU    9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED CRACK" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define CRKMFU    1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CRAKREC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in the lifetime LOG ASSN"
                       91 "NEVER USED CRACK" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CRKYRTOT  985 "BAD DATA Logically assigned"
                       991 "NEVER USED CRACK"
                       993 "DID NOT USE CRACK IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define CRTOTFG   2 "Trimmed relative to the 30-day freq"
                       98 "BLANK (NO ANSWER)" ;
label define CRFQFLG   1 "Trimmed to be consistent with mo/yr of 1st use"
                       98 "BLANK (NO ANSWER)" ;
label define CRBSTWAY  1 "Prefer to answer in days per week"
                       2 "Prefer to answer in days per month"
                       3 "Prefer to answer in days per year"
                       13 "Prefer to ans in days per yr LOG ASSN"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CRDAYPYR  991 "NEVER USED CRACK"
                       993 "DID NOT USE CRACK IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define CRDAYPMO  85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CRDAYPWK  85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CRKUS30A  85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CR30EST   91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HEREVER   1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED" ;
label define HERAGE    985 "BAD DATA Logically assigned"
                       991 "NEVER USED HEROIN" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define HERYFU    9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED HEROIN" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define HERMFU    1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HERREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in the lifetime LOG ASSN"
                       91 "NEVER USED HEROIN" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HERYRTOT  985 "BAD DATA Logically assigned"
                       991 "NEVER USED HEROIN"
                       993 "DID NOT USE HEROIN IN THE PAST 12 MOS"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define HRTOTFG   2 "Trimmed relative to the 30-day freq"
                       98 "BLANK (NO ANSWER)" ;
label define HRFQFLG   1 "Trimmed to be consistent with mo/yr of 1st use"
                       98 "BLANK (NO ANSWER)" ;
label define HRBSTWAY  1 "Prefer to answer in days per week"
                       2 "Prefer to answer in days per month"
                       3 "Prefer to answer in days per year"
                       13 "Prefer to ans in days per yr LOG ASSN"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PAST 12 MONTHS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HRDAYPYR  991 "NEVER USED HEROIN"
                       993 "DID NOT USE HEROIN PAST 12 MOS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define HRDAYPMO  85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PAST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HRDAYPWK  85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PAST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HER30USE  85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HR30EST   2 "3 to 5 days" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PAST 30 DAYS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define LSD       1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       91 "NEVER USED HALLUCINOGENS" 94 "DON'T KNOW"
                       97 "REFUSED" ;
label define PCP       1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       91 "NEVER USED HALLUCINOGENS" 94 "DON'T KNOW"
                       97 "REFUSED" ;
label define PEYOTE    1 "Yes" 2 "No" 91 "NEVER USED HALLUCINOGENS"
                       94 "DON'T KNOW" 97 "REFUSED" ;
label define MESC      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       91 "NEVER USED HALLUCINOGENS" 94 "DON'T KNOW"
                       97 "REFUSED" ;
label define PSILCY    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       91 "NEVER USED HALLUCINOGENS" 94 "DON'T KNOW"
                       97 "REFUSED" ;
label define ECSTASY   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       91 "NEVER USED HALLUCINOGENS" 94 "DON'T KNOW"
                       97 "REFUSED" ;
label define HALNOLST  1 "Yes" 2 "No" 91 "NEVER USED HALLUCINOGENS"
                       94 "DON'T KNOW" 97 "REFUSED" ;
label define HALNEWA   116 "Methaqualone, Quaalude, Sopor" 123 "Unisom <OTC>"
                       124 "Yellow jackets" 138 "Mandrakes" 142 "Belladona"
                       174 "Ambien, Zolpidem" 180 "Tylenol P.M. <OTC>"
                       187 "Belladona plant/flower/root, Deadly nightshade"
                       201 "Valium, Diazepam" 209 "Xanax, Alprazolam"
                       240 "Lithium carbonate, Lithonate"
                       246 "Clonazepam, Klonopin, Rivotril" 267 "Marezine"
                       280 "Ketaset" 301 "Dexedrine"
                       322 "Methamphetamine ('ice' or 'crank'), Meth"
                       326 "White cross" 327 "Black beauties, Black beauty"
                       329 "Bird's eggs, Robin's eggs, speckled eggs"
                       348 "Crystal" 355 "Crystal meth" 369 "Artane"
                       394 "Debs" 408 "Dilaudid" 415 "Codeine"
                       417 "Morphine, Roxanol" 418 "Dolophine, Methadone"
                       420 "OTHER Analgesic, NOT OTHERWISE SPECIFIED"
                       423 "Percocet"
                       434 "Anexsia, Co-Gesic, Lorcet, Lortab, Vicodin, Zydo"
                       501 "Gasoline or lighter fluids" 502 "Spray paints"
                       503 "Other aerosol sprays"
                       504 "Shoeshine liquid, glue, or toluene"
                       505 "Lacquer thinner or other paint solvents"
                       506 "Amyl nitrite,'poppers,'locker room odorizer,'rush'"
                       507 "Halothane, ether, or other anesthetics; chlorofo"
                       508 "Nitrous oxide, 'whippets,' dentist gas"
                       510 "OTHER Inhalant, NOT OTHERWISE SPECIFIED"
                       516 "Freon, refrigerant" 520 "Old paint, paint"
                       524 "White-Out" 525 "Butane" 526 "Nail polish"
                       560 "Laundry detergent, soap"
                       566 "Smoked tea from Lipton tea bag"
                       592 "Computer air duster, computer cleaner, dust-off"
                       601 "LSD ('acid')" 602 "Peyote" 603 "Mescaline"
                       604 "Psilocybin (mushrooms), shrooms"
                       605 "PCP ('angel dust,' phencyclidine)"
                       606 "'Ecstasy' (MDMA), X-TC, 'X'"
                       607 "OTHER Hallucinogen, NOT OTHERWISE SPECIFIED"
                       609 "Jimson weed" 610 "Crystal T"
                       612 "Happy stick, sherm, sherman, shermstick"
                       614 "MDA, Methylenedioxy amphetamine"
                       616 "DET, Dimethyltryptamine, DMT"
                       617 "Morning glory seeds, morning glory tendrils"
                       618 "Acid paper, blotter (acid)"
                       622 "Microdot(s), green microdot, purple microdot"
                       625 "Window, window pane, 4-way pane"
                       627 "Hawaiian Woodrose, Hawaiian Woodrose seeds"
                       635 "Ginseng seeds, ginseng weed" 636 "DOM, STP"
                       637 "Purple haze" 639 "Nutmeg, Mace"
                       648 "Designer drugs"
                       650 "Datura stramonium, daytura, thorn apple"
                       658 "Special K, Ketamine" 659 "Boat"
                       660 "Toad, Toad licking" 682 "Kif" 683 "Yage"
                       687 "Spray" 691 "Maximum impact" 695 "Angel's trumpet"
                       698 "Nexus, 2C-B" 703 "Opium"
                       802 "THC, cannabinol, marinol"
                       803 "Marijuana, MarrJane, Mary Jane, MJ, pot, weed,he"
                       805 "Cocaine, coca, coca8na, coke"
                       813 "Cigarettes, smoking (substance not specified)"
                       829 "Robitussin DM <OTC>" 847 "GHB, NSC"
                       852 "Formaldehyde, wak, whack (embalming fluid)"
                       883 "Dextromethorphan Hydrobromide <OTC>"
                       900 "Not a drug"
                       1002 "Dramamine, seasick/motion sickness pill <OTC>"
                       2002 "Muscle Relaxers" 3046 "Adrenalin, Epinephrine"
                       3052 "Speed; otherwise unspecified" 4067 "Oxycontin"
                       5009 "Robo" 5032 "Nitrogen"
                       5042 "Fuels other than gasoline" 5055 "PVC"
                       6012 "Cloud 9, Cloud 13" 6029 "DXM" 6037 "Fry"
                       6043 "Salviadivinorum" 6044 "Gel caps, gel tabs"
                       6047 "Water" 6049 "Locoseeds, Locoweed seeds"
                       6064 "Marigold buttons" 6074 "LSA" 6077 "San Pedro"
                       6083 "CCC, Triple 'C', C3" 6091 "Ergot, rye mold"
                       6100 "2C-T-7, T7" 6101 "Alice in Wonderland"
                       6102 "Absinthe" 6103 "Ayahuasca"
                       6105 "Alpha-methyltryptamine, AMT, IT-290, 3-IT"
                       6106 "Paramethoxyamphetamine, PMA" 6107 "Ambrosia"
                       6109 "2, 5-Dimethoxyamphetamine, DMA" 6110 "Mad dog"
                       6114 "Molly; not otherwise specified" 8002 "Zantac"
                       8009 "Allergy pills/antihistamine; type unspecified"
                       8011 "Herb, flower, plant; type unspecified"
                       8012 "Coriciden <OTC>"
                       8058 "Cough medicine/syrup; type unspecified"
                       8100 "Kava Kava <OTC>"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED HALLUCINOGENS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define HALNEWB   105 "Placidyl" 123 "Unisom <OTC>" 142 "Belladona"
                       189 "Sonata" 201 "Valium, Diazepam"
                       209 "Xanax, Alprazolam" 280 "Ketaset"
                       322 "Methamphetamine ('ice' or 'crank'), Meth"
                       327 "Black beauties, Black beauty"
                       329 "Bird's eggs, Robin's eggs, speckled eggs"
                       332 "Ephedrine" 336 "Diet pills" 348 "Crystal"
                       420 "OTHER Analgesic, NOT OTHERWISE SPECIFIED"
                       434 "Anexsia, Co-Gesic, Lorcet, Lortab, Vicodin, Zydo"
                       501 "Gasoline or lighter fluids"
                       504 "Shoeshine liquid, glue, or toluene"
                       508 "Nitrous oxide, 'whippets,' dentist gas"
                       516 "Freon, refrigerant" 520 "Old paint, paint"
                       524 "White-Out" 566 "Smoked tea from Lipton tea bag"
                       601 "LSD ('acid')"
                       604 "Psilocybin (mushrooms), shrooms"
                       606 "'Ecstasy' (MDMA), X-TC, 'X'"
                       607 "OTHER Hallucinogen, NOT OTHERWISE SPECIFIED"
                       609 "Jimson weed"
                       614 "MDA, Methylenedioxy amphetamine"
                       615 "Homemade drugs"
                       616 "DET, Dimethyltryptamine, DMT"
                       622 "Microdot(s), green microdot, purple microdot"
                       627 "Hawaiian Woodrose, Hawaiian Woodrose seeds"
                       637 "Purple haze" 639 "Nutmeg, Mace"
                       658 "Special K, Ketamine" 673 "Orange"
                       678 "Banana peels" 698 "Nexus, 2C-B" 703 "Opium"
                       709 "Poppy"
                       803 "Marijuana, MarrJane, Mary Jane, MJ, pot, weed,he"
                       829 "Robitussin DM <OTC>" 847 "GHB, NSC"
                       852 "Formaldehyde, wak, whack (embalming fluid)"
                       876 "Glass" 883 "Dextromethorphan Hydrobromide <OTC>"
                       1001 "Benadryl <OTC>"
                       1002 "Dramamine, seasick/motion sickness pill <OTC>"
                       3052 "Speed; otherwise unspecified" 5009 "Robo"
                       6029 "DXM" 6044 "Gel caps, gel tabs" 6073 "Rolls"
                       6083 "CCC, Triple 'C', C3" 6111 "Syrian rue"
                       8058 "Cough medicine/syrup; type unspecified"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED HALLUCINOGENS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define HALNEWC   124 "Yellow jackets" 176 "Melatonin <OTC>"
                       207 "Ativan, Lorazapam" 241 "Prozac"
                       327 "Black beauties, Black beauty" 348 "Crystal"
                       501 "Gasoline or lighter fluids"
                       520 "Old paint, paint" 601 "LSD ('acid')"
                       607 "OTHER Hallucinogen, NOT OTHERWISE SPECIFIED"
                       615 "Homemade drugs"
                       622 "Microdot(s), green microdot, purple microdot"
                       648 "Designer drugs"
                       801 "OTHER Drugs, NOT OTHERWISE SPECIFIED"
                       829 "Robitussin DM <OTC>" 847 "GHB, NSC"
                       1002 "Dramamine, seasick/motion sickness pill <OTC>"
                       2002 "Muscle Relaxers" 6029 "DXM"
                       6044 "Gel caps, gel tabs" 6083 "CCC, Triple 'C', C3"
                       6100 "2C-T-7, T7"
                       8058 "Cough medicine/syrup; type unspecified"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED HALLUCINOGENS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define HALNEWD   174 "Ambien, Zolpidem"
                       607 "OTHER Hallucinogen, NOT OTHERWISE SPECIFIED"
                       616 "DET, Dimethyltryptamine, DMT"
                       625 "Window, window pane, 4-way pane"
                       658 "Special K, Ketamine" 900 "Not a drug"
                       6098 "Dust; not otherwise specified"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED HALLUCINOGENS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define HALNEWE   607 "OTHER Hallucinogen, NOT OTHERWISE SPECIFIED"
                       6043 "Salviadivinorum"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED HALLUCINOGENS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define HALLAGE   985 "BAD DATA Logically assigned"
                       991 "NEVER USED HALLUCINOGENS" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define HALYFU    9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assn"
                       9991 "NEVER USED HALLUCINOGENS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define HALMFU    1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assn"
                       91 "NEVER USED HALLUCINOGENS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HALLREC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in lifetime LOG ASSN"
                       11 "Used in the past 30 days LOGICALLY ASSIGNED"
                       12 "Used >30 days ago but within pst 12 mos LOG ASSN"
                       91 "NEVER USED HALLUCINOGENS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HALYRTOT  985 "BAD DATA Logically assigned"
                       991 "NEVER USED HALLUCINOGENS"
                       993 "DID NOT USE HALLUCINOGENS IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define HLTOTFG   2 "Trimmed relative to the 30-day freq"
                       98 "BLANK (NO ANSWER)" ;
label define HLFQFLG   1 "Trimmed to be consistent with mo/yr of 1st use"
                       98 "BLANK (NO ANSWER)" ;
label define HLBSTWAY  1 "Prefer to answer in days per week"
                       2 "Prefer to answer in days per month"
                       3 "Prefer to answer in days per year"
                       11 "Prefer to ans in days per wk LOG ASSN"
                       12 "Prefer to ans in days per mo LOG ASSN"
                       13 "Prefer to ans in days per yr LOG ASSN"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HLDAYPYR  989 "LEGITIMATE SKIP Logically assigned"
                       991 "NEVER USED HALLUCINOGENS"
                       993 "DID NOT USE HALLUCINOGENS IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define HLDAYPMO  85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLDAYPWK  85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HAL30USE  85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HL30EST   4 "10 to 19 days" 5 "20 to 29 days"
                       91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define LSDAGE    985 "BAD DATA Logically assigned" 991 "NEVER USED LSD"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define LSDYFU    9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED LSD" 9994 "DON'T KNOW" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define LSDMFU    1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED LSD"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define LSDREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in the lifetime LOG ASSN"
                       91 "NEVER USED LSD" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PCPAGE    985 "BAD DATA Logically assigned" 991 "NEVER USED PCP"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define PCPYFU    9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED PCP" 9994 "DON'T KNOW" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define PCPMFU    1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED PCP"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PCPREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in the lifetime LOG ASSN"
                       91 "NEVER USED PCP" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ECSAGE    985 "BAD DATA Logically assigned"
                       991 "NEVER USED ECSTACY" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define ECSYFU    9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED ECSTACY" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define ECSMFU    1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ECSTACY" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ECSREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in the lifetime LOG ASSN"
                       91 "NEVER USED ECSTACY" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define AMYLNIT   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 94 "DON'T KNOW" 97 "REFUSED" ;
label define CLEFLU    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 94 "DON'T KNOW" 97 "REFUSED" ;
label define GAS       1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 94 "DON'T KNOW" 97 "REFUSED" ;
label define GLUE      1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 94 "DON'T KNOW" 97 "REFUSED" ;
label define ETHER     1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 94 "DON'T KNOW" 97 "REFUSED" ;
label define SOLVENT   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 94 "DON'T KNOW" 97 "REFUSED" ;
label define LGAS      1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 94 "DON'T KNOW" 97 "REFUSED" ;
label define NITOXID   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SPPAINT   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define AEROS     1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define INHNOLST  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define INHNEWA   377 "Albuterol, Proventil, Ventolin"
                       501 "Gasoline or lighter fluids"
                       503 "Other aerosol sprays"
                       504 "Shoeshine liquid, glue, or toluene"
                       505 "Lacquer thinner or other paint solvents"
                       506 "Amyl nitrite,'poppers,'locker room odorizer,'rush'"
                       507 "Halothane, ether, or other anesthetics; chlorofo"
                       508 "Nitrous oxide, 'whippets,' dentist gas"
                       509 "Correction fluids, degreasers, cleaning fluids"
                       510 "OTHER Inhalant, NOT OTHERWISE SPECIFIED"
                       511 "Markers, felt-tip pens, ink pens" 512 "Incense"
                       516 "Freon, refrigerant"
                       518 "Acetone, nail polish remover" 519 "Helium"
                       520 "Old paint, paint" 523 "Matches" 524 "White-Out"
                       526 "Nail polish" 528 "Whipped-cream can"
                       534 "Deodorant" 539 "ScotchGard" 540 "PAM"
                       541 "Binaca" 543 "Liquid oxygen, oxygen"
                       545 "Car tailpipe exhaust fumes, CO"
                       548 "Cologne, isopropanol vapors, rubbing alcohol"
                       558 "Kool Aid" 569 "Peganento" 573 "Furniture polish"
                       582 "WD-40" 586 "Carbon from empty soft drink bottle"
                       590 "Canned air, compressed air"
                       592 "Computer air duster, computer cleaner, dust-off"
                       599 "Potpourri" 601 "LSD ('acid')"
                       691 "Maximum impact"
                       803 "Marijuana, MarrJane, Mary Jane, MJ, pot, weed,he"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       900 "Not a drug" 5001 "Bleach" 5004 "Ink print, paper"
                       5022 "Carbon dioxide, CO2, dry ice hits"
                       5045 "Cleaner; not otherwise specified"
                       5049 "Hand sanitizer; contents unspecified"
                       5052 "Silly String" 5053 "Electronics cleaner"
                       5054 "Gum freezer" 5056 "Eucalyptus oil" 5057 "Argon"
                       5058 "Sealers/sealants; type unspecified"
                       6082 "Ammonia"
                       8011 "Herb, flower, plant; type unspecified"
                       8024 "Asthma inhaler/medication, bronchial dilators"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED INHALANTS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define INHNEWB   503 "Other aerosol sprays"
                       504 "Shoeshine liquid, glue, or toluene"
                       505 "Lacquer thinner or other paint solvents"
                       510 "OTHER Inhalant, NOT OTHERWISE SPECIFIED"
                       511 "Markers, felt-tip pens, ink pens"
                       516 "Freon, refrigerant"
                       518 "Acetone, nail polish remover" 519 "Helium"
                       520 "Old paint, paint" 524 "White-Out"
                       526 "Nail polish" 528 "Whipped-cream can" 540 "PAM"
                       548 "Cologne, isopropanol vapors, rubbing alcohol"
                       553 "Pixie sticks"
                       586 "Carbon from empty soft drink bottle"
                       590 "Canned air, compressed air"
                       592 "Computer air duster, computer cleaner, dust-off"
                       803 "Marijuana, MarrJane, Mary Jane, MJ, pot, weed,he"
                       866 "Boomers" 5001 "Bleach"
                       5017 "Oil, lubricant; otherwise unspecified"
                       5045 "Cleaner; not otherwise specified"
                       5053 "Electronics cleaner" 5059 "Transmission fluid"
                       8024 "Asthma inhaler/medication, bronchial dilators"
                       8056 "Vicks VapoRub <OTC>"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED INHALANTS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define INHNEWC   518 "Acetone, nail polish remover" 519 "Helium"
                       526 "Nail polish" 5050 "Burned rubber"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED INHALANTS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define INHNEWD   5017 "Oil, lubricant; otherwise unspecified"
                       8024 "Asthma inhaler/medication, bronchial dilators"
                       9991 "NEVER USED INHALANTS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define INHNEWE   501 "Gasoline or lighter fluids"
                       9991 "NEVER USED INHALANTS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define INHEVER   1 "Yes" 91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define INHAGE    985 "BAD DATA Logically assigned"
                       991 "NEVER USED INHALANTS" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define INHYFU    9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED INHALANTS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define INHMFU    1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define INHREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in lifetime LOG ASSN"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define INHYRTOT  985 "BAD DATA Logically assigned"
                       991 "NEVER USED INHALANTS"
                       993 "DID NOT USE INHALANTS IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define INTOTFG   1 "Trimmed to 365 days (no further editing)"
                       2 "Trimmed relative to the 30-day freq"
                       98 "BLANK (NO ANSWER)" ;
label define INFQFLG   1 "Trimmed to be consistent with mo/yr of 1st use"
                       98 "BLANK (NO ANSWER)" ;
label define INBSTWAY  1 "Prefer to answer in days per week"
                       2 "Prefer to answer in days per month"
                       3 "Prefer to answer in days per year"
                       11 "Prefer to ans in days per wk LOG ASSN"
                       12 "Prefer to ans in days per mo LOG ASSN"
                       13 "Prefer to ans in days per yr LOG ASSN"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define INDAYPYR  985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       991 "NEVER USED INHALANTS"
                       993 "DID NOT USE INHALANTS IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define INDAYPMO  89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define INDAYPWK  85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define INHDY30A  85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define IN30EST   1 "1 or 2 days" 2 "3 to 5 days"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DARVTYLC  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PERCTYLX  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define VICOLOR   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ANLCARD   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CODEINE   1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DEMEROL   1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DILAUD    1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define FIORICET  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define FIORINAL  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HYDROCOD  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define METHDON   1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MORPHINE  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define OXYCONTN  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PHENCOD   1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PROPOXY   1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SK65A     1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define STADOL    1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TALACEN   1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TALWIN    1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TALWINNX  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TRAMADOL  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ULTRAM    1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ANLNOLST  1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ANALNEWA  109 "Seconal" 110 "Tuinal" 113 "Halcion, Triazolam"
                       115 "Phenobarbital"
                       116 "Methaqualone, Quaalude, Sopor"
                       120 "Downers; OTHER Sedative, NOT OTHERWISE SPECIFIED"
                       124 "Yellow jackets" 130 "Phenergan, Promethazine"
                       141 "Dilantin" 173 "Wafers" 174 "Ambien, Zolpidem"
                       178 "Quetiapine, Seroquel" 201 "Valium, Diazepam"
                       207 "Ativan, Lorazapam" 209 "Xanax, Alprazolam"
                       211 "Buspar"
                       221 "OTHER Tranquilizer, NOT OTHERWISE SPECIFIED"
                       223 "Carbacot, Marbaxin, Methocarbamol, Robaxin"
                       225 "Desyrel, Trazodone hydrochloride" 227 "Thorazine"
                       228 "Amitriptyline, Elavil"
                       234 "Cyclobenzaprine, Flexeril"
                       240 "Lithium carbonate, Lithonate" 241 "Prozac"
                       246 "Clonazepam, Klonopin, Rivotril"
                       250 "Aventyl, Nortriptyline, Pamelor"
                       268 "Rohypnol, Roche, roofies" 271 "Zoloft"
                       283 "Paroxetine, Paxil" 290 "Skelaxin" 292 "Serzone"
                       301 "Dexedrine" 318 "Ritalin, Methylphenidate"
                       322 "Methamphetamine ('ice' or 'crank'), Meth"
                       332 "Ephedrine" 336 "Diet pills"
                       382 "Footballs, pink footballs, purple footballs"
                       401 "Darvon" 406 "Percodan" 407 "Demerol"
                       408 "Dilaudid"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol 4"
                       410 "Phenaphen with Codeine, Phenaphen 3"
                       413 "Talacen" 415 "Codeine" 417 "Morphine, Roxanol"
                       418 "Dolophine, Methadone" 419 "Stadol, Stadol NS"
                       420 "OTHER Analgesic, NOT OTHERWISE SPECIFIED"
                       421 "USED ANALGESIC, DON'T KNOW NAME" 422 "Motrin"
                       423 "Percocet" 425 "Advil <OTC>" 426 "Fiorinal"
                       427 "Darvocet" 430 "Aspirin, Ecotrin, Empirin <OTC>"
                       431 "Tylox"
                       434 "Anexsia, Co-Gesic, Lorcet, Lortab, Vicodin, Zydo"
                       435 "Tylenol, Tylenol Extra-Strength <OTC>"
                       438 "Anaprox, Naprosyn, Naproxen" 442 "Ibuprofen"
                       444 "Aspirin with Codeine, Empirin 3"
                       447 "Synalgos, Synalgos DC"
                       458 "Mepergan, Mepergan Fortis, Meprozine"
                       465 "Fentanyl, Duragesic, Sublimaze" 466 "Midol <OTC>"
                       476 "Duradrin, Isocom, Midrin"
                       481 "Acular, Ketorolac tromethamine, Toradol"
                       490 "Nubain" 496 "Ultram"
                       498 "Ponstel, Mefenamic acid"
                       658 "Special K, Ketamine"
                       701 "OTHER Opiates, NOT OTHERWISE SPECIFIED"
                       703 "Opium" 819 "Inderal, Propranalol"
                       820 "Penicillin" 821 "Amoxicillin, Ampicillin"
                       828 "Tetracycline" 858 "Antibiotic"
                       897 "Synthroid, Levothyroxine"
                       2001 "Carisoprodol, Soma" 2002 "Muscle Relaxers"
                       2003 "Zannies, zans, zany bars" 3004 "Black cadillac"
                       3015 "Fen-Phen (fenfluramine and phentermine)"
                       3023 "Adderall" 3027 "Energy pills" 3050 "Mini Thins"
                       3052 "Speed; otherwise unspecified"
                       3072 "Purple Blast <OTC>"
                       4001 "Actron, Ketoprofen, Orudis, Oruvail"
                       4002 "Imitrex, Sumatriptan"
                       4031 "Cough medicine with codeine" 4033 "Vicoprofen"
                       4035 "Nabumetone, Relafin" 4038 "Propacet"
                       4039 "Daypro" 4044 "Hydrocodone" 4046 "Oxycodone"
                       4051 "Celebrex" 4055 "Vioxx" 4061 "Oramorph SR"
                       4063 "Naprelan" 4066 "Suprax" 4067 "Oxycontin"
                       4068 "Roxilox" 4069 "Benflogin" 4071 "Syncol"
                       4072 "Oxycet" 4073 "Temgesic" 4074 "Provil <OTC>"
                       6083 "CCC, Triple 'C', C3" 8002 "Zantac"
                       8007 "Gabapentin, Neurontin"
                       8008 "Antidepressant; type unspecified"
                       8010 "Zyrtec, cetirizine"
                       8019 "Azithromycin, Zithromax" 8020 "Allegra"
                       8025 "Claritin, Claritin D" 8032 "Prilosec"
                       8035 "Prednisone" 8044 "Cephelaxin, Keflex"
                       8058 "Cough medicine/syrup; type unspecified"
                       8063 "Heprin" 8071 "Augmentin" 8073 "Deconamine"
                       8082 "Robinul" 8086 "Provera"
                       8098 "Potassium chloride" 8099 "Somatech"
                       8101 "Colace <OTC>"
                       9981 "NEVER USED PAIN RELIEVERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9991 "NEVER USED PAIN RELIEVERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define ANALNEWB  105 "Placidyl" 109 "Seconal" 110 "Tuinal"
                       115 "Phenobarbital"
                       116 "Methaqualone, Quaalude, Sopor"
                       120 "Downers; OTHER Sedative, NOT OTHERWISE SPECIFIED"
                       124 "Yellow jackets" 174 "Ambien, Zolpidem"
                       178 "Quetiapine, Seroquel" 201 "Valium, Diazepam"
                       207 "Ativan, Lorazapam" 209 "Xanax, Alprazolam"
                       225 "Desyrel, Trazodone hydrochloride" 227 "Thorazine"
                       234 "Cyclobenzaprine, Flexeril" 237 "Versed"
                       241 "Prozac" 246 "Clonazepam, Klonopin, Rivotril"
                       268 "Rohypnol, Roche, roofies" 271 "Zoloft"
                       295 "Mirtazapine, Remeron" 311 "Preludin"
                       318 "Ritalin, Methylphenidate" 319 "Cylert"
                       321 "Methedrine" 326 "White cross"
                       382 "Footballs, pink footballs, purple footballs"
                       406 "Percodan" 407 "Demerol"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol 4"
                       411 "Talwin" 415 "Codeine" 417 "Morphine, Roxanol"
                       418 "Dolophine, Methadone"
                       420 "OTHER Analgesic, NOT OTHERWISE SPECIFIED"
                       421 "USED ANALGESIC, DON'T KNOW NAME" 422 "Motrin"
                       423 "Percocet" 425 "Advil <OTC>"
                       430 "Aspirin, Ecotrin, Empirin <OTC>" 431 "Tylox"
                       434 "Anexsia, Co-Gesic, Lorcet, Lortab, Vicodin, Zydo"
                       435 "Tylenol, Tylenol Extra-Strength <OTC>"
                       442 "Ibuprofen"
                       458 "Mepergan, Mepergan Fortis, Meprozine"
                       468 "Excedrin <OTC>" 496 "Ultram"
                       606 "'Ecstasy' (MDMA), X-TC, 'X'" 820 "Penicillin"
                       829 "Robitussin DM <OTC>" 874 "Premarin"
                       1001 "Benadryl <OTC>" 2001 "Carisoprodol, Soma"
                       2002 "Muscle Relaxers"
                       4031 "Cough medicine with codeine" 4033 "Vicoprofen"
                       4044 "Hydrocodone" 4051 "Celebrex" 4052 "Endocet"
                       4058 "Totem poles"
                       4076 "OTC pain reliever; not otherwise specified <OTC>"
                       6083 "CCC, Triple 'C', C3" 8020 "Allegra"
                       8064 "Triaminic <OTC>"
                       9981 "NEVER USED PAIN RELIEVERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9991 "NEVER USED PAIN RELIEVERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define ANALNEWC  110 "Tuinal" 116 "Methaqualone, Quaalude, Sopor"
                       174 "Ambien, Zolpidem" 201 "Valium, Diazepam"
                       207 "Ativan, Lorazapam" 209 "Xanax, Alprazolam"
                       225 "Desyrel, Trazodone hydrochloride"
                       246 "Clonazepam, Klonopin, Rivotril"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol 4"
                       415 "Codeine" 417 "Morphine, Roxanol"
                       420 "OTHER Analgesic, NOT OTHERWISE SPECIFIED"
                       421 "USED ANALGESIC, DON'T KNOW NAME" 422 "Motrin"
                       423 "Percocet" 427 "Darvocet"
                       434 "Anexsia, Co-Gesic, Lorcet, Lortab, Vicodin, Zydo"
                       435 "Tylenol, Tylenol Extra-Strength <OTC>"
                       496 "Ultram" 896 "Catapres, Clonidine"
                       3052 "Speed; otherwise unspecified" 4044 "Hydrocodone"
                       4068 "Roxilox" 8002 "Zantac" 8042 "Alka Seltzer <OTC>"
                       8074 "Fansidar"
                       9981 "NEVER USED PAIN RELIEVERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9991 "NEVER USED PAIN RELIEVERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define ANALNEWD  105 "Placidyl" 201 "Valium, Diazepam"
                       207 "Ativan, Lorazapam" 228 "Amitriptyline, Elavil"
                       406 "Percodan"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol 4"
                       415 "Codeine"
                       420 "OTHER Analgesic, NOT OTHERWISE SPECIFIED"
                       423 "Percocet"
                       434 "Anexsia, Co-Gesic, Lorcet, Lortab, Vicodin, Zydo"
                       435 "Tylenol, Tylenol Extra-Strength <OTC>"
                       9981 "NEVER USED PAIN RELIEVERS Logically assigned"
                       9991 "NEVER USED PAIN RELIEVERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define ANALNEWE  201 "Valium, Diazepam"
                       420 "OTHER Analgesic, NOT OTHERWISE SPECIFIED"
                       423 "Percocet"
                       9981 "NEVER USED PAIN RELIEVERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED PAIN RELIEVERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define ANLEVER   1 "Yes"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ANALAGE   981 "NEVER USED PAIN RELIEVERS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED PAIN RELIEVERS" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define ANALYFU   9981 "NEVER USED PAIN RELIEVERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED PAIN RELIEVERS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define ANALMFU   1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ANALREC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in lifetime LOG ASSN"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ANLYRTOT  981 "NEVER USED PAIN RELIEVERS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED PAIN RELIEVERS"
                       993 "DID NOT USE PAIN RELIEVERS IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define PRTOTFG   98 "BLANK (NO ANSWER)" ;
label define PRFQFLG   1 "Trimmed to be consistent with mo/yr of 1st use"
                       98 "BLANK (NO ANSWER)" ;
label define PRBSTWAY  1 "Prefer to answer in days per week"
                       2 "Prefer to answer in days per month"
                       3 "Prefer to answer in days per year"
                       11 "Prefer to ans in days per wk LOG ASSN"
                       12 "Prefer to ans in days per mo LOG ASSN"
                       13 "Prefer to ans in days per yr LOG ASSN"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS IN PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PRDAYPYR  981 "NEVER USED PAIN RELIEVERS Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       991 "NEVER USED PAIN RELIEVERS"
                       993 "DID NOT USE PAIN RELIEVERS IN PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define PRDAYPMO  81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS IN PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PRDAYPWK  81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS IN PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define KLONOPIN  1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define XNAXATVN  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define VALMDIAZ  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRNCARD   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ATARAX    1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BUSPAR    1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define EQUANIL   1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define FLEXERIL  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define LIBRIUM   1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define LIMBTROL  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MEPROB    1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MILTOWN   1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ROHYPNOL  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SERAX     1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SOMA      1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TRANXENE  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define VISTAR    1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TRNOLST   1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRNEWA    105 "Placidyl" 108 "Nembutal" 109 "Seconal"
                       112 "Restoril, Temazepam" 113 "Halcion, Triazolam"
                       115 "Phenobarbital"
                       116 "Methaqualone, Quaalude, Sopor"
                       120 "Downers; OTHER Sedative, NOT OTHERWISE SPECIFIED"
                       124 "Yellow jackets" 129 "Reds" 138 "Mandrakes"
                       174 "Ambien, Zolpidem" 178 "Quetiapine, Seroquel"
                       189 "Sonata" 192 "Promazine" 201 "Valium, Diazepam"
                       207 "Ativan, Lorazapam" 209 "Xanax, Alprazolam"
                       211 "Buspar"
                       221 "OTHER Tranquilizer, NOT OTHERWISE SPECIFIED"
                       222 "USED TRANQUILIZER, DON'T KNOW NAME" 224 "Triavil"
                       225 "Desyrel, Trazodone hydrochloride" 227 "Thorazine"
                       228 "Amitriptyline, Elavil" 232 "Mellaril"
                       234 "Cyclobenzaprine, Flexeril" 241 "Prozac"
                       250 "Aventyl, Nortriptyline, Pamelor"
                       268 "Rohypnol, Roche, roofies" 278 "Benzodiazepines"
                       283 "Paroxetine, Paxil" 289 "Olanzapine, Zyprexa"
                       298 "Acepromazine, PromAce" 299 "Midozolam"
                       318 "Ritalin, Methylphenidate" 336 "Diet pills"
                       369 "Artane" 411 "Talwin" 417 "Morphine, Roxanol"
                       421 "USED ANALGESIC, DON'T KNOW NAME" 423 "Percocet"
                       432 "Rufen"
                       435 "Tylenol, Tylenol Extra-Strength <OTC>"
                       438 "Anaprox, Naprosyn, Naproxen" 445 "Norgesic Forte"
                       658 "Special K, Ketamine"
                       663 "Animal tranquilizer, horse tranquilizer"
                       802 "THC, cannabinol, marinol" 886 "Spanish fly"
                       1002 "Dramamine, seasick/motion sickness pill <OTC>"
                       2001 "Carisoprodol, Soma" 2002 "Muscle Relaxers"
                       3026 "Bupropion, Wellbutrin, Zyban" 3037 "Effexor"
                       3077 "Concerta" 4060 "Ansaid, Flurbiprophen"
                       8008 "Antidepressant; type unspecified"
                       8024 "Asthma inhaler/medication, bronchial dilators"
                       9981 "NEVER USED TRANQUILIZERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9991 "NEVER USED TRANQUILIZERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define TRNEWB    108 "Nembutal" 116 "Methaqualone, Quaalude, Sopor"
                       120 "Downers; OTHER Sedative, NOT OTHERWISE SPECIFIED"
                       138 "Mandrakes" 174 "Ambien, Zolpidem"
                       201 "Valium, Diazepam" 212 "Miltown" 213 "Equanil"
                       222 "USED TRANQUILIZER, DON'T KNOW NAME" 224 "Triavil"
                       225 "Desyrel, Trazodone hydrochloride" 227 "Thorazine"
                       234 "Cyclobenzaprine, Flexeril"
                       250 "Aventyl, Nortriptyline, Pamelor" 280 "Ketaset"
                       283 "Paroxetine, Paxil"
                       663 "Animal tranquilizer, horse tranquilizer"
                       4067 "Oxycontin"
                       9981 "NEVER USED TRANQUILIZERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED TRANQUILIZERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define TRNEWC    112 "Restoril, Temazepam" 113 "Halcion, Triazolam"
                       220 "Meprobamate"
                       221 "OTHER Tranquilizer, NOT OTHERWISE SPECIFIED"
                       222 "USED TRANQUILIZER, DON'T KNOW NAME"
                       225 "Desyrel, Trazodone hydrochloride"
                       9981 "NEVER USED TRANQUILIZERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED TRANQUILIZERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define TRNEWD    110 "Tuinal" 113 "Halcion, Triazolam"
                       225 "Desyrel, Trazodone hydrochloride"
                       9981 "NEVER USED TRANQUILIZERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED TRANQUILIZERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define TRNEWE    113 "Halcion, Triazolam"
                       225 "Desyrel, Trazodone hydrochloride"
                       9981 "NEVER USED TRANQUILIZERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED TRANQUILIZERS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define TRNEVER   1 "Yes"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRANAGE   981 "NEVER USED TRANQUILIZERS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED TRANQUILIZERS" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define TRANYFU   9981 "NEVER USED TRANQUILIZERS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED TRANQUILIZERS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define TRANMFU   1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TRANREC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in lifetime LOG ASSN"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TRNYRTOT  981 "NEVER USED TRANQUILIZERS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED TRANQUILIZERS"
                       993 "DID NOT USE TRANQUILIZERS IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define TRTOTFG   1 "Trimmed to 365 days (no further editing)"
                       98 "BLANK (NO ANSWER)" ;
label define TRFQFLG   1 "Trimmed to be consistent with mo/yr of 1st use"
                       98 "BLANK (NO ANSWER)" ;
label define TRBSTWAY  1 "Prefer to answer in days per week"
                       2 "Prefer to answer in days per month"
                       3 "Prefer to answer in days per year"
                       12 "Prefer to ans in days per mo LOG ASSN"
                       13 "Prefer to ans in days per yr LOG ASSN"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRDAYPYR  981 "NEVER USED TRANQUILIZERS Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       991 "NEVER USED TRANQUILIZERS"
                       993 "DID NOT USE TRANQUILIZERS IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define TRDAYPMO  81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TRDAYPWK  81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define METHDES   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DIETPILS  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RITMPHEN  1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STMCARD   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CYLERT    1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DEXED     1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DETAMP    1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DIDREX    1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ESKAT     1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IONAMIN   1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MAZANOR   1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define OBLA      1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PLEGINE   1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PRELUDIN  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SANOREX   1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TENUATE   1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define STMNOLST  1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STIMNEWA  124 "Yellow jackets" 130 "Phenergan, Promethazine"
                       201 "Valium, Diazepam"
                       202 "Librium, Chlordiazepoxide HCl" 211 "Buspar"
                       240 "Lithium carbonate, Lithonate" 241 "Prozac"
                       246 "Clonazepam, Klonopin, Rivotril"
                       268 "Rohypnol, Roche, roofies" 271 "Zoloft"
                       283 "Paroxetine, Paxil" 301 "Dexedrine"
                       304 "Benzedrine" 306 "Desoxyn"
                       307 "Tenuate, Diethylpropion"
                       313 "Adipex-P, Fastin, Phentermine"
                       314 "Pondimin, Fenfluramine"
                       318 "Ritalin, Methylphenidate" 321 "Methedrine"
                       322 "Methamphetamine ('ice' or 'crank'), Meth"
                       324 "Uppers; OTHER Stimulant, NOT OTHERWISE SPECIFIED"
                       325 "USED STIMULANT, DON'T KNOW NAME"
                       326 "White cross" 327 "Black beauties, Black beauty"
                       328 "Pink hearts"
                       329 "Bird?s eggs, Robin's eggs, speckled eggs"
                       330 "Blue birds, blue jays, blue robins, speckled bir"
                       332 "Ephedrine" 333 "357 Magnum, Magnum 44 <OTC>"
                       334 "Crossroads, cross tops" 336 "Diet pills"
                       339 "Amphetamines" 345 "Black Molly" 352 "Lemons"
                       353 "No-Doz <OTC>" 355 "Crystal meth"
                       359 "Criss cross" 374 "Christmas tree(s)"
                       396 "Black Rjs, RJ8"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol 4"
                       418 "Dolophine, Methadone"
                       434 "Anexsia, Co-Gesic, Lorcet, Lortab, Vicodin, Zydo"
                       435 "Tylenol, Tylenol Extra-Strength <OTC>"
                       606 "'Ecstasy' (MDMA), X-TC, 'X'"
                       658 "Special K, Ketamine" 702 "Heroin"
                       806 "Crack, rock" 814 "Caffeine <OTC>"
                       3001 "Brown and clear" 3008 "Miniwhites"
                       3015 "Fen-Phen (fenfluramine and phentermine)"
                       3018 "Up-johns" 3023 "Adderall" 3037 "Effexor"
                       3041 "Desbutal" 3050 "Mini Thins"
                       3052 "Speed; otherwise unspecified" 3070 "Synatan"
                       4027 "Rorer" 4064 "Epidrin"
                       9981 "NEVER USED STIMULANTS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9991 "NEVER USED STIMULANTS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define STIMNEWB  124 "Yellow jackets" 137 "7-14" 312 "Ionamin"
                       318 "Ritalin, Methylphenidate" 321 "Methedrine"
                       324 "Uppers; OTHER Stimulant, NOT OTHERWISE SPECIFIED"
                       325 "USED STIMULANT, DON'T KNOW NAME"
                       326 "White cross" 327 "Black beauties, Black beauty"
                       328 "Pink hearts"
                       329 "Bird?s eggs, Robin's eggs, speckled eggs"
                       332 "Ephedrine" 334 "Crossroads, cross tops"
                       345 "Black Molly" 374 "Christmas tree(s)"
                       382 "Footballs, pink footballs, purple footballs"
                       3023 "Adderall" 3035 "Blacks" 3037 "Effexor"
                       3038 "Obenil" 3050 "Mini Thins" 3069 "DextroStat"
                       3076 "Norephedrine <OTC>"
                       9981 "NEVER USED STIMULANTS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9991 "NEVER USED STIMULANTS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define STIMNEWC  116 "Methaqualone, Quaalude, Sopor"
                       318 "Ritalin, Methylphenidate"
                       325 "USED STIMULANT, DON'T KNOW NAME"
                       326 "White cross" 374 "Christmas tree(s)"
                       382 "Footballs, pink footballs, purple footballs"
                       840 "Cough medicine (contents not specified) <OTC>"
                       847 "GHB, NSC" 3001 "Brown and clear" 3023 "Adderall"
                       9981 "NEVER USED STIMULANTS Logically assigned"
                       9991 "NEVER USED STIMULANTS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define STIMNEWD  129 "Reds" 374 "Christmas tree(s)"
                       435 "Tylenol, Tylenol Extra-Strength <OTC>"
                       9981 "NEVER USED STIMULANTS Logically assigned"
                       9991 "NEVER USED STIMULANTS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define STIMNEWE  124 "Yellow jackets"
                       9981 "NEVER USED STIMULANTS Logically assigned"
                       9991 "NEVER USED STIMULANTS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define STMEVER   1 "Yes" 81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define STIMAGE   981 "NEVER USED STIMULANTS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED STIMULANTS" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define STIMYFU   9981 "NEVER USED STIMULANTS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assn"
                       9991 "NEVER USED STIMULANTS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define STIMMFU   1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assn"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define STIMREC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in lifetime LOG ASSN"
                       11 "Used in the past 30 days LOGICALLY ASSIGNED"
                       12 "Used >30 days ago but within pst 12 mos LOG ASSN"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define STMYRTOT  981 "NEVER USED STIMULANTS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED STIMULANTS"
                       993 "DID NOT USE STIMULANTS IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define STTOTFG   98 "BLANK (NO ANSWER)" ;
label define STFQFLG   1 "Trimmed to be consistent with mo/yr of 1st use"
                       98 "BLANK (NO ANSWER)" ;
label define STBSTWAY  1 "Prefer to answer in days per week"
                       2 "Prefer to answer in days per month"
                       3 "Prefer to answer in days per year"
                       11 "Prefer to ans in days per wk LOG ASSN"
                       12 "Prefer to ans in days per mo LOG ASSN"
                       13 "Prefer to ans in days per yr LOG ASSN"
                       21 "Prefer to ans in days per wk (MTBSTWAY=1,11)"
                       22 "Prefer to ans in days per mo (MTBSTWAY=2,12)"
                       23 "Prefer to ans in days per yr (MTBSTWAY=3,13)"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STDAYPYR  981 "NEVER USED STIMULANTS Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       991 "NEVER USED STIMULANTS"
                       993 "DID NOT USE STIMULANTS IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define STDAYPMO  81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define STDAYPWK  81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define METHAGE   981 "NEVER USED METHAMPHETAMINES Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED METHAMPHETAMINES" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define METHYFU   9981 "NEVER USED METHAMPHETAMINES Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED METHAMPHETAMINES" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define METHMFU   1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       81 "NEVER USED METHAMPHETAMINES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED METHAMPHETAMINES" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define METHREC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in lifetime LOG ASSN"
                       81 "NEVER USED METHAMPHETAMINES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED METHAMPHETAMINES" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define MTHYRTOT  981 "NEVER USED METHAMPHETAMINE Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED METHAMPHETAMINE"
                       993 "DID NOT USE METHAMPHETAMINE IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define MTTOTFG   98 "BLANK (NO ANSWER)" ;
label define MTFQFLG   1 "Trimmed to be consistent with mo/yr of 1st use"
                       98 "BLANK (NO ANSWER)" ;
label define MTBSTWAY  1 "Prefer to answer in days per week"
                       2 "Prefer to answer in days per month"
                       3 "Prefer to answer in days per year"
                       12 "Prefer to ans in days per mo LOG ASSN"
                       13 "Prefer to ans in days per yr LOG ASSN"
                       81 "NEVER USED METHAMPHETAMINE Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED METHAMPHETAMINE"
                       93 "DID NOT USE METHAMPHETAMINE IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MTDAYPYR  981 "NEVER USED METHAMPHETAMINE Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       991 "NEVER USED METHAMPHETAMINE"
                       993 "DID NOT USE METHAMPHETAMINE IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define MTDAYPMO  81 "NEVER USED METHAMPHETAMINE Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED METHAMPHETAMINE"
                       93 "DID NOT USE METHAMPHETAMINE IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MTDAYPWK  81 "NEVER USED METHAMPHETAMINE Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED METHAMPHETAMINE"
                       93 "DID NOT USE METHAMPHETAMINE IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define METHAQ    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define NEMBBARB  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RESTTMAZ  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SEDCARD   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define AMYTAL    1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define BUTISOL   1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CHHYD     1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DALMANE   1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HALCION   1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PHENOBAR  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PLACIDYL  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TUINAL    1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SEDNOLST  1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SEDNEWA   109 "Seconal" 110 "Tuinal" 113 "Halcion, Triazolam"
                       115 "Phenobarbital"
                       116 "Methaqualone, Quaalude, Sopor"
                       120 "Downers; OTHER Sedative, NOT OTHERWISE SPECIFIED"
                       121 "USED SEDATIVE, DON'T KNOW NAME" 129 "Reds"
                       131 "Haldol, Haloperidol" 156 "Sodium barbital"
                       171 "NyQuil <OTC>" 174 "Ambien, Zolpidem"
                       178 "Quetiapine, Seroquel" 189 "Sonata"
                       201 "Valium, Diazepam" 207 "Ativan, Lorazapam"
                       209 "Xanax, Alprazolam"
                       225 "Desyrel, Trazodone hydrochloride"
                       228 "Amitriptyline, Elavil"
                       234 "Cyclobenzaprine, Flexeril"
                       247 "Adapin, Doxepin, Sinequan"
                       268 "Rohypnol, Roche, roofies" 326 "White cross"
                       415 "Codeine" 438 "Anaprox, Naprosyn, Naproxen"
                       658 "Special K, Ketamine"
                       801 "OTHER Drugs, NOT OTHERWISE SPECIFIED"
                       4011 "Carbamazepine, Epitol, Tegretol"
                       6108 "Gorilla biscuits"
                       8009 "Allergy pills/antihistamine; type unspecified"
                       8010 "Zyrtec, cetirizine" 8082 "Robinul"
                       9981 "NEVER USED SEDATIVES Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9991 "NEVER USED SEDATIVES" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define SEDNEWB   108 "Nembutal" 116 "Methaqualone, Quaalude, Sopor"
                       119 "Secobarbital"
                       121 "USED SEDATIVE, DON'T KNOW NAME"
                       174 "Ambien, Zolpidem" 181 "Excedrin P.M. <OTC>"
                       189 "Sonata" 191 "Blues"
                       225 "Desyrel, Trazodone hydrochloride"
                       434 "Anexsia, Co-Gesic, Lorcet, Lortab, Vicodin, Zydo"
                       438 "Anaprox, Naprosyn, Naproxen"
                       2001 "Carisoprodol, Soma"
                       8085 "Antipsychotics; type unspecified"
                       9981 "NEVER USED SEDATIVES Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9991 "NEVER USED SEDATIVES" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define SEDNEWC   2001 "Carisoprodol, Soma"
                       9981 "NEVER USED SEDATIVES Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED SEDATIVES" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define SEDNEWD   9981 "NEVER USED SEDATIVES Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED SEDATIVES" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define SEDNEWE   9981 "NEVER USED SEDATIVES Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED SEDATIVES" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define SEDEVER   1 "Yes" 81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SEDAGE    981 "NEVER USED SEDATIVES Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED SEDATIVES" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define SEDYFU    9981 "NEVER USED SEDATIVES Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED SEDATIVES" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define SEDMFU    1 "January" 2 "February" 3 "March" 4 "April" 5 "May"
                       6 "June" 7 "July" 8 "August" 9 "September"
                       10 "October" 11 "November" 12 "December"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SEDREC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "Used at some point in the past 12 mos LOG ASSN"
                       9 "Used at some point in lifetime LOG ASSN"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SEDYRTOT  981 "NEVER USED SEDATIVES Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED SEDATIVES"
                       993 "DID NOT USE SEDATIVES IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define SVTOTFG   98 "BLANK (NO ANSWER)" ;
label define SVFQFLG   1 "Trimmed to be consistent with mo/yr of 1st use"
                       98 "BLANK (NO ANSWER)" ;
label define SVBSTWAY  1 "Prefer to answer in days per week"
                       2 "Prefer to answer in days per month"
                       3 "Prefer to answer in days per year"
                       12 "Prefer to ans in days per mo LOG ASSN"
                       13 "Prefer to ans in days per yr LOG ASSN"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SVDAYPYR  981 "NEVER USED SEDATIVES Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       991 "NEVER USED SEDATIVES"
                       993 "DID NOT USE SEDATIVES IN THE PAST 12 MOS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define SVDAYPMO  81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SVDAYPWK  81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES IN THE PAST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IRCIGRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago" 9 "Never smoked cigarettes" ;
label define IICIGRC   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2CIGRC  1 "Questionnaire data" 2 "Logically edited data"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8"
                       6 "Statistically imputed data - edited recency=19"
                       7 "Statistically imputed data - edited recency=14" ;
label define IRCGRRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago" 9 "Never smoked cigars" ;
label define IICGRRC   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2CGRRC  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8"
                       6 "Statistically imputed data - edited recency=19"
                       7 "Statistically imputed data - edited recency=14" ;
label define IRPIPLF   1 "Ever used pipes" 9 "Never smoked pipes" ;
label define IIPIPLF   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRPIPMN   1 "Within the past 30 days"
                       2 "More than 30 days ago but within lifetime"
                       9 "Never smoked pipes" ;
label define IIPIPMN   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRSLTRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       9 "Never used smokeless tobacco" ;
label define IISLTRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2SLTRC  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8"
                       6 "Statistically imputed data - edited recency=19"
                       7 "Statistically imputed data - edited recency=14" ;
label define IRCHWRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       9 "Never used chewing tobacco" ;
label define IICHWRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2CHWRC  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8"
                       6 "Statistically imputed data - edited recency=19"
                       7 "Statistically imputed data - edited recency=14" ;
label define IRSNFRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago" 9 "Never used snuff" ;
label define IISNFRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2SNFRC  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8"
                       6 "Statistically imputed data - edited recency=19"
                       7 "Statistically imputed data - edited recency=14" ;
label define IRALCRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 9 "Never used alcohol" ;
label define IIALCRC   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2ALCRC  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8" ;
label define IRMJRC    1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 9 "Never used marijuana" ;
label define IIMJRC    1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2MJRC   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8" ;
label define IRCOCRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 9 "Never used cocaine" ;
label define IICOCRC   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2COCRC  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8" ;
label define IRCRKRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 9 "Never used crack" ;
label define IICRKRC   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2CRKRC  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8" ;
label define IRHERRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 9 "Never used heroin" ;
label define IIHERRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2HERRC  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8" ;
label define IRHALRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       9 "Never used hallucinogens" ;
label define IIHALRC   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2HALRC  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8" ;
label define IRLSDRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 9 "Never used LSD" ;
label define IILSDRC   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2LSDRC  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8" ;
label define IRPCPRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 9 "Never used PCP" ;
label define IIPCPRC   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2PCPRC  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8" ;
label define IRECSRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 9 "Never used ecstasy" ;
label define IIECSRC   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2ECSRC  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8" ;
label define IRINHRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 9 "Never used inhalants" ;
label define IIINHRC   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2INHRC  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8" ;
label define IRANLRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       9 "Never used pain relievers" ;
label define IIANLRC   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2ANLRC  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8" ;
label define IRTRNRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       9 "Never used tranquilizers" ;
label define IITRNRC   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2TRNRC  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8" ;
label define IRSTMRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 9 "Never used stimulants" ;
label define IISTMRC   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2STMRC  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8" ;
label define IRMTHRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       9 "Never used methamphetamines" ;
label define IIMTHRC   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2MTHRC  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8" ;
label define IRSEDRC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 9 "Never used sedatives" ;
label define IISEDRC   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2SEDRC  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - edited recency=9"
                       5 "Statistically imputed data - edited recency=8" ;
label define IRALCFY   991 "NEVER USED ALCOHOL"
                       993 "DID NOT USE ALCOHOL PAST YEAR" ;
label define IIALCFY   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2ALCFY  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRMJFY    991 "NEVER USED MARIJUANA"
                       993 "DID NOT USE MARIJUANA PAST YEAR" ;
label define IIMJFY    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2MJFY   1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRCOCFY   991 "NEVER USED COCAINE"
                       993 "DID NOT USE COCAINE PAST YEAR" ;
label define IICOCFY   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2COCFY  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRCRKFY   991 "NEVER USED CRACK"
                       993 "DID NOT USE CRACK PAST YEAR" ;
label define IICRKFY   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2CRKFY  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRHERFY   991 "NEVER USED HEROIN"
                       993 "DID NOT USE HEROIN PAST YEAR" ;
label define IIHERFY   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2HERFY  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRHALFY   991 "NEVER USED HALLUCINOGENS"
                       993 "DID NOT USE HALLUCINOGENS PAST YEAR" ;
label define IIHALFY   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2HALFY  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRINHFY   991 "NEVER USED INHALANTS"
                       993 "DID NOT USE INHALANTS PAST YEAR" ;
label define IIINHFY   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2INHFY  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRANLFY   991 "NEVER USED PAIN RELIEVER"
                       993 "DID NOT USE PAIN RELIEVER PAST YEAR" ;
label define IIANLFY   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2ANLFY  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRTRNFY   991 "NEVER USED TRANQUILIZERS"
                       993 "DID NOT USE TRANQUILIZERS PAST YEAR" ;
label define IITRNFY   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2TRNFY  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRSTMFY   991 "NEVER USED STIMULANTS"
                       993 "DID NOT USE STIMULANTS PAST YEAR" ;
label define IISTMFY   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2STMFY  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRMTHFY   991 "NEVER USED METH" 993 "DID NOT USE METH PAST YEAR" ;
label define IIMTHFY   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2MTHFY  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRSEDFY   991 "NEVER USED SEDATIVES"
                       993 "DID NOT USE SEDATIVES PAST YEAR" ;
label define IISEDFY   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2SEDFY  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRCIGFM   91.00 "NEVER USED"
                       93.00 "DID NOT USE CIGARETTES PAST MONTH" ;
label define IICIGFM   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2CIGFM  1 "Questionnaire data" 2 "Logically edited data"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRCGRFM   91.00 "NEVER SMOKED CIGARS"
                       93.00 "DID NOT SMOKE CIGARS PAST MONTH" ;
label define IICGRFM   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2CGRFM  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRCHWFM   91.00 "NEVER USED CHEWING TOBACCO"
                       93.00 "DID NOT USE CHEWING TOBACCO PAST MONTH" ;
label define IICHWFM   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2CHWFM  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRSNFFM   91.00 "NEVER USED SNUFF"
                       93.00 "DID NOT USE SNUFF PAST MONTH" ;
label define IISNFFM   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2SNFFM  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRALCFM   91.00 "NEVER USED ALCOHOL"
                       93.00 "DID NOT USE ALCOHOL PAST MONTH" ;
label define IIALCFM   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2ALCFM  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRALCD5   91 "NEVER USED ALCOHOL"
                       93 "DID NOT HAVE 5+ ALC DRNKS PAST MONTH" ;
label define IIALCD5   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2ALCD5  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRMJFM    91.00 "NEVER USED MARIJUANA"
                       93.00 "DID NOT USE MARIJUANA PAST MONTH" ;
label define IIMJFM    1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2MJFM   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRCOCFM   91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE PAST MONTH" ;
label define IICOCFM   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2COCFM  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRCRKFM   91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK PAST MONTH" ;
label define IICRKFM   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define II2CRKFM  1 "Questionnaire data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRHERFM   91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PAST MONTH" ;
label define IIHERFM   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2HERFM  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRHALFM   91.00 "NEVER USED HALLUCINOGENS"
                       93.00 "DID NOT USE HALLUCINOGENS PAST MONTH" ;
label define IIHALFM   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2HALFM  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRINHFM   91.00 "NEVER USED INHALANTS"
                       93.00 "DID NOT USE INHALANTS PAST MONTH" ;
label define IIINHFM   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define II2INHFM  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data - lifetime use imputed"
                       4 "Statistically imputed data - lifetime use known" ;
label define IRCIGAGE  991 "NEVER USED" ;
label define IICIGAGE  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRCIGYFU  9999 "NEVER USED" ;
label define IICIGYFU  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRCDUAGE  991 "Never Used" 993 "Never a daily user" ;
label define IICDUAGE  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define IRCDUYFU  9993 "NEVER A DAILY USER" 9999 "NEVER USED" ;
label define IICDUYFU  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRCGRAGE  991 "NEVER USED" ;
label define IICGRAGE  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRCGRYFU  9999 "NEVER USED" ;
label define IICGRYFU  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRSNFAGE  991 "Never Used" ;
label define IISNFAGE  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRSNFYFU  9999 "NEVER USED" ;
label define IISNFYFU  1 "Questionnaire data" 3 "Statistical Imputation" ;
label define IRCHWAGE  991 "NEVER USED" ;
label define IICHWAGE  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRCHWYFU  9999 "Never Used" ;
label define IICHWYFU  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRSLTAGE  991 "Never Used" ;
label define IISLTAGE  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRSLTYFU  9999 "Never Used" ;
label define IISLTYFU  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRALCAGE  991 "Never Used" ;
label define IIALCAGE  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRALCYFU  9999 "NEVER USED" ;
label define IIALCYFU  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRMJAGE   991 "Never Used" ;
label define IIMJAGE   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRMJYFU   9999 "Never Used" ;
label define IIMJYFU   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRCOCAGE  991 "Never Used" ;
label define IICOCAGE  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRCOCYFU  9999 "Never Used" ;
label define IICOCYFU  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRCRKAGE  991 "Never Used" ;
label define IICRKAGE  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRCRKYFU  9999 "Never Used" ;
label define IICRKYFU  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRHERAGE  991 "Never Used" ;
label define IIHERAGE  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRHERYFU  9999 "Never Used" ;
label define IIHERYFU  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRHALAGE  991 "Never Used" ;
label define IIHALAGE  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRHALYFU  9999 "Never Used" ;
label define IIHALYFU  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRLSDAGE  991 "Never Used" ;
label define IILSDAGE  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRLSDYFU  9999 "NEVER USED" ;
label define IILSDYFU  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRPCPAGE  991 "Never Used" ;
label define IIPCPAGE  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRPCPYFU  9999 "NEVER USED" ;
label define IIPCPYFU  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRECSAGE  991 "Never Used" ;
label define IIECSAGE  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define IRECSYFU  9999 "NEVER USED" ;
label define IIECSYFU  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRINHAGE  991 "Never Used" ;
label define IIINHAGE  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRINHYFU  9999 "Never Used" ;
label define IIINHYFU  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRANLAGE  991 "Never Used" ;
label define IIANLAGE  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define IRANLYFU  9999 "Never Used" ;
label define IIANLYFU  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define IRTRNAGE  991 "Never Used" ;
label define IITRNAGE  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define IRTRNYFU  9999 "Never Used" ;
label define IITRNYFU  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define IRSTMAGE  991 "Never Used" ;
label define IISTMAGE  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define IRSTMYFU  9999 "Never Used" ;
label define IISTMYFU  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define IRMTHAGE  991 "Never Used" ;
label define IIMTHAGE  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define IRMTHYFU  9999 "Never Used" ;
label define IIMTHYFU  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define IRSEDAGE  991 "Never Used" ;
label define IISEDAGE  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define IRSEDYFU  9999 "Never Used" ;
label define IISEDYFU  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define CIGFLAG   0 "Never used (IRCIGRC=9)" 1 "Ever used (IRCIGRC=1-4)" ;
label define CIGMON    0 "Did not use in the past month (IRCIGRC=2-4,9)"
                       1 "Used within the past month (IRCIGRC=1)" ;
label define CIGYR     0 "Did not use in the past year (IRCIGRC=3,4,9)"
                       1 "Used within the past year (IRCIGRC=1,2)" ;
label define CGRFLAG   0 "Never used (IRCGRRC=9)" 1 "Ever used (IRCGRRC=1-4)" ;
label define CGRYR     0 "Did not use in the past year (IRCGRRC=3,4,9)"
                       1 "Used within the past year (IRCGRRC=1,2)" ;
label define CGRMON    0 "Did not use in the past month (IRCGRRC=2-4,9)"
                       1 "Used within the past month (IRCGRRC=1)" ;
label define PIPFLAG   0 "Never Used (IRPIPLF=9)" 1 "Ever Used (IRPIPLF=1)" ;
label define PIPMON    0 "Did not use in the past month (IRPIPMN=2,9)"
                       1 "Used within the past month (IRPIPMN=1)" ;
label define SMKFLAG   0 "Never used (IRSLTRC=9)" 1 "Ever used (IRSLTRC=1-4)" ;
label define SMKYR     0 "Did not use in the past year (IRSLTRC=3,4,9)"
                       1 "Used within the past year (IRSLTRC=1,2)" ;
label define SMKMON    0 "Did not use in the past month (IRSLTRC=2-4,9)"
                       1 "Used within the past month (IRSLTRC=1)" ;
label define CHWFLAG   0 "Never Used (IRCHWRC=9)" 1 "Ever Used (IRCHWRC=1-4)" ;
label define CHWYR     0 "Did not use in the past year (IRCHWRC=3,4,9)"
                       1 "Used within the past year (IRCHWRC=1,2)" ;
label define CHWMON    0 "Did not use in the past month (IRCHWRC=2-4,9)"
                       1 "Used within the past month (IRCHWRC=1)" ;
label define SNFFLAG   0 "Never used (IRSNFRC=9)" 1 "Ever used (IRSNFRC=1-4)" ;
label define SNFYR     0 "Did not use in the past year (IRSNFRC=3,4,9)"
                       1 "Used within the past year (IRSNFRC=1,2)" ;
label define SNFMON    0 "Did not use in the past month (IRSNFRC=2-4,9)"
                       1 "Used within the past month (IRSNFRC=1)" ;
label define TOBFLAG   0 "Never Used (all source vars=9)"
                       1 "Ever Used (any source var=1-4)" ;
label define TOBYR     0 "Never use pst yr(IRPIPMN=2,9 &oth src vars=3,4,9)"
                       1 "Used pst yr(IRPIPMN=1 or any oth src var=1,2)" ;
label define TOBMON    0 "Did not use in pst month (all source vars=2-4,9)"
                       1 "Used in past month (any source var=1)" ;
label define ALCFLAG   0 "Never used (IRALCRC=9)" 1 "Ever used (IRALCRC=1-3)" ;
label define ALCYR     0 "Did not use in the past year (IRALCRC=3,9)"
                       1 "Used within the past year (IRALCRC=1,2)" ;
label define ALCMON    0 "Did not use in the past month (IRALCRC=2-3,9)"
                       1 "Used within the past month (IRALCRC=1)" ;
label define MRJFLAG   0 "Never used (IRMJRC=9)" 1 "Ever used (IRMJRC=1-3)" ;
label define MRJYR     0 "Did not use in the past year (IRMJRC=3,9)"
                       1 "Used within the past year (IRMJRC=1,2)" ;
label define MRJMON    0 "Did not use in the past month (IRMJRC=2-3,9)"
                       1 "Used within the past month (IRMJRC=1)" ;
label define COCFLAG   0 "Never used (IRCOCRC=9)" 1 "Ever used (IRCOCRC=1-3)" ;
label define COCYR     0 "Did not use in the past year (IRCOCRC=3,9)"
                       1 "Used within the past year (IRCOCRC=1,2)" ;
label define COCMON    0 "Did not use in the past month (IRCOCRC=2-3,9)"
                       1 "Used within the past month (IRCOCRC=1)" ;
label define CRKFLAG   0 "Never used (IRCRKRC=9)" 1 "Ever used (IRCRKRC=1-3)" ;
label define CRKYR     0 "Did not use in the past year (IRCRKRC=3,9)"
                       1 "Used within the past year (IRCRKRC=1,2)" ;
label define CRKMON    0 "Did not use in the past month (IRCRKRC=2-3,9)"
                       1 "Used within the past month (IRCRKRC=1)" ;
label define HERFLAG   0 "Never used (IRHERRC=9)" 1 "Ever used (IRHERRC=1-3)" ;
label define HERYR     0 "Did not use in the past year (IRHERRC=3,9)"
                       1 "Used within the past year (IRHERRC=1,2)" ;
label define HERMON    0 "Did not use in the past month (IRHERRC=2-3,9)"
                       1 "Used within the past month (IRHERRC=1)" ;
label define HALFLAG   0 "Never used (IRHALRC=9)" 1 "Ever used (IRHALRC=1-3)" ;
label define HALYR     0 "Did not use in the past year (IRHALRC=3,9)"
                       1 "Used within the past year (IRHALRC=1,2)" ;
label define HALMON    0 "Did not use in the past month (IRHALRC=2-3,9)"
                       1 "Used within the past month (IRHALRC=1)" ;
label define LSDFLAG   0 "Never used (IRLSDRC=9)" 1 "Ever used (IRLSDRC=1-3)" ;
label define LSDYR     0 "Did not use in the past year (IRLSDRC=3,9)"
                       1 "Used within the past year (IRLSDRC=1,2)" ;
label define LSDMON    0 "Did not use in the past month (IRLSDRC=2-3,9)"
                       1 "Used within the past month (IRLSDRC=1)" ;
label define PCPFLAG   0 "Never used (IRPCPRC=9)" 1 "Ever used (IRPCPRC=1-3)" ;
label define PCPYR     0 "Did not use in the past year (IRPCPRC=3,9)"
                       1 "Used within the past year (IRPCPRC=1,2)" ;
label define PCPMON    0 "Did not use in the past month (IRPCPRC=2-3,9)"
                       1 "Used within the past month (IRPCPRC=1)" ;
label define ECSFLAG   0 "Never used (IRECSRC=9)" 1 "Ever used (IRECSRC=1-3)" ;
label define ECSYR     0 "Did not use in the past year (IRECSRC=3,9)"
                       1 "Used within the past year (IRECSRC=1,2)" ;
label define ECSMON    0 "Did not use in the past month (IRECSRC=2-3,9)"
                       1 "Used within the past month (IRECSRC=1)" ;
label define INHFLAG   0 "Never used (IRINHRC=9)" 1 "Ever used (IRINHRC=1-3)" ;
label define INHYR     0 "Did not use in the past year (IRINHRC=3,9)"
                       1 "Used within the past year (IRINHRC=1,2)" ;
label define INHMON    0 "Did not use in the past month (IRINHRC=2-3,9)"
                       1 "Used within the past month (IRINHRC=1)" ;
label define ANLFLAG   0 "Never used (IRANLRC=9)" 1 "Ever used (IRANLRC=1-3)" ;
label define ANLYR     0 "Did not use in the past year (IRANLRC=3,9)"
                       1 "Used within the past year (IRANLRC=1,2)" ;
label define ANLMON    0 "Did not use in the past month (IRANLRC=2-3,9)"
                       1 "Used within the past month (IRANLRC=1)" ;
label define TRQFLAG   0 "Never used (IRTRNRC=9)" 1 "Ever used (IRTRNRC=1-3)" ;
label define TRQYR     0 "Did not use in the past year (IRTRNRC=3,9)"
                       1 "Used within the past year (IRTRNRC=1,2)" ;
label define TRQMON    0 "Did not use in the past month (IRTRNRC=2-3,9)"
                       1 "Used within the past month (IRTRNRC=1)" ;
label define STMFLAG   0 "Never used (IRSTMRC=9)" 1 "Ever used (IRSTMRC=1-3)" ;
label define STMYR     0 "Did not use in the past year (IRSTMRC=3,9)"
                       1 "Used within the past year (IRSTMRC=1,2)" ;
label define STMMON    0 "Did not use in the past month (IRSTMRC=2-3,9)"
                       1 "Used within the past month (IRSTMRC=1)" ;
label define MTHFLAG   0 "Never Used (IRMTHRC=9)" 1 "Ever Used (IRMTHRC=1-3)" ;
label define MTHYR     0 "Did not use in the past year (IRMTHRC=3,9)"
                       1 "Used within the past year (IRMTHRC=1,2)" ;
label define MTHMON    0 "Did not use in the past month (IRMTHRC=2-3,9)"
                       1 "Used within the past month (IRMTHRC=1)" ;
label define SEDFLAG   0 "Never used (IRSEDRC=9)" 1 "Ever used (IRSEDRC=1-3)" ;
label define SEDYR     0 "Did not use in the past year (IRSEDRC=3,9)"
                       1 "Used within the past year (IRSEDRC=1,2)" ;
label define SEDMON    0 "Did not use in the past month (IRSEDRC=2-3,9)"
                       1 "Used within the past month (IRSEDRC=1)" ;
label define PSYFLAG2  0 "Never used (ALL SOURCE VARIABLES=9)"
                       1 "Ever used (ANY SOURCE VARIABLE<9)" ;
label define PSYYR2    0 "Did not use within past year (ALL SOURCE VARS>2)"
                       1 "Used in past year (ANY SOURCE VARIABLE<3)" ;
label define PSYMON2   0 "Did not use in past month (ALL SOURCE VARS>1)"
                       1 "Used in past month (ANY SOURCE VARIABLE=1)" ;
label define SUMFLAG   0 "Never used (ALL SOURCE VARIABLES=0)"
                       1 "Ever used (ANY SOURCE VARIABLE=1)" ;
label define SUMYR     0 "Did not use in past year (ALL SOURCE VARS=0)"
                       1 "Used in past year (ANY SOURCE VARIABLE=1)" ;
label define SUMMON    0 "Did not use in past month (ALL SOURCE VARS=0)"
                       1 "Used in past month (ANY SOURCE VARIABLE=1)" ;
label define MJOFLAG   0 "Never used MJ/has used both MJ & anothr illct drug"
                       1 "Marijuana is only (illicit) drug ever used" ;
label define MJOYR2    0 "MJ not used past yr/Used MJ & othr drug past yr"
                       1 "Marijuana is only (illicit) drug in past year" ;
label define MJOMON2   0 "MJ not used past mnth/Used MJ & othr drug past mo"
                       1 "Marijuana only (illicit) drug in past month" ;
label define IEMFLAG   0 "Never used drug/used only marijuana"
                       1 "Illicit drug except for marijuana are ever used" ;
label define IEMYR     0 "Never used drug/used only marijuana past year"
                       1 "Illicit drug except for marijuana used past year" ;
label define IEMMON    0 "Never used drug/used only marijuana past month"
                       1 "Illicit drug except for marijuana used past month" ;
label define BINGEDRK  0 "Never/No 'Binge' alcohol use (IRALCD5=0)"
                       1 "'Binge' alcohol use (IRALCD5=1-30)" ;
label define HVYDRK2   0 "Never/No heavy alcohol use (IRALCD5=0-4)"
                       1 "Heavy alcohol use (IRALCD5=5-30)" ;
label define BINGEHVY  1 "Heavy Alcohol Use (HVYDRK2=1)"
                       2 "'Binge' But Not Heavy Use (BINGEDRK=1 & HVYDRK2=0)"
                       3 "Past Month But Not 'Binge' (ALCMON=1 & BINGEDRK=0)"
                       4 "Did Not Use Alcohol in Pst Month (All source=0)" ;
label define PEYOTE2   0 "No/Unknown (PEYOTE=2,91,94,97)" 1 "Yes (PEYOTE=1)" ;
label define MESC2     0 "No/Unknown (MESC=2,91,94,97)" 1 "Yes (MESC=1,3)" ;
label define PSILCY2   0 "No/Unknown (PSILCY=2,91,94,97)"
                       1 "Yes (PSILCY=1,3)" ;
label define ECSTASY2  0 "No/Unknown (ECSTASY=2,91,94,97)"
                       1 "Yes (ECSTASY=1,3)" ;
label define AMYLNIT2  0 "No/Unknown (AMYLNIT=2,85,91,94,97)"
                       1 "Yes (AMYLNIT=1,3)" ;
label define CLEFLU2   0 "No/Unknown (CLEFLU=2,85,91,94,97)"
                       1 "Yes (CLEFLU=1,3)" ;
label define GAS2      0 "No/Unknown (GAS=2,85,91,94,97)" 1 "Yes (GAS=1,3)" ;
label define GLUE2     0 "No/Unknown (GLUE=2,85,91,94,97)" 1 "Yes (GLUE=1,3)" ;
label define ETHER2    0 "No/Unknown (ETHER=2,85,91,94,97)"
                       1 "Yes (ETHER=1,3)" ;
label define SOLVENT2  0 "No/Unknown (SOLVENT=2,85,91,94,97)"
                       1 "Yes (SOLVENT=1)" ;
label define LGAS2     0 "No/Unknown (LGAS=2,85,91,94,97)" 1 "Yes (LGAS=1)" ;
label define NITOXID2  0 "No/Unknown (NITOXID=2,85,91,94,97,98)"
                       1 "Yes (NITOXID=1,3)" ;
label define SPPAINT2  0 "No/Unknown (SPPAINT=2,85,91,94,97,98)"
                       1 "Yes (SPPAINT=1)" ;
label define AEROS2    0 "No/Unknown (AEROS=2,85,91,94,97,98)"
                       1 "Yes (AEROS=1,3)" ;
label define DARVTYL2  0 "No/Unknown (DARVTYLC=2,81,85,91,94,97,98)"
                       1 "Yes (DARVTYLC=1,3)" ;
label define PERCTYL2  0 "No/Unknown (PERCTYLX=2,81,85,91,94,97,98)"
                       1 "Yes (PERCTYLX=1,3)" ;
label define VICOLOR2  0 "No/Unknown (VICOLOR=2,81,85,91,94,97,98)"
                       1 "Yes (VICOLOR=1,3)" ;
label define CODEINE2  0 "No/Unknown (CODEINE=6,81,91,94,97,98,99)"
                       1 "Yes (CODEINE=1,3)" ;
label define DEMEROL2  0 "No/Unknown (DEMEROL=6,81,91,94,97,98,99)"
                       1 "Yes (DEMEROL=1,3)" ;
label define DILAUD2   0 "No/Unknown (DILAUD=6,81,91,94,97,98,99)"
                       1 "Yes (DILAUD=1,3)" ;
label define FIORICT2  0 "No/Unknown (FIORICET=6,81,91,94,97,98,99)"
                       1 "Yes (FIORICET=1)" ;
label define FIORINL2  0 "No/Unknown (FIORINAL=6,81,91,94,97,98,99)"
                       1 "Yes (FIORINAL=1,3)" ;
label define HYDROCD2  0 "No/Unknown (HYDROCOD=6,81,91,94,97,98,99)"
                       1 "Yes (HYDROCOD=1,3)" ;
label define METHDON2  0 "No/Unknown (METHDON=6,81,85,91,94,97,98,99)"
                       1 "Yes (METHDON=1,3)" ;
label define MORPHIN2  0 "No/Unknown (MORPHINE=6,81,91,94,97,98,99)"
                       1 "Yes (MORPHINE=1,3)" ;
label define OXYCONT2  0 "No/Unknown (OXYCONTN=6,81,91,94,97,98,99)"
                       1 "Yes (OXYCONTN=1,3)" ;
label define PHENCOD2  0 "No/Unknown (PHENCOD=6,81,91,94,97,98,99)"
                       1 "Yes (PHENCOD=1,3)" ;
label define PROPOXY2  0 "No/Unknown (PROPOXY=6,81,91,94,97,98,99)"
                       1 "Yes (PROPOXY=1)" ;
label define SK65A2    0 "No/Unknown (SK65A=6,81,91,94,97,98,99)"
                       1 "Yes (SK65A=1)" ;
label define STADOL2   0 "No/Unknown (STADOL=6,81,91,94,97,98,99)"
                       1 "Yes (STADOL=1)" ;
label define TALACEN2  0 "No/Unknown (TALACEN=6,81,91,94,97,98,99)"
                       1 "Yes (TALACEN=1,3)" ;
label define TALWIN2   0 "No/Unknown (TALWIN=6,81,91,94,97,98,99)"
                       1 "Yes (TALWIN=1,3)" ;
label define TALWINX2  0 "No/Unknown (TALWINNX=6,81,91,94,97,98,99)"
                       1 "Yes (TALWINNX=1)" ;
label define TRAMADL2  0 "No/Unknown (TRAMADOL=6,81,91,94,97,98,99)"
                       1 "Yes (TRAMADOL=1)" ;
label define ULTRAM2   0 "No/Unknown (ULTRAM=6,81,91,94,97,98,99)"
                       1 "Yes (ULTRAM=1,3)" ;
label define OTHANL    0 "No/Unknwn (ANLCARD/ANLNOLST=2,4,81,85,91,94,97,98)"
                       1 "Yes (ANLCARD or ANLNOLST=1,3)" ;
label define KLONOPI2  0 "No/Unknown (KLONOPIN=2,81,85,91,94,97,98)"
                       1 "Yes (KLONOPIN=1)" ;
label define XNAXATV2  0 "No/Unknown (XNAXATVN=2,81,85,91,94,97,98)"
                       1 "Yes (XNAXATVN=1,3)" ;
label define VALMDIA2  0 "No/Unknown (VALMDIAZ=2,81,85,91,94,97,98)"
                       1 "Yes (VALMDIAZ=1,3)" ;
label define ATARAX2   0 "No/Unknown (ATARAX=6,81,85,91,94,97,98,99)"
                       1 "Yes (ATARAX=1,3)" ;
label define BUSPAR2   0 "No/Unknown (BUSPAR=6,81,91,94,97,98,99)"
                       1 "Yes (BUSPAR=1)" ;
label define EQUANIL2  0 "No/Unknown (EQUANIL=6,81,91,94,97,98,99)"
                       1 "Yes (EQUANIL=1)" ;
label define FLEXERL2  0 "No/Unknown (FLEXERIL=6,81,91,94,97,98,99)"
                       1 "Yes (FLEXERIL=1,3)" ;
label define LIBRIUM2  0 "No/Unknown (LIBRIUM=6,81,91,94,97,98,99)"
                       1 "Yes (LIBRIUM=1)" ;
label define LIMBTRL2  0 "No/Unknown (LIMBTROL=6,81,91,94,97,98,99)"
                       1 "Yes (LIMBTROL=1)" ;
label define MEPROB2   0 "No/Unknown (MEPROB=6,81,91,94,97,98,99)"
                       1 "Yes (MEPROB=1,3)" ;
label define MILTOWN2  0 "No/Unknown (MILTOWN=6,81,91,94,97,98,99)"
                       1 "Yes (MILTOWN=1,3)" ;
label define ROHYPNL2  0 "No/Unknown (ROHYPNOL=6,81,91,94,97,98,99)"
                       1 "Yes (ROHYPNOL=1,3)" ;
label define SERAX2    0 "No/Unknown (SERAX=6,81,85,91,94,97,98,99)"
                       1 "Yes (SERAX=1)" ;
label define SOMA2     0 "No/Unknown (SOMA=6,81,91,94,97,98,99)"
                       1 "Yes (SOMA=1,3)" ;
label define TRANXEN2  0 "No/Unknown (TRANXENE=6,81,91,94,97,98,99)"
                       1 "Yes (TRANXENE=1)" ;
label define VISTAR2   0 "No/Unknown (VISTAR=6,81,91,94,97,98,99)"
                       1 "Yes (VISTAR=1)" ;
label define OTHTRN    0 "No/Unknwn (TRNCARD/TRNOLST=2,4,81,85,91,94,97,98)"
                       1 "Yes (TRNCARD or TRNOLST=1,3)" ;
label define METHDES2  0 "No/Unknown (METHDES=2,81,85,91,94,97,98)"
                       1 "Yes (METHDES=1,3)" ;
label define DIETPIL2  0 "No/Unknown (DIETPILS=2,81,85,91,94,97,98)"
                       1 "Yes (DIETPILS=1,3)" ;
label define RITMPHE2  0 "No/Unknown (RITMPHEN=2,81,85,91,94,97,98)"
                       1 "Yes (RITMPHEN=1)" ;
label define CYLERT2   0 "No/Unknown (CYLERT=6,81,91,94,97,98,99)"
                       1 "Yes (CYLERT=1)" ;
label define DEXED2    0 "No/Unknown (DEXED=6,81,91,94,97,98,99)"
                       1 "Yes (DEXED=1,3)" ;
label define DETAMP2   0 "No/Unknown (DETAMP=6,81,91,94,97,98,99)"
                       1 "Yes (DETAMP=1)" ;
label define DIDREX2   0 "No/Unknown (DIDREX=6,81,91,94,97,98,99)"
                       1 "Yes (DIDREX=1)" ;
label define ESKAT2    0 "No/Unknown (ESKAT=6,81,91,94,97,98,99)"
                       1 "Yes (ESKAT=1)" ;
label define IONAMIN2  0 "No/Unknown (IONAMIN=6,81,91,94,97,98,99)"
                       1 "Yes (IONAMIN=1,3)" ;
label define MAZANOR2  0 "No/Unknown (MAZANOR=6,81,91,94,97,98,99)"
                       1 "Yes (MAZANOR=1)" ;
label define OBLA2     0 "No/Unknown (OBLA=6,81,91,94,97,98,99)"
                       1 "Yes (OBLA=1)" ;
label define PLEGINE2  0 "No/Unknown (PLEGINE=6,81,85,91,94,97,98,99)"
                       1 "Yes (PLEGINE=1)" ;
label define PRELUDN2  0 "No/Unknown (PRELUDIN=6,81,91,94,97,98,99)"
                       1 "Yes (PRELUDIN=1)" ;
label define SANOREX2  0 "No/Unknown (SANOREX=6,81,91,94,97,98,99)"
                       1 "Yes (SANOREX=1)" ;
label define TENUATE2  0 "No/Unknown (TENUATE=6,81,91,94,97,98,99)"
                       1 "Yes (TENUATE=1,3)" ;
label define OTHSTM    0 "No/Unknwn (STMCARD/STMNOLST=2,4,81,85,91,94,97,98)"
                       1 "Yes (STMCARD or STMNOLST=1,3)" ;
label define METHAQ2   0 "No/Unknown (METHAQ=2,81,85,91,94,97,98)"
                       1 "Yes (METHAQ=1,3)" ;
label define NEMBBAR2  0 "No/Unknown (NEMBBARB=2,81,85,91,94,97,98)"
                       1 "Yes (NEMBBARB=1,3)" ;
label define RESTTMA2  0 "No/Unknown (RESTTMAZ=2,81,85,91,94,97,98)"
                       1 "Yes (RESTTMAZ=1)" ;
label define AMYTAL2   0 "No/Unknown (AMYTAL=6,81,91,94,97,98,99)"
                       1 "Yes (AMYTAL=1)" ;
label define BUTISOL2  0 "No/Unknown (BUTISOL=6,81,91,94,97,98,99)"
                       1 "Yes (BUTISOL=1)" ;
label define CHHYD2    0 "No/Unknown (CHHYD=6,81,91,94,97,98,99)"
                       1 "Yes (CHHYD=1)" ;
label define DALMANE2  0 "No/Unknown (DALMANE=6,81,91,94,97,98,99)"
                       1 "Yes (DALMANE=1)" ;
label define HALCION2  0 "No/Unknown (HALCION=6,81,91,94,97,98,99)"
                       1 "Yes (HALCION=1,3)" ;
label define PHENOBR2  0 "No/Unknown (PHENOBAR=6,81,91,94,97,98,99)"
                       1 "Yes (PHENOBAR=1,3)" ;
label define PLACIDY2  0 "No/Unknown (PLACIDYL=6,81,91,94,97,98,99)"
                       1 "Yes (PLACIDYL=1)" ;
label define TUINAL2   0 "No/Unknown (TUINAL=6,81,85,91,94,97,98,99)"
                       1 "Yes (TUINAL=1,3)" ;
label define OTHSED    0 "No/Unknwn (SEDCARD/SEDNOLST=2,4,81,85,91,94,97,98)"
                       1 "Yes (SEDCARD or SEDNOLST=1,3)" ;
label define CIGBRND3  -9 "Not Past Month Cigarette User (CIGMON=0)"
                       1 "Marlboro (CIG30BR2=112)" 2 "Newport (CIG30BR2=118)"
                       3 "Camel (CIG30BR2=104)" 4 "Basic (CIG30BR2=101)"
                       5 "Doral (CIG30BR2=107)" 6 "Winston (CIG30BR2=126)"
                       7 "Kool (CIG30BR2=111)" 8 "GPC (CIG30BR2=109)"
                       9 "Salem (CIG30BR2=122)"
                       10 "Virginia Slims (CIG30BR2=125)"
                       11 "Benson & Hedges (CIG30BR2=102)"
                       12 "Merit (CIG30BR2=113)"
                       13 "Parliament (CIG30BR2=120)"
                       14 "Capri (CIG30BR2=105)"
                       15 "Pall Mall (CIG30BR2=119)"
                       16 "Misty (CIG30BR2=114)"
                       17 "Other Brnd (CIG30BR2=other 100-199,1001-1999)"
                       18 "Unkwn Brnd (CIG30BR2=200-999,2999-5999,9000-9998)" ;
label define CGRBRND3  -9 "Not Past Month Cigar User (CGRMON=0)"
                       1 "Black and Mild (CGR30BR2=404)"
                       2 "Swisher Sweets (CGR30BR2=423)"
                       3 "Macanudos (CGR30BR2=416)"
                       4 "Phillies (CGR30BR2=419)"
                       5 "Backwoods (CGR30BR2=402)"
                       6 "Garcia Y Vega (CGR30BR2=411)"
                       7 "Dutch Masters (CGR30BR2=408)"
                       8 "Cohiba (CGR30BR2=443)" 9 "Partagas (CGR30BR2=418)"
                       10 "White Owl (CGR30BR2=426)"
                       11 "Cuban (brand unspecified) (CGR30BR2=448)"
                       12 "Havatampa (CGR30BR2=412)"
                       13 "Muriel (CGR30BR2=417)"
                       14 "King Edward (CGR30BR2=413)"
                       15 "Antonio Y Cleopatra (CGR30BR2=401)"
                       16 "Other Brnd (CGR30BR2=other 400-499,4000-4999)"
                       17 "Unkwn Brnd (CGR30BR2=<399,501-5999,9000-9998)" ;
label define SMKBRND3  -9 "Not Past Month Smokeless Tobacco User (SMKMON=0)"
                       1 "Copenhagen (SLT30BR2=301)" 2 "Skoal (SLT30BR2=308)"
                       3 "Kodiak (SLT30BR2=305)" 4 "Red Man (SLT30BR2=208)"
                       5 "Levi Garrett (SLT30BR2=206)"
                       6 "Timber Wolf (SLT30BR2=309)"
                       7 "Beech Nut (SLT30BR2=201)"
                       8 "Red Seal (SLT30BR2=316)"
                       9 "Chattanooga Chew (SLT30BR2=202)"
                       10 "Other Brand (SLT30BR2=other 200-399,2999-3999)"
                       11 "Unkwn Brnd (SLT30BR2=<200,400-5999,9000-9998)" ;
label define CIGCMPNY  1 "Philip Morris" 2 "R.J. Reynolds" 3 "Lorillard"
                       4 "Brown and Williamson" 5 "Liggett"
                       6 "Commonwealth Brands"
                       7 "Santa Fe Natural Tobacco Company"
                       8 "Forsyth Tobacco Co (a division of R.J. Reynolds)"
                       70 "SOME OTHER BRAND/COMPANY"
                       80 "CIG BRAND/COMPANY NOT SPECIFIED"
                       85 "BAD DATA Log assn (CIG30BR2=9985)"
                       90 "NOT A CIGARETTE BRAND" 91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN THE PAST 30 DAYS"
                       94 "DON'T KNOW (CIG30BR2=9994)"
                       97 "REFUSED (CIG30BR2=9997)"
                       98 "BLANK (CIG30BR2=9998)" ;
label define ALCAFU    1 "14 Years or Younger (IRALCAGE=1-14)"
                       2 "15-17 Years Old (IRALCAGE=15-17)"
                       3 "18 Years or Older (IRALCAGE=18+)"
                       4 "Non Users (IRALCAGE=991)" ;
label define MJAFU     1 "14 Years or Younger (IRMJAGE=1-14)"
                       2 "15-17 Years Old (IRMJAGE=15-17)"
                       3 "18 Years or Older (IRMJAGE=18+)"
                       4 "Non Users (IRMJAGE=991)" ;
label define COCAFU    1 "14 Years or Younger (IRCOCAGE=1-14)"
                       2 "15-17 Years Old (IRCOCAGE=15-17)"
                       3 "18 Years or Older (IRCOCAGE=18+)"
                       4 "Non Users (IRCOCAGE=991)" ;
label define HERAFU    1 "14 Years or Younger (IRHERAGE=1-14)"
                       2 "15-17 Years Old (IRHERAGE=15-17)"
                       3 "18 Years or Older (IRHERAGE=18+)"
                       4 "Non Users (IRHERAGE=991)" ;
label define HALAFU    1 "14 Years or Younger (IRHALAGE=1-14)"
                       2 "15-17 Years Old (IRHALAGE=15-17)"
                       3 "18 Years or Older (IRHALAGE=18+)"
                       4 "Non Users (IRHALAGE=991)" ;
label define INHAFU    1 "14 Years or Younger (IRINHAGE=1-14)"
                       2 "15-17 Years Old (IRINHAGE=15-17)"
                       3 "18 Years or Older (IRINHAGE=18+)"
                       4 "Non Users (IRINHAGE=991)" ;
label define ANLAFU    1 "14 Years or Younger (IRANLAGE=1-14)"
                       2 "15-17 Years Old (IRANLAGE=15-17)"
                       3 "18 Years or Older (IRANLAGE=18+)"
                       4 "Non Users (IRANLAGE=991)" ;
label define TRNAFU    1 "14 Years or Younger (IRTRNAGE=1-14)"
                       2 "15-17 Years Old (IRTRNAGE=15-17)"
                       3 "18 Years or Older (IRTRNAGE=18+)"
                       4 "Non Users (IRTRNAGE=991)" ;
label define STMAFU    1 "14 Years or Younger (IRSTMAGE=1-14)"
                       2 "15-17 Years Old (IRSTMAGE=15-17)"
                       3 "18 Years or Older (IRSTMAGE=18+)"
                       4 "Non Users (IRSTMAGE=991)" ;
label define SEDAFU    1 "14 Years or Younger (IRSEDAGE=1-14)"
                       2 "15-17 Years Old (IRSEDAGE=15-17)"
                       3 "18 Years or Older (IRSEDAGE=18+)"
                       4 "Non Users (IRSEDAGE=991)" ;
label define CIGAFU    1 "14 Years or Younger (IRCIGAGE=1-14)"
                       2 "15-17 Years Old (IRCIGAGE=15-17)"
                       3 "18 Years or Older (IRCIGAGE=18+)"
                       4 "Non Users (IRCIGAGE=991)" ;
label define CGRAFU    1 "14 Years or Younger (IRCGRAGE=1-14)"
                       2 "15-17 Years Old (IRCGRAGE=15-17)"
                       3 "18 Years or Older (IRCGRAGE=18+)"
                       4 "Non Users (IRCGRAGE=991)" ;
label define SLTAFU    1 "14 Years or Younger (IRSLTAGE=1-14)"
                       2 "15-17 Years Old (IRSLTAGE=15-17)"
                       3 "18 Years or Older (IRSLTAGE=18+)"
                       4 "Non Users (IRSLTAGE=991)" ;
label define CG05      1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CG06      1 "More than 30 days ago but within the past 12 mos"
                       2 "More than 12 months ago but within the past 3 yrs"
                       3 "More than 3 years ago" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CG06DK    1 "More than 30 days ago but within the past 12 mos"
                       2 "More than 12 months ago but within the past 3 yrs"
                       3 "More than 3 years ago" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CG06RE    1 "More than 30 days ago but within the past 12 mos"
                       2 "More than 12 months ago but within the past 3 yrs"
                       3 "More than 3 years ago" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CG27      1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CG28      1 "More than 30 days ago but within the past 12 mos"
                       2 "More than 12 months ago but within the past 3 yrs"
                       3 "More than 3 years ago" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CG28DK    1 "More than 30 days ago but within the past 12 mos"
                       2 "More than 12 months ago but within the past 3 yrs"
                       3 "More than 3 years ago" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CG28RE    94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CG19      1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CG20      1 "More than 30 days ago but within the past 12 mos"
                       2 "More than 12 months ago but within the past 3 yrs"
                       3 "More than 3 years ago" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CG20DK    1 "More than 30 days ago but within the past 12 mos"
                       2 "More than 12 months ago but within the past 3 yrs"
                       3 "More than 3 years ago" 94 "DON'T KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define CG20RE    2 "More than 12 months ago but within the past 3 yrs"
                       3 "More than 3 years ago" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CG36      1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CG37      1 "More than 30 days ago but within the past 12 mos"
                       2 "More than 12 months ago but within the past 3 yrs"
                       3 "More than 3 years ago" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CG37DK    1 "More than 30 days ago but within the past 12 mos"
                       2 "More than 12 months ago but within the past 3 yrs"
                       3 "More than 3 years ago" 94 "DON'T KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define CG37RE    1 "More than 30 days ago but within the past 12 mos"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CG43      1 "Yes" 2 "No" 98 "BLANK (NO ANSWER)" ;
label define ALLAST3   1 "Within the past 30 days -- that is, since DATEFILL"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ALRECDK   1 "Within the past 30 days --that is, since DATEFILL"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ALRECRE   1 "Within the past 30 days -- that is, since DATEFILL"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TOTDRINK  994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define ALFRAME3  1 "Avg num of days per week during pst 12 mos"
                       2 "Avg num of days per month during pst 12 mos"
                       3 "Total number of days during the past 12 months"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ALYRAVE   994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define ALMONAVE  94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ALWKAVE   94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MJLAST3   1 "Within the past 30 days -- that is, since DATEFILL"
                       2 "More than 30 days ago but within the past 12 month"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MJRECDK   1 "Within the past 30 days -- that is, since DATEFILL"
                       2 "More than 30 days ago but within the pst 12 mos"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MJRECRE   1 "Within the past 30 days -- that is, since DATEFILL"
                       2 "More than 30 days ago but within the pst 12 mos"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TOTMJ     994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define MJFRAME3  1 "Avg num of days per week during pst 12 mos"
                       2 "Avg num of days per month during pst 12 mos"
                       3 "Total number of days during the past 12 months"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MJYRAVE   994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define MJMONAVE  94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MJWKAVE   94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CCLAST3   1 "Within the past 30 days -- that is, since DATEFILL"
                       2 "More than 30 days ago but within the past 12 month"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CCRECDK   2 "More than 30 days ago but within the pst 12 mos"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CCRECRE   1 "Within the past 30 days -- that is, since DATEFILL"
                       2 "More than 30 days ago but within the pst 12 mos"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TOTCOKE   994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define CCFRAME3  1 "Avg num of days per week during pst 12 mos"
                       2 "Avg num of days per month during pst 12 mos"
                       3 "Total number of days during the past 12 months"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CCYRAVE   994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define CCMONAVE  94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CCWKAVE   94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CKLAST3   1 "Within the past 30 days -- that is, since DATEFILL"
                       2 "More than 30 days ago but within the past 12 month"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CKRECDK   2 "More than 30 days ago but within the pst 12 mos"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define CKRECRE   3 "More than 12 months ago" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TOTCRACK  994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define CKFRAME3  1 "Avg num of days per week during pst 12 mos"
                       2 "Avg num of days per month during pst 12 mos"
                       3 "Total number of days during the past 12 months"
                       94 "DON'T KNOW" 98 "BLANK (NO ANSWER)" ;
label define CKYRAVE   994 "DON'T KNOW" 998 "BLANK (NO ANSWER)" ;
label define CKMONAVE  94 "DON'T KNOW" 98 "BLANK (NO ANSWER)" ;
label define CKWKAVE   94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HELAST3   1 "Within the past 30 days -- that is, since DATEFILL"
                       2 "More than 30 days ago but within the past 12 month"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HERECDK   3 "More than 12 months ago" 94 "DON'T KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define HERECRE   97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TOTHERO   997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define HEFRAME3  1 "Avg num of days per week during pst 12 mos"
                       2 "Avg num of days per month during pst 12 mos"
                       3 "Total number of days during the past 12 months"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HEYRAVE   998 "BLANK (NO ANSWER)" ;
label define HEMONAVE  97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HEWKAVE   97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LSLAST    1 "Within the past 30 days -- that is, since DATEFILL"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LSRECDK   1 "Within the past 30 days -- that is, since DATEFILL"
                       2 "More than 30 days ago but within the pst 12 mos"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LSRECRE   2 "More than 30 days ago but within the pst 12 mos"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TOTHALL   994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define LSFRAME3  1 "Avg num of days per week during pst 12 mos"
                       2 "Avg num of days per month during pst 12 mos"
                       3 "Total number of days during the past 12 months"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LSYRAVE   994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define LSMONAVE  94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LSWKAVE   94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LS10      1 "Within the past 30 days -- that is, since DATEFILL"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LS16      1 "Within the past 30 days -- that is, since DATEFILL"
                       2 "More than 30 days ago but within the pst 12 mos"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LS22      1 "Within the past 30 days -- that is, since DATEFILL"
                       2 "More than 30 days ago but within the pst 12 mos"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define INLAST    1 "Within the past 30 days -- that is, since DATEFILL"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define INRECDK   1 "Within the past 30 days -- that is, since DATEFILL"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define INRECRE   1 "Within the past 30 days -- that is, since DATEFILL"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TOTINHAL  994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define INFRAME3  1 "Avg num of days per week during pst 12 mos"
                       2 "Avg num of days per month during pst 12 mos"
                       3 "Total number of days during the past 12 months"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define INYRAVE   994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define INMONAVE  94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define INWKAVE   94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PR09      1 "Within the past 30 days -- that is, since DATEFILL"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PRRECDK   1 "Within the past 30 days -- that is, since DATEFILL"
                       2 "More than 30 days ago but within the past 12 month"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PRRECRE   1 "Within the past 30 days -- that is, since DATEFILL"
                       2 "More than 30 days ago but within the past 12 month"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PR10      1 "Avg num of days per week during pst 12 mos"
                       2 "Avg num of days per month during pst 12 mos"
                       3 "Total number of days during the past 12 months"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PR11      994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define PR12      94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PR13      94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TR09      1 "Within the past 30 days -- that is, since DATEFILL"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRRECDK   1 "Within the past 30 days -- that is, since DATEFILL"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRRECRE   1 "Within the past 30 days -- that is, since DATEFILL"
                       3 "More than 12 months ago" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TR10      1 "Avg num of days per week during pst 12 mos"
                       2 "Avg num of days per month during pst 12 mos"
                       3 "Total number of days during the past 12 months"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TR11      994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define TR12      94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TR13      94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ST09      1 "Within the past 30 days -- that is, since DATEFILL"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STRECDK   1 "Within the past 30 days -- that is, since DATEFILL"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STRECRE   2 "More than 30 days ago but within the past 12 mos"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ST10      1 "Avg num of days per week during pst 12 mos"
                       2 "Avg num of days per month during pst 12 mos"
                       3 "Total number of days during the past 12 months"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ST11      994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define ST12      94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ST13      94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ST19      1 "Within the past 30 days - that is, since DATEFILL"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ST20      1 "Avg num of days per week during pst 12 mos"
                       2 "Avg num of days per month during pst 12 mos"
                       3 "Total number of days during the past 12 months"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ST21      994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define ST22      94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ST23      94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SV09      1 "Within the past 30 days -- that is, since DATEFILL"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SVRECDK   3 "More than 12 months ago" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SVRECRE   94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SV10      1 "Avg num of days per week during pst 12 mos"
                       2 "Avg num of days per month during pst 12 mos"
                       3 "Total number of days during the past 12 months"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SV11      994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define SV12      94 "DON'T KNOW" 98 "BLANK (NO ANSWER)" ;
label define SV13      94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HERSMOKE  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       91 "NEVER USED HEROIN" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HRSMKREC  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       9 "At some point in the lifetime LOG ASSN"
                       13 "More than 12 months ago LOGICALLY ASSIGNED"
                       91 "NEVER USED HEROIN"
                       93 "USED HEROIN BUT NEVER SMOKED IT" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HERSNIFF  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       91 "NEVER USED HEROIN" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HRSNFREC  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       9 "At some point in the lifetime LOG ASSN"
                       13 "More than 12 months ago LOGICALLY ASSIGNED"
                       91 "NEVER USED HEROIN"
                       93 "USED HEROIN BUT NEVER SNIFFED IT" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HERNEEDL  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       91 "NEVER USED HEROIN" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HEOTSMK   1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 91 "NEVER USED HEROIN"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HEOTSNF   1 "Response entered" 6 "Response not entered"
                       91 "NEVER USED HEROIN" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HEOTNDL   1 "Response entered" 6 "Response not entered"
                       91 "NEVER USED HEROIN" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HEOTOTH   1 "Response entered" 6 "Response not entered"
                       91 "NEVER USED HEROIN" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HEOTSP    1 "You smoked heroin"
                       5 "You took it orally/by mouth/in pill form"
                       6 "You sniffed or 'snorted' heroin in liquid form"
                       10 "You combined it w/ecstasy (no other drug mentiond)"
                       11 "You combined it w/ecstasy and marijuana"
                       12 "You combined it w/ecstasy and cocaine"
                       13 "You combined it w/marijuana (no oth drug mentiond)"
                       14 "You combined w/a hallucinogen, not otherwise spcfd"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HRNDLREC  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       9 "At some point in the lifetime LOG ASSN"
                       13 "More than 12 months ago LOGICALLY ASSIGNED"
                       91 "NEVER USED HEROIN"
                       93 "USED HEROIN BUT NEVER WITH A NEEDLE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define MTHNEEDL  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       81 "NEVER USED METHAMPHETAMINES Log assn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED METHAMPHETAMINES" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MTNDLREC  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       9 "At some point in the lifetime LOG ASSN"
                       13 "More than 12 months ago LOGICALLY ASSIGNED"
                       81 "NEVER USED METHAMPHET Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED METHAMPHETAMINE"
                       93 "USED METHAMPH BUT NEVER WITH A NEEDLE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define OSTNEEDL  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Log assn"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED STIMULANTS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define OSTNLREC  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       9 "At some point in the lifetime LOG ASSN"
                       13 "More than 12 months ago LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANT Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED STIMULANT"
                       93 "USED STIM/OTHR STIMULANT BUT NEVER WITH A NEEDLE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define COCNEEDL  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       91 "NEVER USED COCAINE" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CONDLREC  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       9 "At some point in the lifetime LOG ASSN"
                       13 "More than 12 months ago LOGICALLY ASSIGNED"
                       91 "NEVER USED COCAINE"
                       93 "USED COCAINE BUT NEVER WITH A NEEDLE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define OTDGNEDL  1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define OTDGNDLA  109 "Seconal" 110 "Tuinal" 112 "Restoril, Temazepam"
                       115 "Phenobarbital" 190 "Dormin <OTC>"
                       201 "Valium, Diazepam" 299 "Midozolam" 311 "Preludin"
                       318 "Ritalin, Methylphenidate" 321 "Methedrine"
                       322 "Methamphetamine ('ice' or 'crank'), Meth"
                       325 "USED STIMULANT, DON'T KNOW NAME"
                       339 "Amphetamines" 348 "Crystal" 355 "Crystal meth"
                       406 "Percodan" 407 "Demerol" 408 "Dilaudid"
                       411 "Talwin" 415 "Codeine" 417 "Morphine, Roxanol"
                       418 "Dolophine, Methadone"
                       420 "OTHER Analgesic, NOT OTHERWISE SPECIFIED"
                       465 "Fentanyl, Duragesic, Sublimaze" 490 "Nubain"
                       601 "LSD ('acid')"
                       605 "PCP ('angel dust,' phencyclidine)"
                       606 "'Ecstasy' (MDMA), X-TC, 'X'"
                       614 "MDA, Methylenedioxy amphetamine"
                       658 "Special K, Ketamine" 702 "Heroin"
                       801 "OTHER Drugs, NOT OTHERWISE SPECIFIED"
                       805 "Cocaine, coca, coca8na, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       824 "Steroids" 1001 "Benadryl <OTC>"
                       3052 "Speed; otherwise unspecified" 4046 "Oxycodone"
                       4067 "Oxycontin"
                       8014 "Throat spray; type unspecified <OTC>"
                       8067 "Testosterone"
                       8072 "Deca-Durabolin, Nondralone Deconate"
                       8076 "Winstrol" 8078 "Vitamin K" 8079 "Insulin"
                       8081 "Primobolan" 8083 "Testosterone Cypronate"
                       8087 "Benzocaine" 8088 "Dianabol"
                       8089 "Sustanol <OTC>" 8090 "Sustanon" 8092 "Decaderm"
                       9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9994 "DON'T KNOW" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define OTDGNDLB  109 "Seconal"
                       120 "Downers; OTHER Sedative, NOT OTHERWISE SPECIFIED"
                       201 "Valium, Diazepam" 209 "Xanax, Alprazolam"
                       311 "Preludin" 318 "Ritalin, Methylphenidate"
                       322 "Methamphetamine ('ice' or 'crank'), Meth"
                       406 "Percodan" 408 "Dilaudid" 417 "Morphine, Roxanol"
                       601 "LSD ('acid')" 606 "'Ecstasy' (MDMA), X-TC, 'X'"
                       702 "Heroin" 805 "Cocaine, coca, coca8na, coke"
                       806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       824 "Steroids"
                       848 "Liquid vitamin, vitamin pills <OTC>"
                       4067 "Oxycontin" 4077 "Tee's"
                       8069 "Decadron, Dexamethasone"
                       8072 "Deca-Durabolin, Nondralone Deconate"
                       8080 "Depotrone" 8090 "Sustanon"
                       9985 "BAD DATA Logically assigned" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define OTDGNDLC  105 "Placidyl" 109 "Seconal" 110 "Tuinal"
                       201 "Valium, Diazepam"
                       322 "Methamphetamine ('ice' or 'crank'), Meth"
                       407 "Demerol" 411 "Talwin" 417 "Morphine, Roxanol"
                       419 "Stadol, Stadol NS"
                       457 "T's and blues, Tee's and B's, Tops and Bottoms"
                       603 "Mescaline"
                       605 "PCP ('angel dust,' phencyclidine)"
                       606 "'Ecstasy' (MDMA), X-TC, 'X'"
                       658 "Special K, Ketamine" 702 "Heroin" 703 "Opium"
                       801 "OTHER Drugs, NOT OTHERWISE SPECIFIED"
                       805 "Cocaine, coca, coca8na, coke" 876 "Glass"
                       8076 "Winstrol" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define OTDGNDLD  603 "Mescaline" 614 "MDA, Methylenedioxy amphetamine"
                       702 "Heroin" 805 "Cocaine, coca, coca8na, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       4067 "Oxycontin" 8076 "Winstrol"
                       8091 "Benzedrex <OTC>"
                       9985 "BAD DATA Logically assigned" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define OTDGNDLE  601 "LSD ('acid')" 8076 "Winstrol"
                       9985 "BAD DATA Logically assigned" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define GNNDREUS  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define GNNDLSH1  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define GNNDCLEN  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define GNNDLSH2  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define GNNDGET2  1 "Bought the needle from a pharmacy"
                       2 "Got the needle from a needle exchange"
                       3 "Bought the needle on the street"
                       4 "Got the needle in a shooting gallery"
                       5 "Got the needle some other way"
                       41 "Given by, stolen from a friend/acquaint of friend"
                       42 "Given by, stolen from a relative"
                       43 "Given by, stolen from someone, relation unspecifd"
                       44 "From drug dealer/came with drugs"
                       46 "Given by, stolen from medical facility/professionl"
                       47 "Given by, stolen from work"
                       49 "Bought, given, stolen from place/location unspecd"
                       56 "Given by, stolen from farm supply store"
                       89 "LEGITIMATE SKIP Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define STNEEDLR  1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "MISSING (BUT NOT REFUSED)" ;
label define STNLRECR  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "At some point in the past 12 months LOG ASSN"
                       9 "At some point in the lifetime LOG ASSN"
                       13 "More than 12 months ago LOGICALLY ASSIGNED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "USED STIMULANTS BUT NEVER WITH A NEEDLE"
                       97 "REFUSED" 98 "MISSING (BUT NOT REFUSED)" ;
label define NEDLRECR  1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       8 "At some point in the past 12 months LOG ASSN"
                       9 "At some point in the lifetime LOG ASSN"
                       13 "More than 12 months ago LOGICALLY ASSIGNED"
                       81 "NEVER USED COC/HER/STM W/NEEDLE Log assn"
                       91 "NEVER USED COC/HER/STM WITH A NEEDLE" 97 "REFUSED"
                       98 "MISSING (BUT NOT REFUSED)" ;
label define NEDFLG01  0 "Never Used (Any source var=2,4,81,91,94,97,98)"
                       1 "Ever Used (Any source var=1,3)" ;
label define NEDMTH    0 "No/Unknown (MTHNEEDL=2,4,81,85,91,94,97,98)"
                       1 "YES (MTHNEEDL=1,3)" ;
label define HERSMOK2  0 "No/Unknown (HERSMOKE=2,91,94,97,98)"
                       1 "Yes (HERSMOKE=1,3)" ;
label define HERSNIF2  0 "No/Unknown (HERSNIFF=2,91,94,97,98)"
                       1 "Yes (HERSNIFF=1,3)" ;
label define NEDHER    0 "No/Unknown (HERNEEDL=2,91,94,97,98)"
                       1 "Yes (HERNEEDL=1,3)" ;
label define NEDCOC    0 "No/Unknown (COCNEEDL=2,91,94,97,98)"
                       1 "Yes (COCNEEDL=1,3)" ;
label define NEDSTM    0 "No/Unknown (STNEEDLR=2,81,91,97,98)"
                       1 "Yes (STNEEDLR=1)" ;
label define RSKPKCIG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RSKMJOCC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RSKMJREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKTRYLSD  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKLSDREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKTRYHER  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKHERREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKCOCOCC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKCOCREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RK5ALDLY  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RK5ALWK   1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RSKDIFMJ  1 "Probably impossible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKDIFLSD  1 "Probably impossible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKDIFCOC  1 "Probably impossible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKDIFCRK  1 "Probably impossible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKDIFHER  1 "Probably impossible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RSKSELL   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKFQDNGR  1 "Never" 2 "Seldom" 3 "Sometimes" 4 "Always"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKFQRSKY  1 "Never" 2 "Seldom" 3 "Sometimes" 4 "Always"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKFQPBLT  1 "Never" 2 "Seldom" 3 "Sometimes" 4 "Always"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKFQDBLT  1 "Never" 2 "Seldom" 3 "Sometimes" 4 "Always"
                       5 "I don't drive" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKLISALL  0 "None of these things" 1 "One of these things"
                       2 "Two of these things" 3 "Three of these things"
                       4 "All four of these things"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKLISRA1  0 "None of these things" 1 "One of these things"
                       2 "Two of these things" 3 "Three of these things"
                       4 "All four of these things"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define RKLISRA2  0 "None of these things" 1 "One of these things"
                       2 "Two of these things" 3 "Three of these things"
                       4 "Four of these things" 5 "All five of these things"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define RKLISRB2  0 "None of these things" 1 "One of these things"
                       2 "Two of these things" 3 "Three of these things"
                       4 "All four of these things"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define RKLISRB1  0 "None of these things" 1 "One of these things"
                       2 "Two of these things" 3 "Three of these things"
                       4 "Four of these things" 5 "All five of these things"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define GRSKPKCG  -9 "Unknown (RSKPKCIG=94,97,98)"
                       0 "Otherwise (RSKPKCIG=1,2,3)"
                       1 "Great Risk (RSKPKCIG=4)" ;
label define GRSKCREG  -9 "Unknown (RKCOCREG=94,97,98)"
                       0 "Otherwise (RKCOCREG=1,2,3)"
                       1 "Great Risk (RKCOCREG=4)" ;
label define GRSKCOCC  -9 "Unknown (RKCOCOCC=94,97,98)"
                       0 "Otherwise (RKCOCOCC=1,2,3)"
                       1 "Great Risk (RKCOCOCC=4)" ;
label define GRSKMREG  -9 "Unknown (RSKMJREG=94,97,98)"
                       0 "Otherwise (RSKMJREG=1,2,3)"
                       1 "Great Risk (RSKMJREG=4)" ;
label define GRSKMOCC  -9 "Unknown (RSKMJOCC=94,97,98)"
                       0 "Otherwise (RSKMJOCC=1,2,3)"
                       1 "Great Risk (RSKMJOCC=4)" ;
label define GRSKHTRY  -9 "Unknown (RKTRYHER=94,97,98)"
                       0 "Otherwise (RKTRYHER=1,2,3)"
                       1 "Great Risk (RKTRYHER=4)" ;
label define GRSKHREG  -9 "Unknown (RKHERREG=94,97,98)"
                       0 "Otherwise (RKHERREG=1,2,3)"
                       1 "Great Risk (RKHERREG=4)" ;
label define GRSKLTRY  -9 "Unknown (RKTRYLSD=94,97,98)"
                       0 "Otherwise (RKTRYLSD=1,2,3)"
                       1 "Great Risk (RKTRYLSD=4)" ;
label define GRSKLREG  -9 "Unknown (RKLSDREG=94,97,98)"
                       0 "Otherwise (RKLSDREG=1,2,3)"
                       1 "Great Risk (RKLSDREG=4)" ;
label define GRSKD4_5  -9 "Unknown (RK5ALDLY=94,97,98)"
                       0 "Otherwise (RK5ALDLY=1,2,3)"
                       1 "Great Risk (RK5ALDLY=4)" ;
label define GRSKD5WK  -9 "Unknown (RK5ALWK=94,97,98)"
                       0 "Otherwise (RK5ALWK=1,2,3)"
                       1 "Great Risk (RK5ALWK=4)" ;
label define RDIFMJ    -9 "Unknown (RSKDIFMJ=94,97,98)"
                       0 "Otherwise (RSKDIFMJ=1,2,3)"
                       1 "Fairly or very easy (RSKDIFMJ=4,5)" ;
label define RDIFCOC   -9 "Unknown (RKDIFCOC=94,97,98)"
                       0 "Otherwise (RKDIFCOC=1,2,3)"
                       1 "Fairly or very easy (RKDIFCOC=4,5)" ;
label define RDIFHER   -9 "Unknown (RKDIFHER=94,97,98)"
                       0 "Otherwise (RKDIFHER=1,2,3)"
                       1 "Fairly or very easy (RKDIFHER=4,5)" ;
label define RDIFLSD   -9 "Unknown (RKDIFLSD=94,97,98)"
                       0 "Otherwise (RKDIFLSD=1,2,3)"
                       1 "Fairly or very easy (RKDIFLSD=4,5)" ;
label define RDIFCRK   -9 "Unknown (RKDIFCRK=94,97,98)"
                       0 "Otherwise (RKDIFCRK=1,2,3)"
                       1 "Fairly or very easy (RKDIFCRK=4,5)" ;
label define APPSELDG  -9 "Unknown (RSKSELL=85,94,97,98)" 0 "No (RSKSELL=2)"
                       1 "Yes (RSKSELL=1)" ;
label define BIDIEVER  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define BIDIREC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       9 "Used at some point in the lifetime LOG ASSN"
                       11 "Used in the past 30 days (BIDI30US=0)"
                       19 "Used more than 30 days ago LOG ASSN"
                       91 "NEVER USED BIDIS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define BIDI30US  0 "0 days (BIDIREC=11)" 91 "NEVER USED BIDIS"
                       93 "DID NOT USE BIDIS IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CLOVEVER  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CLOVREC   1 "Within the past 30 days"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago but within the past 3 yrs"
                       4 "More than 3 years ago"
                       9 "Used at some point in the lifetime LOG ASSN"
                       11 "Used in the past 30 days (CLOV30US=0)"
                       19 "Used more than 30 days ago LOG ASSN"
                       91 "NEVER USED CLOVE CIGARETTES" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CLOV30US  0 "0 days (CLOVREC=11)"
                       91 "NEVER USED CLOVE CIGARETTES"
                       93 "DID NOT USE CLOVE CIGARETTES IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define BIDIMONR  0 "No use Pst Mon/Unk (BIDIREC=2,3,4,9,19,91,97,98)"
                       1 "Used in Past Month (BIDIREC=1,11)" ;
label define BIDIYRR   0 "No use Pst Yr/Unknown (BIDIREC=3,4,9,19,91,97,98)"
                       1 "Used in Past Year (BIDIREC=1,2,11)" ;
label define BIDIFLGR  0 "Never/Unknown (BIDIREC=91,97,98)"
                       1 "Ever used (BIDIREC=1,2,3,4,9,11,19)" ;
label define CLOVMONR  0 "No use Pst Mon/Unk (CLOVREC=2,3,4,9,19,91,97,98)"
                       1 "Used in Past Month (CLOVREC=1,11)" ;
label define CLOVYRR   0 "No use Pst Yr/Unknown (CLOVREC=3,4,9,19,91,97,98)"
                       1 "Used in Past Year (CLOVREC=1,2,11)" ;
label define CLOVFLGR  0 "Never/Unknown (CLOVREC=91,97,98)"
                       1 "Ever used (CLOVREC=1,2,3,4,9,11,19)" ;
label define SPCGMONR  0 "No use Pst Mon/Unknown (BIDIMONR=0 and CLOVMONR=0)"
                       1 "Used in Past Month (BIDIMONR=1 or CLOVMONR=1)" ;
label define SPCGYRR   0 "No use Pst Yr/Unknown (BIDIYRR=0 and CLOVYRR=0)"
                       1 "Used in Past Year (BIDIYRR=1 or CLOVYRR=1)" ;
label define SPCGFLGR  0 "Never/Unknown (BIDIFLGR=0 and CLOVFLGR=0)"
                       1 "Ever used (BIDIFLGR=1 or CLOVFLGR=1)" ;
label define CIGIRTBL  1 "Not at all true" 2 "Somewhat true"
                       3 "Moderately true" 4 "Very true" 5 "Extremely true"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIGCRAVE  1 "Not at all true" 2 "Somewhat true"
                       3 "Moderately true" 4 "Very true" 5 "Extremely true"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIGCRAGP  1 "Not at all true" 2 "Somewhat true"
                       3 "Moderately true" 4 "Very true" 5 "Extremely true"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIGINCTL  1 "Not at all true" 2 "Somewhat true"
                       3 "Moderately true" 4 "Very true" 5 "Extremely true"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIGAVOID  1 "Not at all true" 2 "Somewhat true"
                       3 "Moderately true" 4 "Very true" 5 "Extremely true"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIGFNSMK  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIGFNLKE  1 "Not at all true" 2 "Somewhat true"
                       3 "Moderately true" 4 "Very true" 5 "Extremely true"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CIGPLANE  1 "Not at all true" 2 "Somewhat true"
                       3 "Moderately true" 4 "Very true" 5 "Extremely true"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIGRNOUT  1 "Not at all true" 2 "Somewhat true"
                       3 "Moderately true" 4 "Very true" 5 "Extremely true"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIGREGDY  1 "Not at all true" 2 "Somewhat true"
                       3 "Moderately true" 4 "Very true" 5 "Extremely true"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIGREGWK  1 "Not at all true" 2 "Somewhat true"
                       3 "Moderately true" 4 "Very true" 5 "Extremely true"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIGREGNM  1 "Not at all true" 2 "Somewhat true"
                       3 "Moderately true" 4 "Very true" 5 "Extremely true"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIGNMCHG  1 "Not at all true" 2 "Somewhat true"
                       3 "Moderately true" 4 "Very true" 5 "Extremely true"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIGSVLHR  1 "Not at all true" 2 "Somewhat true"
                       3 "Moderately true" 4 "Very true" 5 "Extremely true"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIGINFLU  1 "Not at all true" 2 "Somewhat true"
                       3 "Moderately true" 4 "Very true" 5 "Extremely true"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIGNOINF  1 "Not at all true" 2 "Somewhat true"
                       3 "Moderately true" 4 "Very true" 5 "Extremely true"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIGINCRS  1 "Not at all true" 2 "Somewhat true"
                       3 "Moderately true" 4 "Very true" 5 "Extremely true"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIGSATIS  1 "Not at all true" 2 "Somewhat true"
                       3 "Moderately true" 4 "Very true" 5 "Extremely true"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIGLOTMR  1 "Not at all true" 2 "Somewhat true"
                       3 "Moderately true" 4 "Very true" 5 "Extremely true"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIGWAKE   1 "Within the first 5 minutes after you wake up"
                       2 "Between 6 and 30 minutes after you wake up"
                       3 "Between 31 and 60 minutes after you wake up"
                       4 "More than 60 minutes after you wake up"
                       85 "BAD DATA Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CIG30PKC  1 "Pack" 2 "Carton" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CIG30PPK  1 "Less than $1.00" 2 "$1.00 - $1.50"
                       3 "$1.51 - $2.00" 4 "$2.01 - $2.50" 5 "$2.51 - $3.00"
                       6 "$3.01 - $3.50" 7 "$3.51 - $4.00" 8 "$4.01 - $4.50"
                       9 "$4.51 - $5.00" 10 "More than $5.00"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CIG30PCR  1 "Less than $10.00" 2 "$10.00 - $13.00"
                       3 "$13.01 - $16.00" 4 "$16.01 - $19.00"
                       5 "$19.01 - $22.00" 6 "$22.01 - $25.00"
                       7 "$25.01 - $28.00" 8 "$28.01 - $31.00"
                       9 "$31.01 - $34.00" 10 "$34.01 - $37.00"
                       11 "$37.01 - $40.00" 12 "$40.01 - $43.00"
                       13 "$43.01 - $46.00" 14 "$46.01 - $49.00"
                       15 "More than $49.00" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCLOTTM  1 "Yes" 2 "No"
                       83 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS Log asn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ALCGTOVR  1 "Yes" 2 "No"
                       83 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS Log asn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCLIMIT  1 "Yes" 2 "No"
                       83 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS Log asn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ALCKPLMT  1 "Usually kept to the limits set"
                       2 "Often drank more than intended"
                       83 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS Log asn"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCNDMOR  1 "Yes" 2 "No"
                       83 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS Log asn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ALCLSEFX  1 "Yes" 2 "No"
                       83 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS Log asn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCCUTDN  1 "Yes" 2 "No"
                       83 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS Log asn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ALCCUTEV  1 "Yes" 2 "No"
                       83 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS Log asn"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCCUT1X  1 "Yes" 2 "No"
                       83 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS Log asn"
                       85 "BAD DATA Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCWD2SX  1 "Yes" 2 "No"
                       83 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS Log asn"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCWDSMT  1 "Yes" 2 "No"
                       83 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS Log asn"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCEMOPB  1 "Yes" 2 "No"
                       83 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS Log asn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ALCEMCTD  1 "Yes" 2 "No"
                       83 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS Log asn"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCPHLPB  1 "Yes" 2 "No"
                       83 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS Log asn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCPHCTD  1 "Yes" 2 "No"
                       83 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS Log asn"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCLSACT  1 "Yes" 2 "No"
                       83 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS Log asn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ALCSERPB  1 "Yes" 2 "No"
                       83 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS Log asn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ALCPDANG  1 "Yes" 2 "No"
                       83 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS Log asn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ALCLAWTR  1 "Yes" 2 "No"
                       83 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS Log asn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ALCFMFPB  1 "Yes" 2 "No"
                       83 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS Log asn"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ALCFMCTD  1 "Yes" 2 "No"
                       83 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS Log asn"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALC PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MRJLOTTM  1 "Yes" 2 "No"
                       83 "DID NOT USE MJ PST 12 MOS OR USED <6 DYS Log asn"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MJ PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MRJGTOVR  1 "Yes" 2 "No"
                       83 "DID NOT USE MJ PST 12 MOS OR USED <6 DAY Log asn"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MJ PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MRJLIMIT  1 "Yes" 2 "No"
                       83 "DID NOT USE MJ PST 12 MOS OR USED <6 DAY Log asn"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MJ PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MRJKPLMT  1 "Usually kept to the limits set"
                       2 "Often used more than intended"
                       83 "DID NOT USE MJ PST 12 MOS OR USED <6 DAY Log asn"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MJ PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MRJNDMOR  1 "Yes" 2 "No"
                       83 "DID NOT USE MJ PST 12 MOS OR USED <6 DAY Log asn"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MJ PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MRJLSEFX  1 "Yes" 2 "No"
                       83 "DID NOT USE MJ PST 12 MOS OR USED <6 DAY Log asn"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MJ PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MRJCUTDN  1 "Yes" 2 "No"
                       83 "DID NOT USE MJ PST 12 MOS OR USED <6 DAY Log asn"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MJ PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MRJCUTEV  1 "Yes" 2 "No"
                       83 "DID NOT USE MJ PST 12 MOS OR USED <6 DAY Log asn"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MJ PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MRJEMOPB  1 "Yes" 2 "No"
                       83 "DID NOT USE MJ PST 12 MOS OR USED <6 DAY Log asn"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MJ PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MRJEMCTD  1 "Yes" 2 "No"
                       83 "DID NOT USE MJ PST 12 MOS OR USED <6 DAY Log asn"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MJ PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MRJPHLPB  1 "Yes" 2 "No"
                       83 "DID NOT USE MJ PST 12 MOS OR USED <6 DAY Log asn"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MJ PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MRJPHCTD  1 "Yes" 2 "No"
                       83 "DID NOT USE MJ PST 12 MOS OR USED <6 DAY Log asn"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MJ PST 12 MOS OR USED <6 DYS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MRJLSACT  1 "Yes" 2 "No"
                       83 "DID NOT USE MJ PST 12 MOS OR USED <6 DAY Log asn"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MJ PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MRJSERPB  1 "Yes" 2 "No"
                       83 "DID NOT USE MJ PST 12 MOS OR USED <6 DAY Log asn"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MJ PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MRJPDANG  1 "Yes" 2 "No"
                       83 "DID NOT USE MJ PST 12 MOS OR USED <6 DAY Log asn"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MJ PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MRJLAWTR  1 "Yes" 2 "No"
                       83 "DID NOT USE MJ PST 12 MOS OR USED <6 DAY Log asn"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MJ PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MRJFMFPB  1 "Yes" 2 "No"
                       83 "DID NOT USE MJ PST 12 MOS OR USED <6 DAY Log asn"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MJ PST 12 MOS OR USED <6 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MRJFMCTD  1 "Yes" 2 "No"
                       83 "DID NOT USE MJ PST 12 MOS OR USED <6 DAY Log asn"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MJ PST 12 MOS OR USED <6 DYS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define COCLOTTM  1 "Yes" 2 "No" 91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define COCGTOVR  1 "Yes" 2 "No" 91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define COCLIMIT  1 "Yes" 2 "No" 91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define COCKPLMT  1 "Usually kept to the limits set"
                       2 "Often used more than intended"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define COCNDMOR  1 "Yes" 2 "No" 91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define COCLSEFX  1 "Yes" 2 "No" 91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define COCCUTDN  1 "Yes" 2 "No" 91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define COCCUTEV  1 "Yes" 2 "No" 91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define COCCUT1X  1 "Yes" 2 "No"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define COCFLBLU  1 "Yes" 2 "No" 91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define COCWD2SX  1 "Yes" 2 "No" 91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define COCWDSMT  1 "Yes" 2 "No" 91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define COCEMOPB  1 "Yes" 2 "No" 91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define COCEMCTD  1 "Yes" 2 "No" 91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define COCPHLPB  1 "Yes" 2 "No" 91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define COCPHCTD  1 "Yes" 2 "No" 91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define COCLSACT  1 "Yes" 2 "No" 91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define COCSERPB  1 "Yes" 2 "No" 91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define COCPDANG  1 "Yes" 2 "No" 91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define COCLAWTR  1 "Yes" 2 "No" 91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define COCFMFPB  1 "Yes" 2 "No" 91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define COCFMCTD  1 "Yes" 2 "No" 91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HERLOTTM  1 "Yes" 2 "No" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HERGTOVR  1 "Yes" 2 "No" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HERLIMIT  1 "Yes" 2 "No" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HERKPLMT  1 "Usually kept to the limits set"
                       2 "Often used more than intended"
                       91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HERNDMOR  1 "Yes" 2 "No" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HERLSEFX  1 "Yes" 2 "No" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HERCUTDN  1 "Yes" 2 "No" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HERCUTEV  1 "Yes" 2 "No" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HERCUT1X  1 "Yes" 2 "No"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HERWD3SX  1 "Yes" 2 "No" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HERWDSMT  1 "Yes" 2 "No" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HEREMOPB  1 "Yes" 2 "No" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HEREMCTD  1 "Yes" 2 "No" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HERPHLPB  1 "Yes" 2 "No" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HERPHCTD  1 "Yes" 2 "No" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HERLSACT  1 "Yes" 2 "No" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HERSERPB  1 "Yes" 2 "No" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HERPDANG  1 "Yes" 2 "No" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HERLAWTR  1 "Yes" 2 "No" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HERFMFPB  1 "Yes" 2 "No" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HERFMCTD  1 "Yes" 2 "No" 91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HALLOTTM  1 "Yes" 2 "No" 91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HALGTOVR  1 "Yes" 2 "No" 91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HALLIMIT  1 "Yes" 2 "No" 91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HALKPLMT  1 "Usually kept to the limits set"
                       2 "Often used more than intended"
                       91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HALNDMOR  1 "Yes" 2 "No" 91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HALLSEFX  1 "Yes" 2 "No" 91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HALCUTDN  1 "Yes" 2 "No" 91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HALCUTEV  1 "Yes" 2 "No" 91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HALEMOPB  1 "Yes" 2 "No" 91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HALEMCTD  1 "Yes" 2 "No" 91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HALPHLPB  1 "Yes" 2 "No" 91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HALPHCTD  1 "Yes" 2 "No" 91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HALLSACT  1 "Yes" 2 "No" 91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HALSERPB  1 "Yes" 2 "No" 91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HALPDANG  1 "Yes" 2 "No" 91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HALLAWTR  1 "Yes" 2 "No" 91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HALFMFPB  1 "Yes" 2 "No" 91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HALFMCTD  1 "Yes" 2 "No" 91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define INHLOTTM  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define INHGTOVR  1 "Yes" 2 "No" 91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define INHLIMIT  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define INHKPLMT  1 "Usually kept to the limits set"
                       2 "Often used more than intended"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define INHNDMOR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define INHLSEFX  1 "Yes" 2 "No" 91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define INHCUTDN  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define INHCUTEV  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define INHEMOPB  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define INHEMCTD  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define INHPHLPB  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define INHPHCTD  1 "Yes" 2 "No" 91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define INHLSACT  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define INHSERPB  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define INHPDANG  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define INHLAWTR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define INHFMFPB  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define INHFMCTD  1 "Yes" 2 "No" 91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANTS PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ANLLOTTM  1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ANLGTOVR  1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ANLLIMIT  1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ANLKPLMT  1 "Usually kept to the limits set"
                       2 "Often used more than intended"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS PST 12 MOS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ANLNDMOR  1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ANLLSEFX  1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ANLCUTDN  1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ANLCUTEV  1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ANLCUT1X  1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ANLWD3SX  1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ANLWDSMT  1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ANLEMOPB  1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ANLEMCTD  1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS PST 12 MOS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ANLPHLPB  1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ANLPHCTD  1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS PST 12 MOS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ANLLSACT  1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ANLSERPB  1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ANLPDANG  1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ANLLAWTR  1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ANLFMFPB  1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ANLFMCTD  1 "Yes" 2 "No"
                       81 "NEVER USED PAIN RELIEVERS Logically assigned"
                       91 "NEVER USED PAIN RELIEVERS"
                       93 "DID NOT USE PAIN RELIEVERS PST 12 MOS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TRNLOTTM  1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRNGTOVR  1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TRNLIMIT  1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRNKPLMT  1 "Usually kept to the limits set"
                       2 "Often used more than intended"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRNNDMOR  1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRNLSEFX  1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TRNCUTDN  1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRNCUTEV  1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRNEMOPB  1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRNEMCTD  1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRNPHLPB  1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TRNPHCTD  1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRNLSACT  1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRNSERPB  1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRNPDANG  1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRNLAWTR  1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRNFMFPB  1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS PST 12 MOS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRNFMCTD  1 "Yes" 2 "No"
                       81 "NEVER USED TRANQUILIZERS Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE TRANQUILIZERS PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define STMLOTTM  1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STMGTOVR  1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define STMLIMIT  1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STMKPLMT  1 "Usually kept to the limits set"
                       2 "Often used more than intended"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define STMNDMOR  1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STMLSEFX  1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define STMCUTDN  1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STMCUTEV  1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define STMCUT1X  1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define STMFLBLU  1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define STMWD2SX  1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define STMWDSMT  1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define STMEMOPB  1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STMEMCTD  1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define STMPHLPB  1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define STMPHCTD  1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define STMLSACT  1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STMSERPB  1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STMPDANG  1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STMLAWTR  1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STMFMFPB  1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STMFMCTD  1 "Yes" 2 "No"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANTS PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SEDLOTTM  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SEDGTOVR  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SEDLIMIT  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SEDKPLMT  1 "Usually kept to the limits set"
                       2 "Often used more than intended"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SEDNDMOR  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SEDLSEFX  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SEDCUTDN  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SEDCUTEV  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SEDCUT1X  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SEDWD1SX  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SEDWDSMT  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SEDEMOPB  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SEDEMCTD  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SEDPHLPB  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SEDPHCTD  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SEDLSACT  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SEDSERPB  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SEDPDANG  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SEDLAWTR  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SEDFMFPB  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES PST 12 MOS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SEDFMCTD  1 "Yes" 2 "No"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE SEDATIVES PST 12 MOS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define IRCGIRTB  85.00 "BAD DATA" 91.00 "NEVER USED"
                       93.00 "DID NOT USE CIGARETTES PAST MONTH"
                       94.00 "DON'T KNOW" 97.00 "REFUSED"
                       98.00 "BLANK/ DID NOT ANSWER" ;
label define IICGIRTB  1 "QUESTIONNAIRE DATA"
                       2 "LOGICALLY ASSN, NOT IMPUTED, <16 NDSS VARS NONMSNG"
                       3 "STATISTICALLY IMPUTED, OTHER 16 NDSS VARS NONMSNG"
                       9 "NEVER USED CIGARETTES, OR DIDN'T USE IN PST 30 DYS"
                       98 "MISSING, NOT IMPUTED, <16 NDSS VARIABLES NONMSNG" ;
label define IRCGCRV   85.00 "BAD DATA" 91.00 "NEVER USED"
                       93.00 "DID NOT USE CIGARETTES PAST MONTH"
                       94.00 "DON'T KNOW" 97.00 "REFUSED"
                       98.00 "BLANK/ DID NOT ANSWER" ;
label define IICGCRV   1 "QUESTIONNAIRE DATA"
                       2 "LOGICALLY ASSN, NOT IMPUTED, <16 NDSS VARS NONMSNG"
                       3 "STATISTICALLY IMPUTED, OTHER 16 NDSS VARS NONMSNG"
                       9 "NEVER USED CIGARETTES, OR DIDN'T USE IN PST 30 DYS"
                       98 "MISSING, NOT IMPUTED, <16 NDSS VARIABLES NONMSNG" ;
label define IRCGCRGP  85.00 "BAD DATA" 91.00 "NEVER USED"
                       93.00 "DID NOT USE CIGARETTES PAST MONTH"
                       94.00 "DON'T KNOW" 97.00 "REFUSED"
                       98.00 "BLANK/ DID NOT ANSWER" ;
label define IICGCRGP  1 "QUESTIONNAIRE DATA"
                       2 "LOGICALLY ASSN, NOT IMPUTED, <16 NDSS VARS NONMSNG"
                       3 "STATISTICALLY IMPUTED, OTHER 16 NDSS VARS NONMSNG"
                       9 "NEVER USED CIGARETTES, OR DIDN'T USE IN PST 30 DYS"
                       98 "MISSING, NOT IMPUTED, <16 NDSS VARIABLES NONMSNG" ;
label define IRCGNCTL  85.00 "BAD DATA" 91.00 "NEVER USED"
                       93.00 "DID NOT USE CIGARETTES PAST MONTH"
                       94.00 "DON'T KNOW" 97.00 "REFUSED"
                       98.00 "BLANK/ DID NOT ANSWER" ;
label define IICGNCTL  1 "QUESTIONNAIRE DATA"
                       2 "LOGICALLY ASSN, NOT IMPUTED, <16 NDSS VARS NONMSNG"
                       3 "STATISTICALLY IMPUTED, OTHER 16 NDSS VARS NONMSNG"
                       9 "NEVER USED CIGARETTES, OR DIDN'T USE IN PST 30 DYS"
                       98 "MISSING, NOT IMPUTED, <16 NDSS VARIABLES NONMSNG" ;
label define IRCGAVD   85.00 "BAD DATA" 91.00 "NEVER USED"
                       93.00 "DID NOT USE CIGARETTES PAST MONTH"
                       94.00 "DON'T KNOW" 97.00 "REFUSED"
                       98.00 "BLANK/ DID NOT ANSWER" ;
label define IICGAVD   1 "QUESTIONNAIRE DATA"
                       2 "LOGICALLY ASSN, NOT IMPUTED, <16 NDSS VARS NONMSNG"
                       3 "STATISTICALLY IMPUTED, OTHER 16 NDSS VARS NONMSNG"
                       9 "NEVER USED CIGARETTES, OR DIDN'T USE IN PST 30 DYS"
                       98 "MISSING, NOT IMPUTED, <16 NDSS VARIABLES NONMSNG" ;
label define IRCGPLN   85.00 "BAD DATA" 91.00 "NEVER USED"
                       93.00 "DID NOT USE CIGARETTES PAST MONTH"
                       94.00 "DON'T KNOW" 97.00 "REFUSED"
                       98.00 "BLANK/ DID NOT ANSWER" ;
label define IICGPLN   1 "QUESTIONNAIRE DATA"
                       2 "LOGICALLY ASSN, NOT IMPUTED, <16 NDSS VARS NONMSNG"
                       3 "STATISTICALLY IMPUTED, OTHER 16 NDSS VARS NONMSNG"
                       9 "NEVER USED CIGARETTES, OR DIDN'T USE IN PST 30 DYS"
                       98 "MISSING, NOT IMPUTED, <16 NDSS VARIABLES NONMSNG" ;
label define IRCGROUT  85.00 "BAD DATA" 91.00 "NEVER USED"
                       93.00 "DID NOT USE CIGARETTES PAST MONTH"
                       94.00 "DON'T KNOW" 97.00 "REFUSED"
                       98.00 "BLANK/ DID NOT ANSWER" ;
label define IICGROUT  1 "QUESTIONNAIRE DATA"
                       2 "LOGICALLY ASSN, NOT IMPUTED, <16 NDSS VARS NONMSNG"
                       3 "STATISTICALLY IMPUTED, OTHER 16 NDSS VARS NONMSNG"
                       9 "NEVER USED CIGARETTES, OR DIDN'T USE IN PST 30 DYS"
                       98 "MISSING, NOT IMPUTED, <16 NDSS VARIABLES NONMSNG" ;
label define IRCGRGDY  85.00 "BAD DATA" 91.00 "NEVER USED"
                       93.00 "DID NOT USE CIGARETTES PAST MONTH"
                       94.00 "DON'T KNOW" 97.00 "REFUSED"
                       98.00 "BLANK/ DID NOT ANSWER" ;
label define IICGRGDY  1 "QUESTIONNAIRE DATA"
                       2 "LOGICALLY ASSN, NOT IMPUTED, <16 NDSS VARS NONMSNG"
                       3 "STATISTICALLY IMPUTED, OTHER 16 NDSS VARS NONMSNG"
                       9 "NEVER USED CIGARETTES, OR DIDN'T USE IN PST 30 DYS"
                       98 "MISSING, NOT IMPUTED, <16 NDSS VARIABLES NONMSNG" ;
label define IRCGRGWK  85.00 "BAD DATA" 91.00 "NEVER USED"
                       93.00 "DID NOT USE CIGARETTES PAST MONTH"
                       94.00 "DON'T KNOW" 97.00 "REFUSED"
                       98.00 "BLANK/ DID NOT ANSWER" ;
label define IICGRGWK  1 "QUESTIONNAIRE DATA"
                       2 "LOGICALLY ASSN, NOT IMPUTED, <16 NDSS VARS NONMSNG"
                       3 "STATISTICALLY IMPUTED, OTHER 16 NDSS VARS NONMSNG"
                       9 "NEVER USED CIGARETTES, OR DIDN'T USE IN PST 30 DYS"
                       98 "MISSING, NOT IMPUTED, <16 NDSS VARIABLES NONMSNG" ;
label define IRCGRGNM  85.00 "BAD DATA" 91.00 "NEVER USED"
                       93.00 "DID NOT USE CIGARETTES PAST MONTH"
                       94.00 "DON'T KNOW" 97.00 "REFUSED"
                       98.00 "BLANK/ DID NOT ANSWER" ;
label define IICGRGNM  1 "QUESTIONNAIRE DATA"
                       2 "LOGICALLY ASSN, NOT IMPUTED, <16 NDSS VARS NONMSNG"
                       3 "STATISTICALLY IMPUTED, OTHER 16 NDSS VARS NONMSNG"
                       9 "NEVER USED CIGARETTES, OR DIDN'T USE IN PST 30 DYS"
                       98 "MISSING, NOT IMPUTED, <16 NDSS VARIABLES NONMSNG" ;
label define IRCGNCG   85.00 "BAD DATA" 91.00 "NEVER USED"
                       93.00 "DID NOT USE CIGARETTES PAST MONTH"
                       94.00 "DON'T KNOW" 97.00 "REFUSED"
                       98.00 "BLANK/ DID NOT ANSWER" ;
label define IICGNCG   1 "QUESTIONNAIRE DATA"
                       2 "LOGICALLY ASSN, NOT IMPUTED, <16 NDSS VARS NONMSNG"
                       3 "STATISTICALLY IMPUTED, OTHER 16 NDSS VARS NONMSNG"
                       9 "NEVER USED CIGARETTES, OR DIDN'T USE IN PST 30 DYS"
                       98 "MISSING, NOT IMPUTED, <16 NDSS VARIABLES NONMSNG" ;
label define IRCGSLHR  85.00 "BAD DATA" 91.00 "NEVER USED"
                       93.00 "DID NOT USE CIGARETTES PAST MONTH"
                       94.00 "DON'T KNOW" 97.00 "REFUSED"
                       98.00 "BLANK/ DID NOT ANSWER" ;
label define IICGSLHR  1 "QUESTIONNAIRE DATA"
                       2 "LOGICALLY ASSN, NOT IMPUTED, <16 NDSS VARS NONMSNG"
                       3 "STATISTICALLY IMPUTED, OTHER 16 NDSS VARS NONMSNG"
                       9 "NEVER USED CIGARETTES, OR DIDN'T USE IN PST 30 DYS"
                       98 "MISSING, NOT IMPUTED, <16 NDSS VARIABLES NONMSNG" ;
label define IRCGINFL  85.00 "BAD DATA" 91.00 "NEVER USED"
                       93.00 "DID NOT USE CIGARETTES PAST MONTH"
                       94.00 "DON'T KNOW" 97.00 "REFUSED"
                       98.00 "BLANK/ DID NOT ANSWER" ;
label define IICGINFL  1 "QUESTIONNAIRE DATA"
                       2 "LOGICALLY ASSN, NOT IMPUTED, <16 NDSS VARS NONMSNG"
                       3 "STATISTICALLY IMPUTED, OTHER 16 NDSS VARS NONMSNG"
                       9 "NEVER USED CIGARETTES, OR DIDN'T USE IN PST 30 DYS"
                       98 "MISSING, NOT IMPUTED, <16 NDSS VARIABLES NONMSNG" ;
label define IRCGNINF  85.00 "BAD DATA" 91.00 "NEVER USED"
                       93.00 "DID NOT USE CIGARETTES PAST MONTH"
                       94.00 "DON'T KNOW" 97.00 "REFUSED"
                       98.00 "BLANK/ DID NOT ANSWER" ;
label define IICGNINF  1 "QUESTIONNAIRE DATA"
                       2 "LOGICALLY ASSN, NOT IMPUTED, <16 NDSS VARS NONMSNG"
                       3 "STATISTICALLY IMPUTED, OTHER 16 NDSS VARS NONMSNG"
                       9 "NEVER USED CIGARETTES, OR DIDN'T USE IN PST 30 DYS"
                       98 "MISSING, NOT IMPUTED, <16 NDSS VARIABLES NONMSNG" ;
label define IRCGINCR  85.00 "BAD DATA" 91.00 "NEVER USED"
                       93.00 "DID NOT USE CIGARETTES PAST MONTH"
                       94.00 "DON'T KNOW" 97.00 "REFUSED"
                       98.00 "BLANK/ DID NOT ANSWER" ;
label define IICGINCR  1 "QUESTIONNAIRE DATA"
                       2 "LOGICALLY ASSN, NOT IMPUTED, <16 NDSS VARS NONMSNG"
                       3 "STATISTICALLY IMPUTED, OTHER 16 NDSS VARS NONMSNG"
                       9 "NEVER USED CIGARETTES, OR DIDN'T USE IN PST 30 DYS"
                       98 "MISSING, NOT IMPUTED, <16 NDSS VARIABLES NONMSNG" ;
label define IRCGSAT   85.00 "BAD DATA" 91.00 "NEVER USED"
                       93.00 "DID NOT USE CIGARETTES PAST MONTH"
                       94.00 "DON'T KNOW" 97.00 "REFUSED"
                       98.00 "BLANK/ DID NOT ANSWER" ;
label define IICGSAT   1 "QUESTIONNAIRE DATA"
                       2 "LOGICALLY ASSN, NOT IMPUTED, <16 NDSS VARS NONMSNG"
                       3 "STATISTICALLY IMPUTED, OTHER 16 NDSS VARS NONMSNG"
                       9 "NEVER USED CIGARETTES, OR DIDN'T USE IN PST 30 DYS"
                       98 "MISSING, NOT IMPUTED, <16 NDSS VARIABLES NONMSNG" ;
label define IRCGLMR   85.00 "BAD DATA" 91.00 "NEVER USED"
                       93.00 "DID NOT USE CIGARETTES PAST MONTH"
                       94.00 "DON'T KNOW" 97.00 "REFUSED"
                       98.00 "BLANK/ DID NOT ANSWER" ;
label define IICGLMR   1 "QUESTIONNAIRE DATA"
                       2 "LOGICALLY ASSN, NOT IMPUTED, <16 NDSS VARS NONMSNG"
                       3 "STATISTICALLY IMPUTED, OTHER 16 NDSS VARS NONMSNG"
                       9 "NEVER USED CIGARETTES, OR DIDN'T USE IN PST 30 DYS"
                       98 "MISSING, NOT IMPUTED, <16 NDSS VARIABLES NONMSNG" ;
label define NDSSAVG   -9.00 "Unknown (see above comment)" ;
label define NDSSDEP   0 "No/Unknown (NDSSAVG<2.75 or missing)"
                       1 "Yes (NDSSAVG>=2.75)" ;
label define FTNDDEP   0 "No/Unknown(CIGWAKE=3,4,81,83,85,90,91,93,94,97,98)"
                       1 "Yes (CIGWAKE=1 or 2)" ;
label define DEPNDNIC  0 "No/Unknown (NDSSDEP=0 and FTNDDEP=0)"
                       1 "Yes (NDSSDEP=1 or FTNDDEP=1)" ;
label define DEPNDALC  0 "No/Unknown (Otherwise)" 1 "Yes (See comment above)" ;
label define DEPNDANL  0 "No/Unknown (Otherwise)" 1 "Yes (See comment above)" ;
label define DEPNDCOC  0 "No/Unknown (Otherwise)" 1 "Yes (See comment above)" ;
label define DEPNDHER  0 "No/Unknown (Otherwise)" 1 "Yes (See comment above)" ;
label define DEPNDSTM  0 "No/Unknown (Otherwise)" 1 "Yes (See comment above)" ;
label define DEPNDSED  0 "No/Unknown (Otherwise)" 1 "Yes (See comment above)" ;
label define DEPNDHAL  0 "No/Unknown (Otherwise)" 1 "Yes (See comment above)" ;
label define DEPNDINH  0 "No/Unknown (Otherwise)" 1 "Yes (See comment above)" ;
label define DEPNDMRJ  0 "No/Unknown (Otherwise)" 1 "Yes (See comment above)" ;
label define DEPNDTRN  0 "No/Unknown (Otherwise)" 1 "Yes (See comment above)" ;
label define DEPNDILL  0 "No/Unknown (Otherwise)"
                       1 "Yes (Any source variable listed above=1)" ;
label define DEPNDIEM  0 "No/Unknown (Otherwise)"
                       1 "Yes (Any source variable listed above=1)" ;
label define DEPNDXMJ  0 "No/Unknown (Otherwise)"
                       1 "Yes (DEPNDMRJ=0 and any other source var=1)" ;
label define DEPNDPSY  0 "No/Unknown (Otherwise)"
                       1 "Yes (DEPNDTRN, DEPNDANL, DEPNDSTM, OR DEPNDSED=1)" ;
label define DPILLALC  0 "No/Unknown (DEPNDILL=0 and DEPNDALC=0)"
                       1 "Yes (DEPNDILL=1 or DEPNDALC=1)" ;
label define DPILANAL  0 "No/Unknown (DEPNDILL=0 or DEPNDALC=0)"
                       1 "Yes (DEPNDILL=1 and DEPNDALC=1)" ;
label define ABUSEALC  0 "No/Unknown (Otherwise)"
                       1 "Yes (Any one of above criteria and DEPNDALC=0)" ;
label define ABUSEMRJ  0 "No/Unknown (Otherwise)"
                       1 "Yes (Any one of above criteria and DEPNDMRJ=0)" ;
label define ABUSECOC  0 "No/Unknown (Otherwise)"
                       1 "Yes (Any one of above criteria and DEPNDCOC=0)" ;
label define ABUSEHER  0 "No/Unknown (Otherwise)"
                       1 "Yes (Any one of above criteria and DEPNDHER=0)" ;
label define ABUSEHAL  0 "No/Unknown (Otherwise)"
                       1 "Yes (Any one of above criteria and DEPNDHAL=0)" ;
label define ABUSEINH  0 "No/Unknown (Otherwise)"
                       1 "Yes (Any one of above criteria and DEPNDINH=0)" ;
label define ABUSEANL  0 "No/Unknown (Otherwise)"
                       1 "Yes (Any one of above criteria and DEPNDANL=0)" ;
label define ABUSETRN  0 "No/Unknown (Otherwise)"
                       1 "Yes (Any one of above criteria and DEPNDTRN=0)" ;
label define ABUSESTM  0 "No/Unknown (Otherwise)"
                       1 "Yes (Any one of above criteria and DEPNDSTM=0)" ;
label define ABUSESED  0 "No/Unknown (Otherwise)"
                       1 "Yes (Any one of above criteria and DEPNDSED=0)" ;
label define ABUSEILL  0 "No/Unknown (Otherwise)"
                       1 "Yes (Any source variable above=1 & DEPNDILL=0)" ;
label define ABILLALC  0 "No/Unknown (ABUSEILL=0 and ABUSEALC=0)"
                       1 "Yes (ABUSEILL=1 or ABUSEALC=1)" ;
label define ABILANAL  0 "No/Unknown (Otherwise)"
                       1 "Yes (ABUSEILL=1 & ABUSEALC=1 & DPILLALC=0)" ;
label define ABUSEPSY  0 "No/Unknown (Otherwise)"
                       1 "Yes (Any source variable above=1 & DEPNDPSY=0)" ;
label define ABUSEIEM  0 "No/Unknown (Otherwise)"
                       1 "Yes (Any above source var=1 & DEPNDIEM=0)" ;
label define ABUSEXMJ  0 "No/Unknown (Otherwise)"
                       1 "Yes (Any above var=1 & ABUSEMRJ=0 & DEPNDXMJ=0)" ;
label define ABODALC   0 "No/Unknown (ABUSEALC=0 and DEPNDALC=0)"
                       1 "Yes (ABUSEALC=1 or DEPNDALC=1)" ;
label define ABODMRJ   0 "No/Unknown (ABUSEMRJ=0 and DEPNDMRJ=0)"
                       1 "Yes (ABUSEMRJ=1 or DEPNDMRJ=1)" ;
label define ABODCOC   0 "No/Unknown (ABUSECOC=0 and DEPNDCOC=0)"
                       1 "Yes (ABUSECOC=1 or DEPNDCOC=1)" ;
label define ABODHER   0 "No/Unknown (ABUSEHER=0 and DEPNDHER=0)"
                       1 "Yes (ABUSEHER=1 or DEPNDHER=1)" ;
label define ABODHAL   0 "No/Unknown (ABUSEHAL=0 and DEPNDHAL=0)"
                       1 "Yes (ABUSEHAL=1 or DEPNDHAL=1)" ;
label define ABODINH   0 "No/Unknown (ABUSEINH=0 and DEPNDINH=0)"
                       1 "Yes (ABUSEINH=1 or DEPNDINH=1)" ;
label define ABODANL   0 "No/Unknown (ABUSEANL=0 and DEPNDANL=0)"
                       1 "Yes (ABUSEANL=1 or DEPNDANL=1)" ;
label define ABODTRN   0 "No/Unknown (ABUSETRN=0 and DEPNDTRN=0)"
                       1 "Yes (ABUSETRN=1 or DEPNDTRN=1)" ;
label define ABODSTM   0 "No/Unknown (ABUSESTM=0 and DEPNDSTM=0)"
                       1 "Yes (ABUSESTM=1 or DEPNDSTM=1)" ;
label define ABODSED   0 "No/Unknown (ABUSESED=0 and DEPNDSED=0)"
                       1 "Yes (ABUSESED=1 or DEPNDSED=1)" ;
label define ABODILL   0 "No/Unknown (ABUSEILL=0 and DEPNDILL=0)"
                       1 "Yes (ABUSEILL=1 or DEPNDILL=1)" ;
label define ABODIEM   0 "No/Unknown (DEPNDIEM=0 and ABUSEIEM=0)"
                       1 "Yes (DEPNDIEM=1 or ABUSEIEM=1)" ;
label define ABODPSY   0 "No/Unknown (ABUSEPSY=0 and DEPNDPSY=0)"
                       1 "Yes (ABUSEPSY=1 or DEPNDPSY=1)" ;
label define ABODILAL  0 "No/Unknown (ABILLALC=0 and DPILLALC=0)"
                       1 "Yes (ABILLALC=1 or DPILLALC=1)" ;
label define ABDILAAL  0 "No/Unknown (ABODILL=0 or ABODALC=0)"
                       1 "Yes (ABODILL=1 and ABODALC=1)" ;
label define BOOKED    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define NOBOOKY2  0 "None" 1 "One time" 2 "Two times"
                       3 "Three or more times"
                       985 "BAD DATA Logically assigned" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP (BOOKED=2)" ;
label define BKMVTHFT  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKLARCNY  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKBURGL   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKAGASLT  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKSMASLT  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKROB     1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKRAPE    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKMURDER  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKARSON   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKDRVINF  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKDRUNK   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKPOSTOB  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define BKDRUG    1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKPROS    1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKSEXOFF  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKFRAUD   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKOTH     1 "Yes" 2 "No" 5 "Offense unknown"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define BKOTHOF2  1 "Motor vehicle theft" 2 "Larceny or theft"
                       3 "Burglary or breaking and entering"
                       4 "Aggravated assault"
                       5 "Other assault, such as simple assault or battery"
                       6 "Robbery" 7 "Forcible rape" 9 "Arson"
                       10 "Driving under the influence of alcohol or drugs"
                       11 "Drunkenness or other liquor law violation"
                       12 "Possession of tobacco"
                       13 "Possession, manufacture, or sale of drugs"
                       16 "Fraud, possessing stolen goods, vandalism"
                       17 "Some other offense" 18 "Weapons law violations"
                       19 "Counterfeiting/Forgery"
                       20 "Violation of court order, parole, probation"
                       21 "Disorderly conduct" 22 "Juvenile status offenses"
                       23 "All oth offns: crimes agnst persons/prprty/society"
                       24 "Traffic violations" 25 "Bad checks"
                       26 "Curfew/loitering/vagrancy violations"
                       27 "Trespass of real property" 28 "Runaway"
                       29 "Family offenses, nonviolent" 31 "Intimidation"
                       36 "Possession of drug paraphernalia"
                       38 "Evading/hindering/obstructing police"
                       39 "False report/statement/alarm"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PROBATON  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PAROLREL  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DRVALDR   1 "Yes" 2 "No"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DRVAONLY  1 "Yes" 2 "No"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DRVDONLY  1 "Yes" 2 "No"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DRIVALC   1 "Yes (DRVALDR=1 OR DRVAONLY=1)"
                       2 "No (DRVALDR=2 AND DRVAONLY=2)"
                       3 "Unknown (OTHERWISE)"
                       4 "Never/No Use (DRVALDR AND DRVAONLY=81,89,91,99)" ;
label define DRIVDRG   1 "Yes (DRVALDR=1 OR DRVDONLY=1)"
                       2 "No (DRVALDR=2 AND DRVDONLY=2)"
                       3 "Unknown (OTHERWISE)"
                       4 "Never/No Use (DRVALDR AND DRVDONLY=81,89,91,99)" ;
label define DRIVALD   1 "Yes (DRIVALC=1 OR DRIVDRG=1)"
                       2 "No (DRIVALC=2 AND DRIVDRG=2)"
                       3 "Unknown (DRIVALC=3 OR DRIVDRG=3)"
                       4 "Never/No Use (DRIVALC=4 AND DRIVDRG=4)" ;
label define PAROL     -9 "Unknown Status (PAROLREL=85,94,97,98)"
                       1 "On Parole/Supervised Release (PAROLREL=1)"
                       2 "Not on Parole/Supervised Release (PAROLREL=2)" ;
label define PROB      -9 "Unknown Probation Status (PROBATON=85,94,97,98)"
                       1 "On Probation (PROBATON=1)"
                       2 "Not on Probation (PROBATON=2)" ;
label define MMGETMJ   1 "You bought it" 2 "You traded something else for it"
                       3 "You got it for free or shared someone else's"
                       4 "You grew it yourself" 91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MMBTREC1  1 "DATE FILL"
                       2 "More than 30 days ago, but within the past 12 mos"
                       3 "More than 12 months ago" 91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMBTPYR   1 "Yes" 2 "No" 91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMBTREC2  1 "DATE FILL"
                       2 "More than 30 days ago, but within the past 12 mos"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMBT30DY  91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMJNTLOO  1 "You bought joints"
                       2 "You bought the marijuana in loose form"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMJNTNUM  991 "NEVER USED MARIJUANA"
                       993 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define MMJNPCTB  1 "less than $5.00" 2 "$5.00 to $10.99"
                       3 "$11.00 to $20.99" 4 "$21.00 to $50.99"
                       5 "$51.00 to $100.99" 6 "$101.00 to $150.99"
                       7 "$151.00 to $200.99" 8 "$201.00 to $250.99"
                       10 "$301.00 to $500.99" 11 "$501.00 to $1000.99"
                       12 "More than $1000.99" 91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMJNPCAT  1 "Less than $5.00" 2 "$5.00 to $10.99"
                       3 "$11.00 to $20.99" 41 "$21.00 to $30.99"
                       42 "$31.00 to $40.99" 43 "$41.00 to $50.99"
                       51 "$51.00 to $60.99" 52 "$61.00 to $70.99"
                       53 "$71.00 to $80.99" 54 "$81.00 to $90.99"
                       55 "$91.00 to $100.99" 61 "$101.00 to $110.99"
                       70 "$151.00 to $200.99" 80 "$201.00 to $250.99"
                       101 "$301.00 to $350.99" 120 "$951.00 to $1000.99"
                       121 "More than $1000.99" 991 "NEVER USED MARIJUANA"
                       993 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define MMLSUNIT  1 "Grams" 2 "Ounces" 3 "Pounds"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMLSGMS   1 "At least 1 but less than 5 grams"
                       2 "At least 5 but less than 10 grams"
                       3 "10 grams or more" 91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMLS10GM  991 "NEVER USED MARIJUANA"
                       993 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define MMLSOZS   1 "At least 1/8, but less than 1/4 of an ounce"
                       2 "At least 1/4 but less than 1/3 of an ounce"
                       3 "At least 1/3 but less than 1/2 of an ounce"
                       4 "At least 1/2 but less than 1 ounce"
                       5 "At least 1 but less than 5 ounces"
                       6 "At least 5 but less than 10 ounces"
                       7 "At least 10 but less than 16 ounces"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMLSLBS   1 "At least 1 but less than 2 pounds"
                       2 "At least 2 but less than 3 pounds"
                       3 "At least 3 but less than 4 pounds"
                       4 "At least 4 but less than 5 pounds"
                       5 "5 or more pounds" 91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMLS5LBS  991 "NEVER USED MARIJUANA"
                       993 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define MMLSPCTB  1 "less than $5.00" 2 "$5.00 to $10.99"
                       3 "$11.00 to $20.99" 4 "$21.00 to $50.99"
                       5 "$51.00 to $100.99" 6 "$101.00 to $150.99"
                       7 "$151.00 to $200.99" 8 "$201.00 to $250.99"
                       9 "$251.00 to $300.99" 10 "$301.00 to $500.99"
                       11 "$501.00 to $1000.99" 12 "More than $1000.99"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMLSPCAT  1 "Less than $5.00" 2 "$5.00 to $10.99"
                       3 "$11.00 to $20.99"
                       40 "$21.00 to $50.99 (No further detail)"
                       41 "$21.00 to $30.99" 42 "$31.00 to $40.99"
                       43 "$41.00 to $50.99"
                       50 "$51.00 to $100.99 (No further detail)"
                       51 "$51.00 to $60.99" 52 "$61.00 to $70.99"
                       53 "$71.00 to $80.99" 54 "$81.00 to $90.99"
                       55 "$91.00 to $100.99"
                       60 "$101.00 to $150.99 (No further detail)"
                       61 "$101.00 to $110.99" 62 "$111.00 to $120.99"
                       63 "$121.00 to $130.99" 64 "$131.00 to $140.99"
                       65 "$141.00 to $150.99" 70 "$151.00 to $200.99"
                       80 "$201.00 to $250.99" 90 "$251.00 to $300.99"
                       101 "$301.00 to $350.99" 102 "$351.00 to $400.99"
                       103 "$401.00 to $450.99" 104 "$451.00 to $500.99"
                       111 "$501.00 to $550.99" 113 "$601.00 to $650.99"
                       114 "$651.00 to $700.99" 115 "$701.00 to $750.99"
                       116 "$751.00 to $800.99" 117 "$801.00 to $850.99"
                       118 "$851.00 to $900.99" 119 "$901.00 to $950.99"
                       120 "$951.00 to $1000.99" 121 "More than $1000.99"
                       990 "NOT ASKED THE QUESTIONS Logically assigned"
                       991 "NEVER USED MARIJUANA"
                       993 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define MMBUYWHO  1 "A friend" 2 "A relative or family member"
                       3 "Someone I had just met or didn't know well"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMBPLACE  1 "Inside a public bldg, such as a store, restaurant"
                       2 "Inside a school building"
                       3 "Outside on school property"
                       4 "Inside a home, apartment, or dorm"
                       5 "Outside in a public area, such as a parking lot"
                       6 "Some other place" 91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMBATJOB  1 "Yes" 2 "No" 3 "Do not work at a job or business"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMBCLOSE  1 "Near where you are now living" 2 "Somewhere else"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMBSELL   1 "Yes" 2 "No" 91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMBGIVE   1 "Yes" 2 "No" 91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMTRADE   1 "Yes" 2 "No" 91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMTRD30D  1 "Yes" 2 "No" 91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMTRDREC  1 "DATE FILL"
                       2 "More than 30 days ago, but within the past 12 mos"
                       3 "More than 12 months ago" 91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMT30FRQ  91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMTJNTLS  1 "You got joints"
                       2 "You got the marijuana in loose form"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMTJNTNM  991 "NEVER USED MARIJUANA"
                       993 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define MMTJWRCB  1 "less than $5.00" 2 "$5.00 to $10.99"
                       3 "$11.00 to $20.99" 4 "$21.00 to $50.99"
                       6 "$101.00 to $150.99" 10 "$301.00 to $500.99"
                       12 "More than $1000.99" 91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMTJWRTH  1 "Less than $5.00" 2 "$5.00 to $10.99"
                       3 "$11.00 to $20.99" 41 "$21.00 to $30.99"
                       42 "$31.00 to $40.99" 43 "$41.00 to $50.99"
                       63 "$121.00 to $130.99" 102 "$351.00 to $400.99"
                       121 "More than $1000.99" 991 "NEVER USED MARIJUANA"
                       993 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define MMTLUNIT  1 "Grams" 2 "Ounces" 3 "Pounds"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMTLGMS   1 "At least 1 but less than 5 grams"
                       2 "At least 5 but less than 10 grams"
                       3 "10 grams or more" 91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMTLOZS   1 "At least 1/8, but less than 1/4 of an ounce"
                       2 "At least 1/4 but less than 1/3 of an ounce"
                       3 "At least 1/3 but less than 1/2 of an ounce"
                       4 "At least 1/2 but less than 1 ounce"
                       5 "At least 1 but less than 5 ounces"
                       6 "At least 5 but less than 10 ounces"
                       7 "At least 10 but less than 16 ounces"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMTLWRCB  1 "less than $5.00" 2 "$5.00 to $10.99"
                       3 "$11.00 to $20.99" 4 "$21.00 to $50.99"
                       5 "$51.00 to $100.99" 6 "$101.00 to $150.99"
                       7 "$151.00 to $200.99" 9 "$251.00 to $300.99"
                       10 "$301.00 to $500.99" 11 "$501.00 to $1000.99"
                       12 "More than $1000.99"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMTLWRTH  1 "Less than $5.00" 2 "$5.00 to $10.99"
                       3 "$11.00 to $20.99" 41 "$21.00 to $30.99"
                       42 "$31.00 to $40.99" 43 "$41.00 to $50.99"
                       51 "$51.00 to $60.99" 52 "$61.00 to $70.99"
                       54 "$81.00 to $90.99" 61 "$101.00 to $110.99"
                       63 "$121.00 to $130.99" 65 "$141.00 to $150.99"
                       70 "$151.00 to $200.99" 90 "$251.00 to $300.99"
                       102 "$351.00 to $400.99" 104 "$451.00 to $500.99"
                       111 "$501.00 to $550.99" 121 "More than $1000.99"
                       990 "NOT ASKED THE QUESTIONS Logically assigned"
                       991 "NEVER USED MARIJUANA"
                       993 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define MMTRDWHO  1 "A friend" 2 "A relative or family member"
                       3 "Someone I had just met or didn't know well"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMTPLACE  1 "Inside a public bldg, such as a store, restaurant"
                       2 "Inside a school building"
                       3 "Outside on school property"
                       4 "Inside a home, apartment, or dorm"
                       5 "Outside in a public area, such as a parking lot"
                       6 "Some other place" 91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMTCLOSE  1 "Near where you are now living" 2 "Somewhere else"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMTKEEP   1 "Yes" 2 "No" 91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMTSELL   1 "Yes" 2 "No" 91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMTGIVE   1 "Yes" 2 "No" 91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMGKEEP   1 "Yes" 2 "No" 91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMGSELL   1 "Yes" 2 "No" 91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMGGIVE   1 "Yes" 2 "No" 91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMFREWHO  1 "A friend" 2 "A relative or family member"
                       3 "Someone I had just met or didn't know well"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMFPLACE  1 "Inside a public bldg, such as a store, restaurant"
                       2 "Inside a school building"
                       3 "Outside on school property"
                       4 "Inside a home, apartment, or dorm"
                       5 "Outside in a public area, such as a parking lot,"
                       6 "Some other place" 91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMFCLOSE  1 "Near where you are now living" 2 "Somewhere else"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMFKEEP   1 "Yes" 2 "No" 91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMFSELL   1 "Yes" 2 "No" 91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MMFGIVE   1 "Yes" 2 "No" 91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MONTHS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXEVER    1 "Yes" 2 "No"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TXYREVER  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       4 "No LOGICALLY ASSIGNED"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXYRADG   1 "Alcohol use only" 2 "Drug use only"
                       3 "Both alcohol and drug use"
                       5 "Drugs (alcohol trmt unknown) LOGICALLY ASSIGNED"
                       11 "Alcohol only (but last tmt for drugs reported)"
                       12 "Drugs only (but last tmt for alc reported)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXYRHOSP  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       5 "Yes LOGICALLY ASSIGNED (from TXLTYMN2)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXYRHPAD  1 "Alcohol use" 2 "Drug use"
                       3 "Both alcohol and drug use"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXYRRFIN  1 "Yes" 2 "No"
                       5 "Yes LOGICALLY ASSIGNED (from TXLTYMN2)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXYRINAD  1 "Alcohol use" 2 "Drug use"
                       3 "Both alcohol and drug use"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXYRRFOP  1 "Yes" 2 "No"
                       5 "Yes LOGICALLY ASSIGNED (from TXLTYMN2)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXYRPOAD  1 "Alcohol use" 2 "Drug use"
                       3 "Both alcohol and drug use"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXYRMHC   1 "Yes" 2 "No"
                       5 "Yes LOGICALLY ASSIGNED (from TXLTYMN2)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXYRMHAD  1 "Alcohol use" 2 "Drug use"
                       3 "Both alcohol and drug use"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXYRTXER  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       5 "Yes LOGICALLY ASSIGNED (from TXLTYMN2)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXYRERAD  1 "Alcohol use" 2 "Drug use"
                       3 "Both alcohol and drug use"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXYRDOC   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       5 "Yes LOGICALLY ASSIGNED (from TXLTYMN2)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXYRDCAD  1 "Alcohol use" 2 "Drug use"
                       3 "Both alcohol and drug use"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXYRJAIL  1 "Yes" 2 "No"
                       5 "Yes LOGICALLY ASSIGNED (from TXLTYMN2)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXYRJLAD  1 "Alcohol use" 2 "Drug use"
                       3 "Both alcohol and drug use"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXYRSHG   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       5 "Yes LOGICALLY ASSIGNED (from TXLTYMN2)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXYRSGAD  1 "Alcohol use" 2 "Drug use"
                       3 "Both alcohol and drug use"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXYRSOP   1 "Yes" 2 "No"
                       5 "Yes LOGICALLY ASSIGNED (from TXLTYMN2)"
                       7 "Treatment location unknown, LOG ASSN"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXYROTS2  9 "Some other place, not categorized elsewhere"
                       21 "Hospital inpatient overnight"
                       24 "Mental health center or facility as outpatient"
                       26 "Private doctor's office" 28 "Self-help group"
                       40 "Home, family, friends" 41 "School, college"
                       42 "Church/religious/spiritual influence"
                       44 "Halfway house/group home"
                       45 "Rehab/intervention fac/prgrm, ptnt status unspcfd"
                       47 "Community/city/county/state program, unspecified"
                       48 "Counselor, therapist, psychologist"
                       49 "Court-mandated/sponsored program"
                       51 "Alcohol/drug class, location unspecified"
                       53 "Hospital, patient status unspecified"
                       54 "On the job, Job Corp, EAP"
                       55 "Youth-oriented facility/organization/program"
                       58 "Other individual, relationship unspecified"
                       64 "Methadone clinic/program"
                       65 "Name of facility/program given"
                       981 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED ALCOHOL OR DRUGS" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define TXYROTAD  1 "Alcohol use" 2 "Drug use"
                       3 "Both alcohol and drug use"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXYRVSER  1 "Yes" 2 "No" 6 "NEVER USED RELEVANT DRUGS"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXYRNME2  981 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       991 "NEVER USED ALCOHOL OR DRUGS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define TXRCVNOW  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define NDTXNEDR  1 "Yes" 2 "No" 11 "Yes (TXYREVER=3)"
                       12 "No (TXYREVER=3)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NDTXMORE  1 "Yes" 2 "No"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NDTMRALC  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NDTMRMJ   1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NDTMRCOC  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NDTMRHER  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NDTMRHAL  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NDTMRINH  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NDTMRANL  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NDTMRTRN  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NDTMRSTM  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NDTMRSED  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NDTMROTH  1 "Response entered" 6 "Response not entered"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NDTXALCR  1 "Yes" 2 "No" 11 "Yes (TXYREVER=3)"
                       12 "No (TXYREVER=3)"
                       13 "Yes LOGICALLY ASSIGNED (TXYREVER=3)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define NDTXMJR   1 "Yes" 2 "No" 11 "Yes (TXYREVER=3)"
                       12 "No (TXYREVER=3)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define NDTXCOCR  1 "Yes" 2 "No" 11 "Yes (TXYREVER=3)"
                       12 "No (TXYREVER=3)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define NDTXHERR  1 "Yes" 2 "No" 11 "Yes (TXYREVER=3)"
                       12 "No (TXYREVER=3)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define NDTXHALR  1 "Yes" 2 "No" 11 "Yes (TXYREVER=3)"
                       12 "No (TXYREVER=3)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define NDTXINHR  1 "Yes" 2 "No" 11 "Yes (TXYREVER=3)"
                       12 "No (TXYREVER=3)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define NDTXANLR  1 "Yes" 2 "No" 11 "Yes (TXYREVER=3)"
                       12 "No (TXYREVER=3)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define NDTXTRNR  1 "Yes" 2 "No" 11 "Yes (TXYREVER=3)"
                       12 "No (TXYREVER=3)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define NDTXSTMR  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       11 "Yes (TXYREVER=3)" 12 "No (TXYREVER=3)"
                       13 "Yes LOGICALLY ASSIGNED (TXYREVER=3)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define NDTXSEDR  1 "Yes" 2 "No" 12 "No (TXYREVER=3)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define NDTXSODR  1 "Yes" 2 "No" 5 "Drug Unknown LOGICALLY ASSIGNED"
                       11 "Yes (TXYREVER=3)" 12 "No (TXYREVER=3)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NDTXDG1R  322 "Methamphetamine ('ice' or 'crank'), Meth"
                       355 "Crystal meth"
                       803 "Marijuana, MarrJane, Mary Jane, MJ, pot, weed,he"
                       3068 "Mini Two-way Action <OTC>"
                       9981 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED ALCOHOL OR DRUGS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define NDTXDG2R  805 "Cocaine, coca, coca8na, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champagne"
                       9981 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED ALCOHOL OR DRUGS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define NDTXDG3R  3050 "Mini Thins"
                       9981 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED ALCOHOL OR DRUGS" 9994 "DON'T KNOW"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)"
                       9999 "LEGITIMATE SKIP" ;
label define NDTXDG4R  9981 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED ALCOHOL OR DRUGS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define NDTXDG5R  9981 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED ALCOHOL OR DRUGS" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define NDTXEFTR  1 "Yes" 2 "No" 11 "Yes (see note)"
                       12 "No (TXYREVER=3)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define NDTMREFT  1 "Yes" 2 "No"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXLASREC  1 "Within the past 30 days -- that is, since DATEFILL"
                       2 "More than 30 days ago but within the past 12 mos"
                       3 "More than 12 months ago"
                       7 "Still in treatment LOG ASSN (TXRCVNOW=1)"
                       8 "Treatment in past year LOGICALLY ASSIGNED"
                       9 "Treatment in lifetime LOGICALLY ASSIGNED"
                       13 "Treatment > 12 mos ago LOG ASSN (TXYREVER=2)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXLTYMN2  1 "A hospital overnight as an inpatient"
                       2 "A res drug/alcohol rehab facility overnight"
                       3 "A drug or alcohol rehab facility as an outpatient"
                       4 "A mental health center or facility as outpatient"
                       5 "An emergency room" 6 "A private doctor's office"
                       7 "A prison or jail" 8 "A self-help group"
                       9 "Some other place" 40 "Home, family, friends"
                       41 "School, college"
                       48 "Counselor, therapist, psychologist"
                       49 "Court-mandated/sponsored program"
                       51 "Alcohol/drug class, location unspecified"
                       54 "On the job, Job Corp, EAP"
                       65 "Name of facility/program given"
                       981 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED ALCOHOL OR DRUGS" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define TXLTYALC  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       5 "Yes LOG ASSN (TXYRADG = 1)"
                       6 "NEVER USED ALCOHOL (TXEVER = 1)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)" ;
label define TXLTYMJ   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       6 "NEVER USED MARIJUANA (TXEVER = 1)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)" ;
label define TXLTYCOC  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       6 "NEVER USED COCAINE (TXEVER = 1)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)" ;
label define TXLTYHER  1 "Yes" 2 "No" 6 "NEVER USED HEROIN (TXEVER = 1)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)" ;
label define TXLTYHAL  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       6 "NEVER USED HALLUCINOGENS (TXEVER = 1)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)" ;
label define TXLTYINH  1 "Yes" 2 "No" 6 "NEVER USED INHALANTS (TXEVER = 1)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)" ;
label define TXLTYANL  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       6 "NEVER USED PAIN RELIEVERS (TXEVER = 1)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)" ;
label define TXLTYTRN  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       6 "NEVER USED TRANQUILIZERS (TXEVER = 1)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)" ;
label define TXLTYSTM  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       6 "NEVER USED STIMULANTS (TXEVER = 1)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)" ;
label define TXLTYSED  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       6 "NEVER USED SEDATIVES (TXEVER = 1)"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)" ;
label define TXLTYSOD  1 "Yes" 2 "No"
                       5 "Treatment drug unknown, LOGICALLY ASSIGNED"
                       7 "Treatment drug/alc unknown LOG ASSN"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXLTYOU2  1 "You are still in treatment"
                       2 "You successfully completed treatment"
                       3 "You left because you had a problem with program"
                       4 "You left b/c you couldn't afford to continue"
                       5 "You left because your family needed you"
                       6 "You left because you began using drugs again"
                       7 "Your last treatment had some other outcome"
                       41 "You left because you didn't need/want treatment"
                       44 "You relapsed/program did not work for you"
                       48 "Discontinued treatment, success unknown"
                       49 "Completed treatment, outcome unknown"
                       50 "You had other problems to deal with"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXLTYDU2  31 "31 or more"
                       99981 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       99985 "BAD DATA Logically assigned"
                       99991 "NEVER USED ALCOHOL OR DRUGS" 99994 "DON'T KNOW"
                       99997 "REFUSED" 99998 "BLANK (NO ANSWER)"
                       99999 "LEGITIMATE SKIP" ;
label define TXPYINS   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXPYCARE  1 "Yes" 2 "No"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXPYCAID  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXPYPUBP  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXPYSAVE  1 "Yes" 2 "No"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXPYFMLY  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXPYCORT  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXPYMILC  1 "Yes" 2 "No"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXPYEMPL  1 "Yes" 2 "No"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXPYSOS   1 "Yes" 2 "No" 4 "No LOG ASSN (free trmt specified)"
                       5 "Yes, payment source not specified LOG ASSN"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXPYSP2   1 "Private health insurance" 3 "Medicaid"
                       4 "Public assistance program other than Medicaid"
                       5 "Own savings or earnings" 6 "Family members"
                       7 "Courts" 10 "Free" 11 "Some other source"
                       12 "Friend/sponsor" 14 "School" 15 "Treatment program"
                       19 "Public assistance, unspecified"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXPYFRE   1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TXENROLL  1 "Yes" 2 "No"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (TXEVER=2)" ;
label define TXYRDTXO  1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       81 "NEVER USED ALCOHOL OR DRUGS Logically assigned"
                       91 "NEVER USED ALCOHOL OR DRUGS" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SPECTILL  0 "No/Unknown (Otherwise)" 1 "Yes (See comment above)" ;
label define SPECTALC  0 "No/Unknown (Otherwise)" 1 "Yes (See comment above)" ;
label define SPILLALC  0 "No/Unknown (Otherwise)" 1 "Yes (See comment above)" ;
label define ILLNEED   0 "No/Unknown (Otherwise)" 1 "Yes (See comment above)" ;
label define TXNOSPEC  0 "No/Unknown (Otherwise)"
                       1 "Yes (ILLNEED=1 and SPECTILL=0)" ;
label define ALCTRMT   0 "No/Unknown (TXYRADG=2,5,81,85,91,94,97,99)"
                       1 "Yes (TXYRADG=1,3,11,12)" ;
label define ILLTRMT   0 "No/Unknown (TXYRADG=1,81,85,91,94,97,98,99)"
                       1 "Yes (TXYRADG=2,3,5,11,12)" ;
label define TXILLALC  0 "No/Unknown (TXYREVER=2,4,81,85,91,94,97,98,99)"
                       1 "Yes (TXYREVER=1,3)" ;
label define TXILANAL  0 "No/Unknown (TXYRADG=1,2,5,81,85,91,94,97,98,99)"
                       1 "Yes (TXYRADG=3,11,12)" ;
label define TXLTMJ2   0 "No/Unknown (TXLTYMJ=2,6,81,85,91,97,98,99)"
                       1 "Yes (TXLTYMJ=1,3)" ;
label define TXLTCOC2  0 "No/Unknown (TXLTYCOC=2,6,81,85,91,94,97,98,99)"
                       1 "Yes (TXLTYCOC=1,3)" ;
label define TXLTHER2  0 "No/Unknown (TXLTYHER=2,6,81,85,91,97,98,99)"
                       1 "Yes (TXLTYHER=1)" ;
label define TXLTSTM2  0 "No/Unknown (TXLTYSTM=2,6,81,85,91,94,97,98,99)"
                       1 "Yes (TXLTYSTM=1,3)" ;
label define TXLTSED2  0 "No/Unknown (TXLTYSED=2,6,81,91,97,98,99)"
                       1 "Yes (TXLTYSED=1,3)" ;
label define TXLTANL2  0 "No/Unknown (TXLTYANL=2,6,81,85,91,94,97,98,99)"
                       1 "Yes (TXLTYANL=1,3)" ;
label define TXLTTRN2  0 "No/Unknown (TXLTYTRN=2,6,81,85,91,94,97,98,99)"
                       1 "Yes (TXLTYTRN=1,3)" ;
label define TXLTHAL2  0 "No/Unknown (TXLTYHAL=2,6,81,85,91,94,97,98,99)"
                       1 "Yes (TXLTYHAL=1,3)" ;
label define TXLTINH2  0 "No/Unknown (TXLTYINH=2,6,81,85,91,94,97,98,99)"
                       1 "Yes (TXLTYINH=1)" ;
label define TXLTALC2  0 "No/Unknown (TXLTYALC=2,6,81,85,91,94,97,98,99)"
                       1 "Yes (TXLTYALC=1,3,5)" ;
label define TXLTILL2  0 "No/Unknown (Otherwise)"
                       1 "Yes (ANY SOURCE VARIABLE=1)" ;
label define TXPINS2   0 "No/Unknown (TXPYINS=2,81,85,91,94,97,98,99)"
                       1 "Yes (TXPYINS=1,3)" ;
label define TXPCARE2  0 "No/Unknown (TXPYCARE=2,81,85,91,94,97,98,99)"
                       1 "Yes (TXPYCARE=1)" ;
label define TXPCAID2  0 "No/Unknown (TXPYCAID=2,81,85,91,94,97,98,99)"
                       1 "Yes (TXPYCAID=1,3)" ;
label define TXPPUBP2  0 "No/Unknown (TXPYPUBP=2,81,85,91,94,97,98,99)"
                       1 "Yes (TXPYPUBP=1,3)" ;
label define TXPSAVE2  0 "No/Unknown (TXPYSAVE=2,81,85,91,94,97,98,99)"
                       1 "Yes (TXPYSAVE=1)" ;
label define TXPFMLY2  0 "No/Unknown (TXPYFMLY=2,81,85,91,94,97,98,99)"
                       1 "Yes (TXPYFMLY=1,3)" ;
label define TXPCORT2  0 "No/Unknown (TXPYCORT=2,81,85,91,94,97,98,99)"
                       1 "Yes (TXPYCORT=1,3)" ;
label define TXPMILC2  0 "No/Unknown (TXPYMILC=2,81,85,91,94,97,98,99)"
                       1 "Yes (TXPYMILC=1)" ;
label define TXPEMPL2  0 "No/Unknown (TXPYEMPL=2,81,85,91,94,97,98,99)"
                       1 "Yes (TXPYEMPL=1)" ;
label define ILLPINS   0 "No/Unknown (TXLTILL2=0 OR TXPINS2=0)"
                       1 "Yes (TXLTILL2=1 AND TXPINS2=1)" ;
label define ILLPCARE  0 "No/Unknown (TXLTILL2=0 OR TXPCARE2=0)"
                       1 "Yes (TXLTILL2=1 AND TXPCARE2=1)" ;
label define ILLPCAID  0 "No/Unknown (TXLTILL2=0 OR TXPCAID2=0)"
                       1 "Yes (TXLTILL2=1 AND TXPCAID2=1)" ;
label define ILLPPUBP  0 "No/Unknown (TXLTILL2=0 OR TXPPUBP2=0)"
                       1 "Yes (TXLTILL2=1 AND TXPPUBP2=1)" ;
label define ILLPSAVE  0 "No/Unknown (TXLTILL2=0 OR TXPSAVE2=0)"
                       1 "Yes (TXLTILL2=1 AND TXPSAVE2=1)" ;
label define ILLPFMLY  0 "No/Unknown (TXLTILL2=0 OR TXPFMLY2=0)"
                       1 "Yes (TXLTILL2=1 AND TXPFMLY2=1)" ;
label define ILLPCORT  0 "No/Unknown (TXLTILL2=0 OR TXPCORT2=0)"
                       1 "Yes (TXLTILL2=1 AND TXPCORT2=1)" ;
label define ILLPMILC  0 "No/Unknown (TXLTILL2=0 OR TXPMILC2=0)"
                       1 "Yes (TXLTILL2=1 AND TXPMILC2=1)" ;
label define ILLPEMPL  0 "No/Unknown (TXLTILL2=0 OR TXPEMPL2=0)"
                       1 "Yes (TXLTILL2=1 AND TXPEMPL2=1)" ;
label define ALCPINS   0 "No/Unknown (TXLTALC2=0 OR TXPINS2=0)"
                       1 "Yes (TXLTALC2=1 AND TXPINS2=1)" ;
label define ALCPCARE  0 "No/Unknown (TXLTALC2=0 OR TXPCARE2=0)"
                       1 "Yes (TXLTALC2=1 AND TXPCARE2=1)" ;
label define ALCPCAID  0 "No/Unknown (TXLTALC2=0 OR TXPCAID2=0)"
                       1 "Yes (TXLTALC2=1 AND TXPCAID2=1)" ;
label define ALCPPUBP  0 "No/Unknown (TXLTALC2=0 OR TXPPUBP2=0)"
                       1 "Yes (TXLTALC2=1 AND TXPPUBP2=1)" ;
label define ALCPSAVE  0 "No/Unknown (TXLTALC2=0 OR TXPSAVE2=0)"
                       1 "Yes (TXLTALC2=1 AND TXPSAVE2=1)" ;
label define ALCPFMLY  0 "No/Unknown (TXLTALC2=0 OR TXPFMLY2=0)"
                       1 "Yes (TXLTALC2=1 AND TXPFMLY2=1)" ;
label define ALCPCORT  0 "No/Unknown (TXLTALC2=0 OR TXPCORT2=0)"
                       1 "Yes (TXLTALC2=1 AND TXPCORT2=1)" ;
label define ALCPMILC  0 "No/Unknown (TXLTALC2=0 OR TXPMILC2=0)"
                       1 "Yes (TXLTALC2=1 AND TXPMILC2=1)" ;
label define ALCPEMPL  0 "No/Unknown (TXLTALC2=0 OR TXPEMPL2=0)"
                       1 "Yes (TXLTALC2=1 AND TXPEMPL2=1)" ;
label define DRGHOSP   0 "No/Unknown (Otherwise)"
                       1 "Yes (TXYRHOSP=1 AND TXYRHPAD=2,3)" ;
label define DRGRFIN   0 "No/Unknown (Otherwise)"
                       1 "Yes (TXYRRFIN=1 AND TXYRINAD=2,3)" ;
label define DRGRFOP   0 "No/Unknown (Otherwise)"
                       1 "Yes (TXYRRFOP=1 AND TXYRPOAD=2,3)" ;
label define DRGMHC    0 "No/Unknown (Otherwise)"
                       1 "Yes (TXYRMHC=1 AND TXYRMHAD=2,3)" ;
label define DRGTXER   0 "No/Unknown (Otherwise)"
                       1 "Yes (TXYRTXER=1 AND TXYRERAD=2,3)" ;
label define DRGDOC    0 "No/Unknown (Otherwise)"
                       1 "Yes (TXYRDOC=1 AND TXYRDCAD=2,3)" ;
label define DRGJAIL   0 "No/Unknown (Otherwise)"
                       1 "Yes (TXYRJAIL=1 AND TXYRJLAD=2,3)" ;
label define DRGSHG    0 "No/Unknown (Otherwise)"
                       1 "Yes (TXYRSHG=1 AND TXYRSGAD=2,3)" ;
label define ALCHOSP   0 "No/Unknown (Otherwise)"
                       1 "Yes (TXYRHOSP=1 AND TXYRHPAD=1,3)" ;
label define ALCRFIN   0 "No/Unknown (Otherwise)"
                       1 "Yes (TXYRRFIN=1 AND TXYRINAD=1,3)" ;
label define ALCRFOP   0 "No/Unknown (Otherwise)"
                       1 "Yes (TXYRRFOP=1 AND TXYRPOAD=1,3)" ;
label define ALCMHC    0 "No/Unknown (Otherwise)"
                       1 "Yes (TXYRMHC=1 AND TXYRMHAD=1,3)" ;
label define ALCTXER   0 "No/Unknown (Otherwise)"
                       1 "Yes (TXYRTXER=1 AND TXYRERAD=1,3)" ;
label define ALCDOC    0 "No/Unknown (Otherwise)"
                       1 "Yes (TXYRDOC=1 AND TXYRDCAD=1,3)" ;
label define ALCJAIL   0 "No/Unknown (Otherwise)"
                       1 "Yes (TXYRJAIL=1 AND TXYRJLAD=1,3)" ;
label define ALCSHG    0 "No/Unknown (Otherwise)"
                       1 "Yes (TXYRSHG=1 AND TXYRSGAD=1,3)" ;
label define LOCHOSP   0 "No/Unknown (TXYRHOSP=2,81,85,91,97,98,99)"
                       1 "Yes (TXYRHOSP=1,3,5)" ;
label define LOCRFIN   0 "No/Unknown (TXYRRFIN=2,81,85,91,94,97,98,99)"
                       1 "Yes (TXYRRFIN=1,3,5)" ;
label define LOCRFOP   0 "No/Unknown (TXYRRFOP=2,81,85,91,94,97,98,99)"
                       1 "Yes (TXYRRFOP=1,5)" ;
label define LOCMHC    0 "No/Unknown (TXYRMHC=2,81,85,91,94,97,98,99)"
                       1 "Yes (TXYRMHC=1,5)" ;
label define LOCTXER   0 "No/Unknown (TXYRTXER=2,81,85,91,97,98,99)"
                       1 "Yes (TXYRTXER=1,3,5)" ;
label define LOCDOC    0 "No/Unknown (TXYRDOC=2,81,85,91,94,97,98,99)"
                       1 "Yes (TXYRDOC=1,3,5)" ;
label define LOCJAIL   0 "No/Unknown (TXYRJAIL=2,81,85,91,97,98,99)"
                       1 "Yes (TXYRJAIL=1,5)" ;
label define LOCSHG    0 "No/Unknown (TXYRSHG=2,81,85,91,97,98,99)"
                       1 "Yes (TXYRSHG=1,3,5)" ;
label define PREGNANT  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define NMERTMT2  31 "31 or more" 985 "BAD DATA Logically assigned"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define INHOSPYR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define NMNGTHS2  31 "31 or more" 985 "BAD DATA Logically assigned"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DOMOSTYR  1 "Working at a job or business" 2 "Going to school"
                       3 "Keeping house" 4 "Doing something else"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PBLMWORK  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define LIMITWRK  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TYPEPBLM  1 "Physical problem" 2 "Mental or emotional problem"
                       3 "Both" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PREG      0 "Otherwise"
                       1 "Pregnant Females Aged 12-44 (PREGNANT=1)" ;
label define PREG2     -9 "Unknown (PREGNANT = 94,97,98)"
                       1 "Pregnant (PREGNANT=1)"
                       2 "Not Pregnant (PREGNANT=2)"
                       3 "Males/Females not age 12-44 (PREGNANT=99)" ;
label define TRIMEST   -9 "Unknown" 1 "1st 3 months of pregnancy"
                       2 "2nd 3 months of pregnancy"
                       3 "Last 3 months of pregnancy"
                       4 "Males/Not Pregnant Females" ;
label define AUINPYR   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUINPSYH  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUINPGEN  1 "Response entered" 6 "Response not entered"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUINMEDU  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUINAHSP  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUINRESD  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUINSFAC  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUNMPSY2  31 "31 or more" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define AUNMPGE2  31 "31 or more" 985 "BAD DATA Logically assigned"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define AUNMMED2  31 "31 or more" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define AUNMAHSP  997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define AUNMRES2  31 "31 or more" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define AUNMSFA2  31 "31 or more" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define AUPINSLF  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUPINOFM  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUPINPHI  1 "Response entered" 6 "Response not entered"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUPINMCR  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUPINMCD  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define AUPINREH  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUPINEMP  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUPINMIL  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUPINPUB  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUPINPRV  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUPINFRE  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUPINAMT  1 "Less than $100" 2 "$100 to $200" 3 "$201 to $500"
                       4 "$501 to $900" 5 "$901 to $1,500"
                       6 "$1,501 to $2,000" 7 "$2,001 to $5,000"
                       8 "More than $5,000" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define AUOPTYR   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUOPMENT  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUOPTHER  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUOPDOC   1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define AUOPCLNC  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUOPDTMT  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define AUOPOTOP  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUOPYRS2  2 "Non-clinic therapist/psychologist/counselor"
                       3 "A doctor's office that was not part of a clinic"
                       4 "An outpatient medical clinic"
                       5 "A partial day hospital or day treatment program"
                       6 "Some other place, not categorized elsewhere"
                       9 "School or university setting/clinic/center"
                       10 "Church/clergy/religious influence"
                       11 "Support group/self-help group/group counseling"
                       13 "Therapist/psychologist/counselor; locale unspecfd"
                       14 "A doctor's office; location unspecified"
                       15 "Work/parents' work/Employee Assistance Program"
                       16 "Domestic abuse shelter/victims assistance"
                       17 "Internet/phone/crisis hotline"
                       23 "Hospital; unspecified whether for mental health"
                       24 "Clinic/center, type unspecified"
                       27 "Non-profit mental health service grp/organization"
                       28 "Social Services/Mental Health"
                       70 "Name of facility/description of facility given"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define AUNMMEN2  31 "31 or more" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define AUNMTHE2  31 "31 or more" 985 "BAD DATA Logically assigned"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define AUNMDOC2  31 "31 or more" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define AUNMCLN2  31 "31 or more" 985 "BAD DATA Logically assigned"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define AUNMDTM2  31 "31 or more" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define AUNMOTO2  31 "31 or more" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define AUPOPSLF  1 "Response entered" 6 "Response not entered"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUPOPOFM  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define AUPOPPHI  1 "Response entered" 6 "Response not entered"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUPOPMCR  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUPOPMCD  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUPOPREH  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define AUPOPEMP  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUPOPMIL  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUPOPPUB  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define AUPOPPRV  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define AUPOPFRE  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUPOPMOS  1 "Self or a family member living with you"
                       2 "A family member who does not live with you"
                       3 "Private health insurance" 4 "Medicare" 5 "Medicaid"
                       6 "Rehabilitation program" 7 "Employer"
                       8 "VA or other military program"
                       9 "Other public source" 10 "Other private source"
                       11 "No one paid because the treatment was free"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUPOPAMT  1 "Less than $100" 2 "$100 to $200" 3 "$201 to $500"
                       4 "$501 to $900" 5 "$901 to $1,500"
                       6 "$1,501 to $2,000" 7 "$2,001 to $5,000"
                       8 "More than $5,000" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AURXYR    1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUUNMTYR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUUNCOST  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUUNNBR   1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUUNJOB   1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUUNNCOV  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUUNENUF  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUUNWHER  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUUNCFID  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUUNCMIT  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AUUNSOR   1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AMHINP    1 "Yes (AUINPYR=1)" 2 "No (AUINPYR=2)"
                       3 "Unknown (AUINPYR=85,94,97,98)"
                       4 "Aged 12-17 (AUINPYR=89,99)" ;
label define AMHOUTP   1 "Yes (AUOPTYR=1)" 2 "No (AUOPTYR=2)"
                       3 "Unknown (AUOPTYR=85,94,97,98)"
                       4 "Aged 12-17 (AUOPTYR=89,99)" ;
label define AMHRX     1 "Yes (AURXYR=1)" 2 "No (AURXYR=2)"
                       3 "Unknown (AURXYR=85,94,97,98)"
                       4 "Aged 12-17 (AURXYR=89,99)" ;
label define AMHTXREC  1 "Yes (AMHINP=1 OR AMHOUTP=1 OR AMHRX=1)"
                       2 "No (AMHINP=2 AND AMHOUTP=2 AND AMHRX=2)"
                       3 "Unknown (OTHERWISE)"
                       4 "Aged 12-17 (AMHINP=4 AND AMHOUTP=4 AND AMHRX=4)" ;
label define AMHTRTND  1 "Yes (AUUNMTYR=1)" 2 "No (AUUNMTYR=2)"
                       3 "Unknown (AUUNMTYR=85,94,97,98)"
                       4 "Aged 12-17 (AUUNMTYR=89,99)" ;
label define RECNEED   -9 "Unknown/Aged 12-17 (AMHTRTND=3,4 or AMHTXREC=3,4)"
                       0 "No (Otherwise)" 1 "Yes (AMHTRTND=1 and AMHTXREC=1)" ;
label define NORECNED  -9 "Unknown/Aged 12-17 (AMHTRTND=3,4 or AMHTXREC=3,4)"
                       0 "No (Otherwise)" 1 "Yes (AMHTRTND=1 and AMHTXREC=2)" ;
label define SNAPKCIG  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNAMJEVR  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNAALDLY  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNAALDRV  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNMOV5Y2  0 "None" 1 "One time" 2 "Two times" 3 "Three times"
                       4 "Four times" 5 "Five times" 6 "Six or more times"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define SNPPHHLD  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNINSULT  1 "Strongly Agree" 2 "Somewhat Agree"
                       3 "Somewhat Disagree" 4 "Strongly Disagree"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNSRARGU  1 "Strongly Agree" 2 "Somewhat Agree"
                       3 "Somewhat Disagree" 4 "Strongly Disagree"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNSMARGU  1 "Strongly Agree" 2 "Somewhat Agree"
                       3 "Somewhat Disagree" 4 "Strongly Disagree"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNSPOUSE  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNSPACTV  1 "0 times" 2 "1 or 2 times" 3 "A few times"
                       4 "Many times" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNSPANGR  1 "0 times" 2 "1 or 2 times" 3 "A few times"
                       4 "Many times" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNSPHITU  1 "0 times" 2 "1 or 2 times" 3 "A few times"
                       4 "Many times" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNYHITSP  1 "0 times" 2 "1 or 2 times" 3 "A few times"
                       4 "Many times" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNSPCRIT  1 "Always" 2 "Sometimes" 3 "Seldom" 4 "Never"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNSPCONC  1 "Always" 2 "Sometimes" 3 "Seldom" 4 "Never"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNFRCONC  1 "None" 2 "One" 3 "2 or 3" 4 "4 to 5" 5 "More than 5"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNFRACTV  1 "None" 2 "One" 3 "2 or 3" 4 "4 to 5" 5 "More than 5"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNFRCARE  1 "None" 2 "One" 3 "2 or 3" 4 "4 to 5" 5 "More than 5"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNYSELL   1 "0 times" 2 "1 or 2 times" 3 "3 to 5 times"
                       4 "6 to 9 times" 5 "10 or more times"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNYSTOLE  1 "0 times" 2 "1 or 2 times" 3 "3 to 5 times"
                       4 "6 to 9 times" 5 "10 or more times"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNYATTAK  1 "0 times" 2 "1 or 2 times" 3 "3 to 5 times"
                       4 "6 to 9 times" 5 "10 or more times"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNYDFAST  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNY50LBS  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNYINJUR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNYSTERD  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNYRRXNG  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNYLAXTV  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNYPASNS  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNYFIRE   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNFACIG   1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNFAMJEV  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNFAALDY  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNFAALDV  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNFDCIG   1 "None of them" 2 "A few of them" 3 "Most of them"
                       4 "All of them"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNFDMJ    1 "None of them" 2 "A few of them" 3 "Most of them"
                       4 "All of them"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNFDALC   1 "None of them" 2 "A few of them" 3 "Most of them"
                       4 "All of them"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNFDDRNK  1 "None of them" 2 "A few of them" 3 "Most of them"
                       4 "All of them"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNRLGSVC  1 "0 times" 2 "1 to 2 times" 3 "3 to 5 times"
                       4 "6 to 24 times" 5 "25 to 52 times"
                       6 "More than 52 times"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNRLGIMP  1 "Strongly Disagree" 2 "Disagree" 3 "Agree"
                       4 "Strongly Agree"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNRLDCSN  1 "Strongly Disagree" 2 "Disagree" 3 "Agree"
                       4 "Strongly Agree"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SNRLFRND  1 "Strongly Disagree" 2 "Disagree" 3 "Agree"
                       4 "Strongly Agree"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEMOV5Y2  0 "None" 1 "One time" 2 "Two times" 3 "Three times"
                       4 "Four times" 5 "Five times" 6 "Six or more times"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define YEATNDYR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEHMSLYR  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YESCHFLT  1 "You liked going to school a lot"
                       2 "You kind of liked going to school"
                       3 "You didn't like going to school very much"
                       4 "You hated going to school"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YESCHWRK  1 "Always" 2 "Sometimes" 3 "Seldom" 4 "Never"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YESCHIMP  1 "Very important" 2 "Somewhat important"
                       3 "Somewhat unimportant" 4 "Very unimportant"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YESCHINT  1 "Very interesting" 2 "Somewhat interesting"
                       3 "Somewhat boring" 4 "Very boring"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YETCGJOB  1 "Always" 2 "Sometimes" 3 "Seldom" 4 "Never"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YELSTGRD  1 "An 'A+', 'A' or 'A-minus' average"
                       2 "A 'B+', 'B' or 'B-minus' average"
                       3 "A 'C+', 'C' or 'C-minus' average"
                       4 "A 'D' or less than a 'D' average"
                       5 "My school does not give these grades"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YESTSCIG  1 "None of them" 2 "A few of them" 3 "Most of them"
                       4 "All of them" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YESTSMJ   1 "None of them" 2 "A few of them" 3 "Most of them"
                       4 "All of them" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YESTSALC  1 "None of them" 2 "A few of them" 3 "Most of them"
                       4 "All of them" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YESTSDNK  1 "None of them" 2 "A few of them" 3 "Most of them"
                       4 "All of them" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPCHKHW  1 "Always" 2 "Sometimes" 3 "Seldom" 4 "Never"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPHLPHW  1 "Always" 2 "Sometimes" 3 "Seldom" 4 "Never"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPCHORE  1 "Always" 2 "Sometimes" 3 "Seldom" 4 "Never"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPLMTTV  1 "Always" 2 "Sometimes" 3 "Seldom" 4 "Never"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPLMTSN  1 "Always" 2 "Sometimes" 3 "Seldom" 4 "Never"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPGDJOB  1 "Always" 2 "Sometimes" 3 "Seldom" 4 "Never"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPPROUD  1 "Always" 2 "Sometimes" 3 "Seldom" 4 "Never"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEYARGUP  1 "0 times" 2 "1 or 2 times" 3 "3 to 5 times"
                       4 "6 to 9 times" 5 "10 or more times"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEYFGTSW  1 "0 times" 2 "1 or 2 times" 3 "3 to 5 times"
                       4 "6 to 9 times" 5 "10 or more times"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEYFGTGP  1 "0 times" 2 "1 or 2 times" 3 "3 to 5 times"
                       4 "6 to 9 times" 5 "10 or more times"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEYHGUN   1 "0 times" 2 "1 or 2 times" 3 "3 to 5 times"
                       4 "6 to 9 times" 5 "10 or more times"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEYSELL   1 "0 times" 2 "1 or 2 times" 3 "3 to 5 times"
                       4 "6 to 9 times" 5 "10 or more times"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEYSTOLE  1 "0 times" 2 "1 or 2 times" 3 "3 to 5 times"
                       4 "6 to 9 times" 5 "10 or more times"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEYATTAK  1 "0 times" 2 "1 or 2 times" 3 "3 to 5 times"
                       4 "6 to 9 times" 5 "10 or more times"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEYRNAWY  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEY50LBS  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEYINJUR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEYSTERD  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEYRRXNG  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEYLAXTV  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEYHACK   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEYFIRE   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPPKCIG  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPMJEVR  1 "Neither Approve or Disapprove"
                       2 "Somewhat Disapprove" 3 "Strongly Disapprove"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPMJMO   1 "Neither Approve or Disapprove"
                       2 "Somewhat Disapprove" 3 "Strongly Disapprove"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPALDLY  1 "Neither Approve or Disapprove"
                       2 "Somewhat Disapprove" 3 "Strongly Disapprove"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEGPKCIG  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEGMJEVR  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEGMJMO   1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEGALDLY  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEFPKCIG  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEFMJEVR  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEFMJMO   1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEFALDLY  1 "Neither approve nor disapprove"
                       2 "Somewhat disapprove" 3 "Strongly disapprove"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YETLKNON  1 "Response entered" 6 "Response not entered"
                       11 "Response entered (& other responses entered)"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YETLKPAR  1 "Response entered" 6 "Response not entered"
                       11 "Response entered (YETLKNON=11)" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YETLKBGF  1 "Response entered" 6 "Response not entered"
                       11 "Response entered (YETLKNON=11)" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YETLKOTA  1 "Response entered" 6 "Response not entered"
                       11 "Response entered (YETLKNON=11)" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YETLKSOP  1 "Response entered" 6 "Response not entered"
                       11 "Response entered (YETLKNON=11)" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPRTDNG  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPRBSLV  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEVIOPRV  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEDGPRGP  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YESLFHLP  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPRGSTD  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YESCHACT  0 "None" 1 "One" 2 "Two" 3 "3 or more"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YECOMACT  0 "None" 1 "One" 2 "Two" 3 "3 or more"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEFAIACT  0 "None" 1 "One" 2 "Two" 3 "3 or more"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEOTHACT  0 "None" 1 "One" 2 "Two" 3 "3 or more"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEDECLAS  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEDERGLR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEDESPCL  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPVNTYR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YERLGSVC  1 "0 times" 2 "1 to 2 times" 3 "3 to 5 times"
                       4 "6 to 24 times" 5 "25 to 52 times"
                       6 "More than 52 times"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YERLGIMP  1 "Strongly Disagree" 2 "Disagree" 3 "Agree"
                       4 "Strongly Agree" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YERLDCSN  1 "Strongly Disagree" 2 "Disagree" 3 "Agree"
                       4 "Strongly Agree" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YERLFRND  1 "Strongly Disagree" 2 "Disagree" 3 "Agree"
                       4 "Strongly Agree" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YECGFRND  1 "0 times" 2 "1 time" 3 "2 times" 4 "3 to 5 times"
                       5 "6 to 9 times" 6 "10 or more times"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YECGVEND  1 "0 times" 2 "1 time" 3 "2 times" 4 "3 to 5 times"
                       5 "6 to 9 times" 6 "10 or more times"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YECGMAI2  1 "0 times" 2 "1 time" 3 "2 times" 4 "3 to 5 times"
                       5 "6 or more times" 91 "NEVER USED CIGARETTES"
                       93 "DID NOT USE CIGARETTES IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YECGCHKO  1 "0 times" 2 "1 time" 3 "2 times" 4 "3 to 5 times"
                       5 "6 to 9 times" 6 "10 or more times"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YECGCLRK  1 "0 times" 2 "1 time" 3 "2 times" 4 "3 to 5 times"
                       5 "6 to 9 times" 6 "10 or more times"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YECGINET  1 "0 times" 2 "1 time" 3 "2 times" 4 "3 to 5 times"
                       5 "6 to 9 times" 6 "10 or more times"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YECGSMKT  1 "0 times" 2 "1 time" 3 "2 times" 4 "3 to 5 times"
                       5 "6 to 9 times" 6 "10 or more times"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YECGDSTO  1 "0 times" 2 "1 time" 3 "2 times" 4 "3 to 5 times"
                       5 "6 to 9 times" 6 "10 or more times"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YECGCONV  1 "0 times" 2 "1 time" 3 "2 times" 4 "3 to 5 times"
                       5 "6 to 9 times" 6 "10 or more times"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YECGINDV  1 "0 times" 2 "1 time" 3 "2 times" 4 "3 to 5 times"
                       5 "6 to 9 times" 6 "10 or more times"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YECGPRUF  1 "Yes" 2 "No"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YECGSUCC  1 "Yes" 2 "No"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPKCRTN  1 "Pack" 2 "Carton"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPDPACK  1 "Less than $1.00" 2 "$1.00 - $1.50"
                       3 "$1.51 - $2.00" 4 "$2.01 - $2.50" 5 "$2.51 - $3.00"
                       6 "$3.01 - $3.50" 7 "$3.51 - $4.00" 8 "$4.01 - $4.50"
                       9 "$4.51 - $5.00" 10 "More than $5.00"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEPDCRTN  1 "Less than $10.00" 2 "$10.00 - $13.00"
                       3 "$13.01 - $16.00" 4 "$16.01 - $19.00"
                       5 "$19.01 - $22.00" 6 "$22.01 - $25.00"
                       7 "$25.01 - $28.00" 8 "$28.01 - $31.00"
                       9 "$31.01 - $34.00" 10 "$34.01 - $37.00"
                       11 "$37.01 - $40.00" 12 "$40.01 - $43.00"
                       14 "$46.01 - $49.00" 15 "More than $49.00"
                       91 "NEVER USED CIGARETTES/SPECIALTY CIGARETTES"
                       93 "DID NOT USE CIGS/SPECIALTY CIGS IN THE PAST 30 DYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEBLNTEV  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YEBLNT30  1 "Yes" 2 "No" 11 "Yes (YEBL30FQ=0)" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YEBL30FQ  0 "0 days (YEBLNT30=11)" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YECGRWMJ  1 "Yes" 2 "No" 91 "NEVER USED CIGARS"
                       93 "DID NOT USE CIGARS IN THE PAST 30 DAYS"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MVIN5YR2  -9 "Otherwise (YEMOV5YR=994,997,998,999)"
                       1 "More than 1 time (YEMOV5YR=2 to 90)"
                       2 "None or one time (YEMOV5YR=0,1)" ;
label define PRPKCIG2  -9 "Otherwise (YEPPKCIG=94,97,98,99)"
                       1 "Strongly disapprove (YEPPKCIG=3)"
                       2 "Somewhat disapprove or neither (YEPPKCIG=1,2)" ;
label define PRMJEVR2  -9 "Otherwise (YEPMJEVR=94,97,98,99)"
                       1 "Strongly disapprove (YEPMJEVR=3)"
                       2 "Somewhat disapprove or neither (YEPMJEVR=1,2)" ;
label define PRALDLY2  -9 "Otherwise (YEPALDLY=94,97,98,99)"
                       1 "Strongly disapprove (YEPALDLY=3)"
                       2 "Somewhat disapprove or neither (YEPALDLY=1,2)" ;
label define PRTALK3   -9 "Otherwise (YEPRTDNG=85,94,97,98,99)"
                       1 "Yes (YEPRTDNG=1)" 2 "No (YEPRTDNG=2)" ;
label define YOFIGHT2  -9 "Otherwise (YEYFGTSW=85,94,97,98,99)"
                       1 "One or more times (YEYFGTSW=2,3,4,5)"
                       2 "None (YEYFGTSW=1)" ;
label define YOGRPFT2  -9 "Otherwise (YEYFGTGP=85,94,97,98,99)"
                       1 "One or more times (YEYFGTGP=2,3,4,5)"
                       2 "None (YEYFGTGP=1)" ;
label define YOHGUN2   -9 "Otherwise (YEYHGUN=85,94,97,98,99)"
                       1 "One or more times (YEYHGUN=2,3,4,5)"
                       2 "None (YEYHGUN=1)" ;
label define YOSELL2   -9 "Otherwise (YEYSELL=85,94,97,98,99)"
                       1 "One or more times (YEYSELL=2,3,4,5)"
                       2 "None (YEYSELL=1)" ;
label define YOSTOLE2  -9 "Otherwise (YEYSTOLE=85,94,97,98,99)"
                       1 "One or more times (YEYSTOLE=2,3,4,5)"
                       2 "None (YEYSTOLE=1)" ;
label define YOATTAK2  -9 "Otherwise (YEYATTAK=85,94,97,98,99)"
                       1 "One or more times (YEYATTAK=2,3,4,5)"
                       2 "None (YEYATTAK=1)" ;
label define YFLPKCG2  -9 "Otherwise (YEGPKCIG=94,97,98,99)"
                       1 "Somewhat or strongly disapprove (YEGPKCIG=2,3)"
                       2 "Neither approve or disapprove (YEGPKCIG=1)" ;
label define YFLTMRJ2  -9 "Otherwise (YEGMJEVR=94,97,98,99)"
                       1 "Somewhat or strongly disapprove (YEGMJEVR=2,3)"
                       2 "Neither approve or disapprove (YEGMJEVR=1)" ;
label define YFLADLY2  -9 "Otherwise (YEGALDLY=94,97,98,99)"
                       1 "Somewhat or strongly disapprove (YEGALDLY=2,3)"
                       2 "Neither approve or disapprove (YEGALDLY=1)" ;
label define PRBSOLV2  -9 "Otherwise (YEPRBSLV=85,94,97,98,99)"
                       1 "Yes (YEPRBSLV=1)" 2 "No (YEPRBSLV=2)" ;
label define PREVIOL2  -9 "Otherwise (YEVIOPRV=85,94,97,98,99)"
                       1 "Yes (YEVIOPRV=1)" 2 "No (YEVIOPRV=2)" ;
label define PRVDRGO2  -9 "OTHERWISE (YEDGPRGP=85,94,97,98,99)"
                       1 "YES (YEDGPRGP=1)" 2 "NO (YEDGPRGP=2)" ;
label define GRPCNSL2  -9 "Otherwise (YESLFHLP=85,94,97,98,99)"
                       1 "Yes (YESLFHLP=1)" 2 "No (YESLFHLP=2)" ;
label define PREGPGM2  -9 "Otherwise (YEPRGSTD=85,94,97,98,99)"
                       1 "Yes (YEPRGSTD=1)" 2 "No (YEPRGSTD=2)" ;
label define DGSPCLS2  -9 "Otherwise (YEDECLAS=85,94,97,98,99)"
                       1 "Yes (YEDECLAS=1)" 2 "No (YEDECLAS=2)" ;
label define DGRGCLS2  -9 "Otherwise (YEDERGLR=85,94,97,98,99)"
                       1 "Yes (YEDERGLR=1)" 2 "No (YEDERGLR=2)" ;
label define DRGLECT2  -9 "Otherwise (YEDESPCL=85,94,97,98,99)"
                       1 "Yes (YEDESPCL=1)" 2 "No (YEDESPCL=2)" ;
label define DRPRVME3  -9 "Otherwise (YEPVNTYR=85,94,97,98,99)"
                       1 "Yes (YEPVNTYR=1)" 2 "No (YEPVNTYR=2)" ;
label define ANYEDUC3  -9 "OTHERWISE"
                       1 "Yes (DGSPCLS2=1 OR DGRGCLS2=1 OR DRGLECT2=1)"
                       2 "No (DGSPCLS2=2 & DGRGCLS2=2 & DRGLECT2=2)" ;
label define CIGFRND   -9 "Aged 18 or Older (YECGFRND=99)"
                       0 "Otherwise (YECGFRND=1,91,93,94,97,98)"
                       1 "Yes (YECGFRND=2,3,4,5,6)" ;
label define CIGVEND   -9 "Aged 18 or Older (YECGVEND=99)"
                       0 "Otherwise (YECGVEND=1,91,93,94,97,98)"
                       1 "Yes (YECGVEND=2,3,4,5,6)" ;
label define CIGMAIL   -9 "Aged 18 or Older (YECGMAI2=99)"
                       0 "Otherwise (YECGMAI2=1,91,93,94,97,98)"
                       1 "Yes (YECGMAI2=2,3,4,5)" ;
label define CIGCKOUT  -9 "Aged 18 or Older (YECGCHKO=99)"
                       0 "Otherwise (YECGCHKO=1,91,93,94,97,98)"
                       1 "Yes (YECGCHKO=2,3,4,5,6)" ;
label define CIGCLERK  -9 "Aged 18 or Older (YECGCLRK=99)"
                       0 "Otherwise (YECGCLRK=1,91,93,94,97,98)"
                       1 "Yes (YECGCLRK=2,3,4,5,6)" ;
label define CIGINET   -9 "Aged 18 or Older (YECGINET=99)"
                       0 "Otherwise (YECGINET=1,91,93,94,97,98)"
                       1 "Yes (YECGINET=2,3,4,5,6)" ;
label define CIGSMKT   -9 "Aged 18 or Older (YECGSMKT=99)"
                       0 "Otherwise (YECGSMKT=1,91,93,94,97,98)"
                       1 "Yes (YECGSMKT=2,3,4,5,6)" ;
label define CIGDSTO   -9 "Aged 18 or Older (YECGDSTO=99)"
                       0 "Otherwise (YECGDSTO=1,91,93,94,97,98)"
                       1 "Yes (YECGDSTO=2,3,4,5,6)" ;
label define CIGCONV   -9 "Aged 18 or Older (YECGCONV=99)"
                       0 "Otherwise (YECGCONV=1,91,93,94,97,98)"
                       1 "Yes (YECGCONV=2,3,4,5,6)" ;
label define CIGINDIV  -9 "Aged 18 or Older (YECGINDV=99)"
                       0 "Otherwise (YECGINDV=1,91,93,94,97,98)"
                       1 "Yes (YECGINDV=2,3,4,5,6)" ;
label define YTHBGHT   -9 "Aged 18 or Older (ALL SOURCE VARIABLES=.)"
                       0 "Otherwise" 1 "Yes (ANY SOURCE VARIABLE=1)" ;
label define RLGATTD   -9 "Otherwise (YERLGSVC=85,94,97,98,99)"
                       1 "25 or more (YERLGSVC=5,6)"
                       2 "Less than 25 (YERLGSVC=1,2,3,4)" ;
label define RLGIMPT   -9 "Otherwise (YERLGIMP=94,97,98,99)"
                       1 "Agree/Strongly Agree (YERLGIMP=3,4)"
                       2 "Disagree/Strongly Disagree (YERLGIMP=1,2)" ;
label define RLGDCSN   -9 "Otherwise (YERLDCSN=94,97,98,99)"
                       1 "Agree/Strongly Agree (YERLDCSN=3,4)"
                       2 "Disagree/Strongly Disagree (YERLDCSN=1,2)" ;
label define RLGFRND   -9 "Otherwise (YERLFRND=94,97,98,99)"
                       1 "Agree/Strongly Agree (YERLFRND=3,4)"
                       2 "Disagree/Strongly Disagree (YERLFRND=1,2)" ;
label define SCHFELT   -9 "Otherwise (YESCHFLT=85,94,97,98,99)"
                       1 "Liked A Lot/Kind of Liked (YESCHFLT=1,2)"
                       2 "Didn't Like Very Much/Hated (YESCHFLT=3,4)" ;
label define SCHWORK   -9 "Otherwise (YESCHWRK=85,94,97,98,99)"
                       1 "Always/Sometimes (YESCHWRK=1,2)"
                       2 "Seldom/Never (YESCHWRK=3,4)" ;
label define SCHIMPT   -9 "Otherwise (YESCHIMP=85,94,97,98,99)"
                       1 "Very/Somewhat Important (YESCHIMP=1,2)"
                       2 "Very/Somewhat Unimportant (YESCHIMP=3,4)" ;
label define SCHINTST  -9 "Otherwise (YESCHINT=85,94,97,98,99)"
                       1 "Very/Somewhat Interesting (YESCHINT=1,2)"
                       2 "Very/Somewhat Boring (YESCHINT=3,4)" ;
label define TCHGJOB   -9 "Otherwise (YETCGJOB=85,94,97,98,99)"
                       1 "Always/Sometimes (YETCGJOB=1,2)"
                       2 "Seldom/Never (YETCGJOB=3,4)" ;
label define STNDSCIG  -9 "Otherwise (YESTSCIG=85,94,97,98,99)"
                       1 "All/Most (YESTSCIG=3,4)"
                       2 "Few/None (YESTSCIG=1,2)" ;
label define STNDSMJ   -9 "Otherwise (YESTSMJ=85,94,97,98,99)"
                       1 "All/Most (YESTSMJ=3,4)" 2 "Few/None (YESTSMJ=1,2)" ;
label define STNDALC   -9 "Otherwise (YESTSALC=85,94,97,98,99)"
                       1 "All/Most (YESTSALC=3,4)"
                       2 "Few/None (YESTSALC=1,2)" ;
label define STNDDNK   -9 "Otherwise (YESTSDNK=85,94,97,98,99)"
                       1 "All/Most (YESTSDNK=3,4)"
                       2 "None/Few (YESTSDNK=1,2)" ;
label define PARCHKHW  -9 "Otherwise (YEPCHKHW=85,94,97,98,99)"
                       1 "Always/Sometimes (YEPCHKHW=1,2)"
                       2 "Seldom/Never (YEPCHKHW=3,4)" ;
label define PARHLPHW  -9 "Otherwise (YEPHLPHW=85,94,97,98,99)"
                       1 "Always/Sometimes (YEPHLPHW=1,2)"
                       2 "Seldom/Never (YEPHLPHW=3,4)" ;
label define PRCHORE2  -9 "Otherwise (YEPCHORE=85,94,97,98,99)"
                       1 "Always/Sometimes (YEPCHORE=1,2)"
                       2 "Seldom/Never (YEPCHORE=3,4)" ;
label define PRLMTTV2  -9 "Otherwise (YEPLMTTV=85,94,97,98,99)"
                       1 "Always/Sometimes (YEPLMTTV=1,2)"
                       2 "Seldom/Never (YEPLMTTV=3,4)" ;
label define PARLMTSN  -9 "Otherwise (YEPLMTSN=85,94,97,98,99)"
                       1 "Always/Sometimes (YEPLMTSN=1,2)"
                       2 "Seldom/Never (YEPLMTSN=3,4)" ;
label define PRGDJOB2  -9 "Otherwise (85,94,97,98,99)"
                       1 "Always/Sometimes (YEPGDJOB=1,2)"
                       2 "Seldom/Never (YEPGDJOB=3,4)" ;
label define PRPROUD2  -9 "Otherwise (85,94,97,98,99)"
                       1 "Always/Sometimes (YEPPROUD=1,2)"
                       2 "Seldom/Never (YEPPROUD=3,4)" ;
label define ARGUPAR   -9 "Otherwise (YEYARGUP=85,94,97,98,99)"
                       1 "9 or Fewer (YEYARGUP=1,2,3,4)"
                       2 "10 or More (YEYARGUP=5)" ;
label define PRMJMO    -9 "Otherwise (YEPMJMO=94,97,98,99)"
                       1 "Strongly Disapprove (YEPMJMO=3)"
                       2 "Somewhat Dis/Neither App Nor Dis (YEPMJMO=1,2)" ;
label define YFLMJMO   -9 "Otherwise (YEPMJMO=94,97,98,99)"
                       1 "Strongly/Somewhat Disapprove (YEPMJMO=2,3)"
                       2 "Neither Approve Nor Disapprove (YEPMJMO=1)" ;
label define FRDPCIG2  -9 "Otherwise (YEFPKCIG=94,97,98,99)"
                       1 "Strongly/Somewhat Disapprove (YEFPKCIG=2,3)"
                       2 "Neither Approve Nor Disapprove (YEFPKCIG=1)" ;
label define FRDMEVR2  -9 "Otherwise (YEFMJEVR=94,97,98,99)"
                       1 "Strongly/Somewhat Disapprove (YEFMJEVR=2,3)"
                       2 "Neither Approve Nor Disapprove (YEFMJEVR=1)" ;
label define FRDMJMON  -9 "Otherwise (YEFMJMO=94,97,98,99)"
                       1 "Strongly/Somewhat Disapprove (YEFMJMO=2,3)"
                       2 "Neither Approve Nor Disapprove (YEFMJMO=1)" ;
label define FRDADLY2  -9 "Otherwise (YEFALDLY=94,97,98,99)"
                       1 "Strongly/Somewhat Disapprove (YEFALDLY=2,3)"
                       2 "Neither Approve Nor Disapprove (YEFALDLY=1)" ;
label define YTHACT2   -9 "Otherwise (See comment above)"
                       1 "None or 1 Activity (See comment above)"
                       2 "2 or More Activities (2 or more source vars=1)" ;
label define PANATAK   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PANREAC   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PANATKN2  1 "1-10 times" 2 "11-12 times" 3 "13-20 times"
                       4 "21-30 times" 5 "31-40 times" 6 "41-52 times"
                       7 "53-60 times" 8 "61-100 times" 9 "101-200 times"
                       10 "201-300 times" 11 "301-365 times"
                       12 "366 or more times"
                       985 "BAD DATA Logically assigned" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define MDEDP2WK  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MDEDPWKR  1 "2-4 weeks" 2 "5-8 weeks" 3 "9-12 weeks"
                       4 "13-16 weeks" 5 "17-18 weeks" 6 "19-20 weeks"
                       7 "21-22 weeks" 8 "23-24 weeks" 9 "25-26 weeks"
                       10 "27-36 weeks" 11 "37-44 weeks" 12 "45-51 weeks"
                       13 "All 52 weeks" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MDEDAYFQ  1 "Nearly every day" 2 "Just some days"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MDEDAYLN  1 "All day long" 2 "Most of the day"
                       3 "About half the day" 4 "Less then half the day"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MDECHNGS  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MDELOSIN  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MDELIWK2  1 "2-4 weeks" 2 "5-8 weeks" 3 "9-12 weeks"
                       4 "13-16 weeks" 5 "17-18 weeks" 6 "19-20 weeks"
                       7 "21-22 weeks" 8 "23-24 weeks" 9 "25-26 weeks"
                       10 "27-36 weeks" 11 "37-44 weeks" 12 "45-51 weeks"
                       13 "All 52 weeks" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MDELIFQ   1 "Nearly every day" 2 "Just some days"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MDELILN   1 "All day long" 2 "Most of the day"
                       3 "About half the day" 4 "Less then half the day"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MDELICHG  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define MNCHYPER  1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED (MNCEVER = 2)"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MNCNOSLP  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define MNCSPWRS  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define MNCEVER   1 "Yes" 2 "No"
                       5 "Yes LOGICALLY ASSIGNED (MNCHYPER = 1)"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MNCMEDS   1 "Yes" 2 "No"
                       5 "Hyper in past 12 mos LOG ASSN (MNCHYPER = 1)"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PHBSOCL   1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PHBLEVEL  1 "Your fear is mild" 2 "Your fear is moderate"
                       3 "Your fear is severe" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PHBAVOID  1 "Often" 2 "Sometimes" 3 "Rarely" 4 "Never"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PHBINTFR  1 "Not at all" 2 "A little" 3 "Some" 4 "A lot"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PHBCRWDS  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED (PHBWRSFR=1)"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PHBPUBPL  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED (PHBWRSFR=2)"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PHBTRAVL  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED (PHBWRSFR=3)"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PHBAWYHM  1 "Yes" 2 "No" 3 "Yes LOGICALLY ASSIGNED (PHBWRSFR=4)"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PHBWRSFR  1 "Being in crowds" 2 "Going to public places"
                       3 "Traveling in a bus, train, or car"
                       4 "Being away from home alone" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PHBWRSST  1 "Your fear is mild" 2 "Your fear is moderate"
                       3 "Your fear is severe" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PHBWRSAV  1 "Often" 2 "Sometimes" 3 "Rarely" 4 "Never"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PHBWRSIN  1 "Not at all" 2 "A little" 3 "Some" 4 "A lot"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define GADWORMR  1 "More" 2 "About the same" 3 "Less"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define GADWORLT  1 "A lot more" 2 "Somewhat more" 3 "A little more"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define GADNRVOS  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define GADNRVLT  1 "A lot more" 2 "Somewhat more" 3 "A little more"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define GADWKS2   1 "1-4 weeks" 2 "5-8 weeks" 3 "9-12 weeks"
                       4 "13-16 weeks" 5 "17-18 weeks" 6 "19-20 weeks"
                       7 "21-22 weeks" 8 "23-24 weeks" 9 "25-26 weeks"
                       10 "27-36 weeks" 11 "37-44 weeks" 12 "45-51 weeks"
                       13 "All 52 weeks" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define GADNMWOR  1 "One or two particular things"
                       2 "A number of different things"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define GADSTRON  1 "All of the time" 2 "Most of the time"
                       3 "Some of the time" 4 "A little of the time"
                       5 "Never" 85 "BAD DATA Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define GADOPROB  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PTSEVER   1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PTSPYEAR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PTSWRSFQ  1 "Several times a day" 2 "Once or twice a day"
                       3 "Several times a week" 4 "Once or twice a week"
                       5 "Less than once a week"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define PTSWKS2   1 "1-4 weeks" 2 "5-8 weeks" 3 "9-12 weeks"
                       4 "13-16 weeks" 5 "17-18 weeks" 6 "19-20 weeks"
                       7 "21-22 weeks" 8 "23-24 weeks" 9 "25-26 weeks"
                       10 "27-36 weeks" 11 "37-44 weeks" 12 "45-51 weeks"
                       13 "All 52 weeks" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DELVOICE  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DELFORCE  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DELXRAY   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DELTHOTS  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DELSIGNL  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DELPLOT   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DELVISON  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MHSEEDR   1 "Yes" 2 "No" 11 "Yes (MHOPNUM2 = 0 & MHHOSPOV = 12)"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MHHOSPOV  1 "Yes" 2 "No" 12 "No (MHSEEDR = 11 & MHOPNUM2 = 0)"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MHOPNUM2  0 "No visits" 31 "31 or more"
                       985 "BAD DATA Logically assigned" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define MHMEDS    1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MHMEDWK2  0 "0 weeks" 1 "1-4 weeks" 2 "5-8 weeks" 3 "9-12 weeks"
                       4 "13-16 weeks" 5 "17-18 weeks" 6 "19-20 weeks"
                       7 "21-22 weeks" 8 "23-24 weeks" 9 "25-26 weeks"
                       10 "27-36 weeks" 11 "37-44 weeks" 12 "45-51 weeks"
                       13 "All 52 weeks" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DSTNRVOS  1 "All of the time" 2 "Most of the time"
                       3 "Some of the time" 4 "A little of the time"
                       5 "None of the time" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DSTNCALM  1 "All of the time" 2 "Most of the time"
                       3 "Some of the time" 4 "A little of the time"
                       5 "None of the time" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DSTTIRE   1 "All of the time" 2 "Most of the time"
                       3 "Some of the time" 4 "A little of the time"
                       5 "None of the time" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DSTHOPLS  1 "All of the time" 2 "Most of the time"
                       3 "Some of the time" 4 "A little of the time"
                       5 "None of the time" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DSTRSTLS  1 "All of the time" 2 "Most of the time"
                       3 "Some of the time" 4 "A little of the time"
                       5 "None of the time" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DSTSITST  1 "All of the time" 2 "Most of the time"
                       3 "Some of the time" 4 "A little of the time"
                       5 "None of the time" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DSTDEPRS  1 "All of the time" 2 "Most of the time"
                       3 "Some of the time" 4 "A little of the time"
                       5 "None of the time" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DSTCHEER  1 "All of the time" 2 "Most of the time"
                       3 "Some of the time" 4 "A little of the time"
                       5 "None of the time" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DSTEFFRT  1 "All of the time" 2 "Most of the time"
                       3 "Some of the time" 4 "A little of the time"
                       5 "None of the time" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DSTNGOOD  1 "All of the time" 2 "Most of the time"
                       3 "Some of the time" 4 "A little of the time"
                       5 "None of the time" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IMPTHINK  1 "No difficulty" 2 "Mild difficulty"
                       3 "Moderate difficulty" 4 "Severe difficulty"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IMPUNDST  1 "No difficulty" 2 "Mild difficulty"
                       3 "Moderate difficulty" 4 "Severe difficulty"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IMPREMBR  1 "No difficulty" 2 "Mild difficulty"
                       3 "Moderate difficulty" 4 "Severe difficulty"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IMPCONC   1 "No difficulty" 2 "Mild difficulty"
                       3 "Moderate difficulty" 4 "Severe difficulty"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IMPMONY   1 "No difficulty" 2 "Mild difficulty"
                       3 "Moderate difficulty" 4 "Severe difficulty"
                       5 "You didn't manage money on your own"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IMPMONYM  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IMPLERN   1 "No difficulty" 2 "Mild difficulty"
                       3 "Moderate difficulty" 4 "Severe difficulty"
                       5 "You didn't try to learn a new task"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IMPLERNM  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IMPWASH   1 "No difficulty" 2 "Mild difficulty"
                       3 "Moderate difficulty" 4 "Severe difficulty"
                       5 "You didn't wash,dress,or feed yourself on your own"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IMPWASHM  1 "Yes" 2 "No" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IMPGO     1 "No difficulty" 2 "Mild difficulty"
                       3 "Moderate difficulty" 4 "Severe difficulty"
                       5 "You didn't leave the house on your own"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IMPGOM    1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IMPDLPP   1 "No difficulty" 2 "Mild difficulty"
                       3 "Moderate difficulty" 4 "Severe difficulty"
                       5 "You didn't deal with people you did not know well"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IMPDLPPM  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IMPSOCL   1 "No difficulty" 2 "Mild difficulty"
                       3 "Moderate difficulty" 4 "Severe difficulty"
                       5 "You didn't participate in social activities"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IMPSOCLM  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IMPGTALG  1 "No difficulty" 2 "Mild difficulty"
                       3 "Moderate difficulty" 4 "Severe difficulty"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IMPCTRLE  1 "No difficulty" 2 "Mild difficulty"
                       3 "Moderate difficulty" 4 "Severe difficulty"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IMPRELAX  1 "No difficulty" 2 "Mild difficulty"
                       3 "Moderate difficulty" 4 "Severe difficulty"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IMPHRSP   1 "No difficulty" 2 "Mild difficulty"
                       3 "Moderate difficulty" 4 "Severe difficulty"
                       5 "You didn't take care of household responsibilities"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IMPHRSPM  1 "Yes" 2 "No" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IMPDLRSP  1 "No difficulty" 2 "Mild difficulty"
                       3 "Moderate difficulty" 4 "Severe difficulty"
                       5 "You didn't work or go to school"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IMPDLWRK  1 "No difficulty" 2 "Mild difficulty"
                       3 "Moderate difficulty" 4 "Severe difficulty"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IMPWKS2   1 "1-4 weeks" 2 "5-8 weeks" 3 "9-12 weeks"
                       4 "13-16 weeks" 5 "17-18 weeks" 6 "19-20 weeks"
                       7 "21-22 weeks" 8 "23-24 weeks" 9 "25-26 weeks"
                       10 "27-36 weeks" 11 "37-44 weeks" 12 "45-51 weeks"
                       13 "All 52 weeks" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IMPDAYFQ  1 "Every day" 2 "Most days"
                       3 "Only one or two days a week"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MHSVCHLP  1 "None" 2 "A little" 3 "Some" 4 "A lot"
                       5 "A great deal" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SMI_SUM   -9 "Aged 12-17" ;
label define SMI       -9 "Aged 12-17" 0 "No (SMI_SUM<13)"
                       1 "Yes (SMI_SUM>=13)" ;
label define YUHOSPYR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUHOSPN2  31 "31 or more" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define YUHOSUIC  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUHODEPR  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YUHOFEAR  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YUHOBKRU  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUHOEATP  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUHOSOR   1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YURSIDYR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YURSIDN2  31 "31 or more" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define YURSSUIC  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YURSDEPR  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YURSFEAR  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YURSBKRU  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YURSEATP  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YURSSOR   1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUFCARYR  1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUFCARN2  31 "31 or more" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define YUFCSUIC  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YUFCDEPR  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUFCFEAR  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YUFCBKRU  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YUFCEATP  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUFCSOR   1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUDYTXYR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUDYTXN2  31 "31 or more" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define YUDYSUIC  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUDYDEPR  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUDYFEAR  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUDYBKRU  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YUDYEATP  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YUDYSOR   1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUMHCRYR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUMHCRN2  31 "31 or more" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define YUMHSUIC  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUMHDEPR  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YUMHFEAR  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YUMHBKRU  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YUMHEATP  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YUMHSOR   1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUTPSTYR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUTPSTN2  31 "31 or more" 985 "BAD DATA Logically assigned"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define YUTPSUIC  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUTPDEPR  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUTPFEAR  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YUTPBKRU  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YUTPEATP  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YUTPSOR   1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUIHTPYR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUIHTPN2  31 "31 or more" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define YUIHSUIC  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUIHDEPR  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YUIHFEAR  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YUIHBKRU  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YUIHEATP  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUIHSOR   1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUFDOCYR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUFDOCN2  31 "31 or more" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define YUFDSUIC  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUFDDEPR  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YUFDFEAR  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YUFDBKRU  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YUFDEATP  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUFDSOR   1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUSPEDYR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUSHCNYR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUSHSUIC  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUSHDEPR  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUSHFEAR  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YUSHBKRU  1 "Response entered"
                       3 "Response entered LOGICALLY ASSIGNED"
                       6 "Response not entered" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YUSHEATP  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUSHSOR   1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YUJAILEV  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define YUFCAREV  1 "Yes" 2 "No"
                       5 "Yes LOGICALLY ASSIGNED (from skip pattern)"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define YHOSP     -9 "Unknown/Aged 18+ (YUHOSPYR=85,94,97,98,99)"
                       0 "No (YUHOSPYR=2)" 1 "Yes (YUHOSPYR=1)" ;
label define YRESID    -9 "Unknown/Aged 18+ (YURSIDYR=85,94,97,98,99)"
                       0 "No (YURSIDYR=2)" 1 "Yes (YURSIDYR=1)" ;
label define YFOST     -9 "Unknown/Aged 18+ (YUFCARYR=94,97,98,99)"
                       0 "No (YUFCARYR=2,4)" 1 "Yes (YUFCARYR=1)" ;
label define YDAYTRT   -9 "Unknown/Aged 18+ (YUDYTXYR=85,94,97,98,99)"
                       0 "No (YUDYTXYR=2)" 1 "Yes (YUDYTXYR=1)" ;
label define YCLIN     -9 "Unknown/Aged 18+ (YUMHCRYR=85,94,97,98,99)"
                       0 "No (YUMHCRYR=2)" 1 "Yes (YUMHCRYR=1)" ;
label define YTHER     -9 "Unknown/Aged 18+ (YUTPSTYR=85,94,97,98,99)"
                       0 "No (YUTPSTYR=2)" 1 "Yes (YUTPSTYR=1)" ;
label define YHOME     -9 "Unknown/Aged 18+ (YUIHTPYR=85,94,97,98,99)"
                       0 "No (YUIHTPYR=2)" 1 "Yes (YUIHTPYR=1)" ;
label define YPED      -9 "Unknown/Aged 18+ (YUFDOCYR=85,94,97,98,99)"
                       0 "No (YUFDOCYR=2)" 1 "Yes (YUFDOCYR=1)" ;
label define YSPED     -9 "Unknown/Aged 18+ (Otherwise)"
                       0 "AGE2<7 AND YUSPEDYR=99" 1 "Yes (YUSPEDYR=1)" ;
label define YSCHL     -9 "Unknown/Aged 18+ (Otherwise)"
                       0 "AGE2<7 AND YUSHCNYR=99" 1 "Yes (YUSHCNYR=1)" ;
label define ANYTRT10  -9 "Unknown/Aged 18+ (See comment above)"
                       0 "No (See comment above)"
                       1 "Yes (Any above source variables=1)" ;
label define ANYTRT9   -9 "Unknown/Aged 18+ (See comment above)"
                       0 "No (See comment above)"
                       1 "Yes (Any above source variables=1)" ;
label define REASSUIC  -9 "Unknown/Aged 18+ (See comment above)"
                       0 "Reason not indicated (Otherwise)"
                       1 "Reason indicated (Any above source variable=1,3)" ;
label define REASDEPR  -9 "Unknown/Aged 18+ (See comment above)"
                       0 "Reason not indicated (Otherwise)"
                       1 "Reason indicated (Any above source variable=1,3)" ;
label define REASFEAR  -9 "Unknown/Aged 18+ (See comment above)"
                       0 "Reason not indicated (Otherwise)"
                       1 "Reason indicated (Any above source variable=1,3)" ;
label define REASBRAK  -9 "Unknown/Aged 18+ (See comment above)"
                       0 "Reason not indicated (Otherwise)"
                       1 "Reason indicated (Any above source variable=1,3)" ;
label define REASEATP  -9 "Unknown/Aged 18+ (See comment above)"
                       0 "Reason not indicated (Otherwise)"
                       1 "Reason indicated (Any above source variable=1,3)" ;
label define REASFAM   -9 "Unknown/Aged 18+ (See comment above)"
                       0 "Reason not specified (Otherwise)"
                       1 "Reason specified (See comment above)" ;
label define REASSOC   -9 "Unknown/Aged 18+ (See comment above)"
                       0 "Reason not specified (Otherwise)"
                       1 "Reason specified (See comment above)" ;
label define REASSCH   -9 "Unknown/Aged 18+ (See comment above)"
                       0 "Reason not specified (Otherwise)"
                       1 "Reason specified (See comment above)" ;
label define REASOTH   -9 "Unknown/Aged 18+ (See comment above)"
                       0 "Other reason not specified (Otherwise)"
                       1 "Other reason specified (See comment above)" ;
label define IMOTHER   1 "R is 12-17, mother in hh"
                       2 "R is 12-17, no mother in hh"
                       3 "R is 12-17, don't know whether mother is in hh"
                       4 "R is 18 or older" ;
label define IFATHER   1 "R is 12-17, father in hh"
                       2 "R is 12-17, no father in hh"
                       3 "R is 12-17, don't know whether father is in hh"
                       4 "R is 18 or older" ;
label define NRCH17_2  -9 "Missing" 3 "3 or more" ;
label define IRHHSIZ2  1 "One person in household"
                       2 "Two people in household"
                       3 "Three people in household"
                       4 "Four people in household"
                       5 "Five people in household"
                       6 "6 to 25 people in household" ;
label define IIHHSIZ2  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRHH65_2  1 "No people 65 or older in household"
                       2 "One person 65 or older in household"
                       3 "Two or more people 65 or older in household" ;
label define IIHH65_2  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRKI17_2  1 "No children under 18" 2 "One child under 18"
                       3 "Two children under 18"
                       4 "Three or more children under 18" ;
label define IIKI17_2  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define PROXANS2  1 "Yes" 2 "No" 7 "Unclear LOGICALLY ASSIGNED"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (Respondent answering)" ;
label define IRPSOC    1 "Yes" 2 "No" ;
label define IIPSOC    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRFAMSOC  1 "Yes" 2 "No" ;
label define IIFAMSOC  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRPSSI    1 "Yes" 2 "No" ;
label define IIPSSI    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRFAMSSI  1 "Yes" 2 "No" ;
label define IIFAMSSI  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRFSTAMP  1 "Yes" 2 "No" ;
label define IIFSTAMP  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRPPMT    1 "Yes" 2 "No" ;
label define IIPPMT    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRFAMPMT  1 "Yes" 2 "No" ;
label define IIFAMPMT  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRPSVC    1 "Yes" 2 "No" ;
label define IIPSVC    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRFAMSVC  1 "Yes" 2 "No" ;
label define IIFAMSVC  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRWELMOS  99 "LEGITIMATE SKIP" ;
label define IIWELMOS  1 "Questionnaire data" 3 "Statistically imputed data"
                       9 "Legitimate skip" ;
label define IRPINT    1 "Yes" 2 "No" ;
label define IIPINT    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRFAMINT  1 "Yes" 2 "No" ;
label define IIFAMINT  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRPCHD    1 "Yes" 2 "No" ;
label define IIPCHD    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRFAMCHD  1 "Yes" 2 "No" ;
label define IIFAMCHD  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRPWAG    1 "Yes" 2 "No" ;
label define IIPWAG    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRFAMWAG  1 "Yes" 2 "No" ;
label define IIFAMWAG  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRPOTH    1 "Yes" 2 "No" ;
label define IIPOTH    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRFAMOTH  1 "Yes" 2 "No" ;
label define IIFAMOTH  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRPINC3   1 "$0 - $9,999 (Including Loss)" 2 "$10,000 - $19,999"
                       3 "$20,000 - $29,999" 4 "$30,000 - $39,999"
                       5 "$40,000 - $49,999" 6 "$50,000 - $74,999"
                       7 "$75,000 or more" ;
label define IIPINC3   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRFAMIN3  1 "$0 - $9,999 (Including Loss)" 2 "$10,000 - $19,999"
                       3 "$20,000 - $29,999" 4 "$30,000 - $39,999"
                       5 "$40,000 - $49,999" 6 "$50,000 - $74,999"
                       7 "$75,000 or more" ;
label define IIFAMIN3  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define MEDICARE  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CAIDCHIP  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CHAMPUS   1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PRVHLTIN  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GRPHLTIN  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRVHLTIN = 2)" ;
label define HLTINALC  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRVHLTIN = 2)" ;
label define HLTINDRG  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRVHLTIN = 2)" ;
label define HLTINMNT  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRVHLTIN = 2)" ;
label define HLTINNOS  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLCNOTYR  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       90 "NOT ASKED THE QUESTION Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLCNOTMO  90 "NOT ASKED THE QUESTION Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLCLAST   1 "Within the past 6 months"
                       2 "More than 6 months ago, but within the past year"
                       3 "More than 1 year ago, but within the past 3 years"
                       4 "More than 3 years ago" 5 "Never had coverage"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLLOSRSN  1 "Pers in family w/health ins lost job/chng employer"
                       2 "Lost Medicaid/Med Assist b/c new job/incr income"
                       3 "Lost Medicaid/Med Assist some other reason"
                       4 "Cost is too high/can't afford premiums"
                       5 "Became ineligible because of age or leaving school"
                       6 "Employer does not offer coverage, or not eligible"
                       7 "Got divorced or separated from person w/insurance"
                       8 "Death of spouse or parent"
                       9 "Insurance company refused coverage"
                       10 "Don't need it"
                       11 "Received Medicaid/med insur only while pregnant"
                       12 "Some other reason"
                       85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLNVCOST  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLNVOFFR  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLNVREF   1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLNVNEED  1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLNVSOR   1 "Response entered" 6 "Response not entered"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define IRPINSUR  1 "Yes, respondent does have private health insurance"
                       2 "No, respondent does not have private health insur" ;
label define IIPINSUR  1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRINSUR   1 "Yes, respondent does have health insurance"
                       2 "No, respondent does not have health insurance" ;
label define IIINSUR   1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define IRINSUR3  1 "Yes, respondent does have health insurance"
                       2 "No, respondent does not have health insurance" ;
label define IIINSUR3  1 "Questionnaire data" 2 "Logically edited data"
                       3 "Statistically imputed data" ;
label define GOVTPROG  1 "YES (ANY SOURCE VARIABLE=1)"
                       2 "NO (ALL SOURCE VARIABLES=2)" ;
label define HLCALLFG  1 "Answered yes to all current health insurance Qs"
                       98 "BLANK (NO ANSWER)" ;
label define HLCALL99  1 "Yes (see comment above)" 98 "BLANK (NO ANSWER)" ;
label define ANYHLTI2  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "OTHER MISSING" ;
label define INSCDCH2  1 "Yes (CAIDCHIP=1)"
                       2 "No/Unknown (CAIDCHIP=2,85,94,97,98)" ;
label define INSOTHR2  1 "Yes (MEDICARE=1, CHAMPUS=1 or HLTINNOS=1)"
                       2 "No/Unknown (Otherwise)" ;
label define LANGVER   1 "English" 2 "Spanish" ;
label define QUARTER   1 "Quarter 1" 2 "Quarter 2" 3 "Quarter 3"
                       4 "Quarter 4" ;
label define GQTYPE    -9 "Not a Group Quarter" 1 "Halfway House"
                       2 "Boarding House" 3 "College Dorm" 4 "Shelter"
                       5 "Other" ;
label define AGE2      1 "Respondent is 12 years old"
                       2 "Respondent is 13 years old"
                       3 "Respondent is 14 years old"
                       4 "Respondent is 15 years old"
                       5 "Respondent is 16 years old"
                       6 "Respondent is 17 years old"
                       7 "Respondent is 18 years old"
                       8 "Respondent is 19 years old"
                       9 "Respondent is 20 years old"
                       10 "Respondent is 21 years old"
                       11 "Respondent is 22 or 23 years old"
                       12 "Respondent is 24 or 25 years old"
                       13 "Respondent is between 26 and 29 years old"
                       14 "Respondent is between 30 and 34 years old"
                       15 "Respondent is between 35 and 49 years old"
                       16 "Respondent is between 50 and 64 years old"
                       17 "Respondent is 65 years old or older" ;
label define NOMARR2   1 "One time" 2 "Two or more times" 94 "DON'T KNOW"
                       97 "REFUSED" 99 "LEGITIMATE SKIP" ;
label define SERVICE   1 "Yes" 2 "No" 97 "REFUSED" 99 "LEGITIMATE SKIP" ;
label define MILSTAT   2 "In a reserves component"
                       3 "Now separated/retired from reserves/active duty"
                       94 "DON'T KNOW" 97 "REFUSED" 99 "LEGITIMATE SKIP" ;
label define HEALTH    1 "Excellent" 2 "Very good" 3 "Good" 4 "Fair" 5 "Poor"
                       94 "DON'T KNOW" 97 "REFUSED" ;
label define IRSEX     1 "Male" 2 "Female" ;
label define IISEX     1 "Sex from questionnaire" ;
label define IRMARIT   1 "Married" 2 "Widowed" 3 "Divorced or Separated"
                       4 "Never Been Married"
                       99 "LEGITIMATE SKIP Respondent is <= 14 years old" ;
label define IIMARIT   1 "Marital status from questionnaire"
                       3 "Marital status statistically imputed"
                       9 "LEGITIMATE SKIP Respondent is <= 14 years old" ;
label define IREDUC2   1 "Fifth grade or less" 2 "Sixth grade"
                       3 "Seventh grade" 4 "Eighth grade" 5 "Ninth grade"
                       6 "Tenth grade" 7 "Eleventh grade" 8 "Twelfth grade"
                       9 "Freshman/13th year"
                       10 "Sophomore/14th year or Junior/15th year"
                       11 "Senior/16th year or GradProf School (or higher)" ;
label define IIEDUC2   1 "Education from questionnaire"
                       3 "Education statistically imputed" ;
label define MOVESPY2  0 "None" 1 "One time" 2 "Two times"
                       3 "Three or more times" 994 "DON'T KNOW" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define SCHENRL   1 "Yes" 2 "No"
                       3 "Yes LOGICALLY ASSIGNED (LFSCHWH2=778)"
                       4 "No LOGICALLY ASSIGNED"
                       5 "Yes LOGICALLY ASSIGNED (LFSCHWH2=601)"
                       11 "Yes (SCHDSKIP = 30)" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define EDUCATN2  1 "5th Grade or lower" 2 "6th Grade" 3 "7th Grade"
                       4 "8th Grade" 5 "9th Grade" 6 "10th Grade"
                       7 "11th Grade" 8 "12th Grade"
                       9 "College or university/1st year"
                       10 "College or university/2nd Year, 3rd year"
                       11 "College or university/4th Year, 5th or higher year"
                       12 "Missing" 13 "LEGITIMATE SKIP" ;
label define STUDNT    1 "Full-time" 2 "Part-time"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SCHDSICK  0 "None" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       90 "SCHOOL NOT IN SESSION" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SCHDSKIP  0 "None" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HSDIPLMA  1 "Yes" 2 "No" 3 "Yes LOG ASSN"
                       4 "No LOGICALLY ASSIGNED"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HSGED     1 "Yes" 2 "No" 3 "Yes LOG ASSN (LFSCHWH2=606)"
                       89 "LEGITIMATE SKIP Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define LFSCHWH2  1 "School was boring or I didn't want to be there"
                       2 "I got pregnant"
                       3 "I got in trouble or expelled for selling drugs"
                       4 "I got in trouble or expelled for using drugs"
                       5 "I got in trouble or expelled for some other reason"
                       6 "I often got into trouble"
                       7 "I had to get a job (or work more hours)"
                       8 "I was getting bad grades"
                       9 "I wasn't learning anything"
                       10 "I got married (or moved in with my boy/girlfriend)"
                       11 "I moved here from another country/didn't enroll"
                       12 "I was treated badly at school"
                       13 "I became ill (or injured)"
                       14 "I went to jail/prison"
                       15 "I had responsibilities at home/personal problems"
                       16 "Other reason"
                       41 "Family member became ill/sick/died"
                       43 "Parents/guardian/partner wouldn't allow me to"
                       46 "Learning disabled"
                       49 "Afraid of gangs/fear of violence/crime"
                       50 "Moved away/didn't re-enroll"
                       51 "Skipping school/excessive absenteeism"
                       52 "Too expensive/couldn't afford"
                       54 "No transportation/school too far away"
                       56 "Grade,credit discrepancies/lacked credits/document"
                       58 "All the schooling/preferred that was available"
                       59 "Wasn't required/didn't have to go/not needed/custo"
                       63 "I was stupid/foolish/lazy" 66 "Too old"
                       67 "Got job/apprenticeship, necessity unspecified"
                       69 "Just quit; reason unspecified"
                       71 "Didn't pass/take end of grade/school test"
                       601 "Home schooled"
                       602 "Went to technical school/community college"
                       603 "Graduated/finished high school in another country"
                       605 "Completed HS/certificate, general"
                       606 "Received GED"
                       607 "Pursuing GED/proficiency exam/re-enrolling"
                       778 "I am still in school"
                       985 "BAD DATA Logically assigned" 994 "DON'T KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define LFTSCHA2  10 "Left at age 10 or younger"
                       19 "Left at age 19 or older"
                       985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       990 "NOT ASKED THE QUESTION Logically assigned"
                       994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define JBSTATR2  1 "Worked at full-time job, past week"
                       2 "Worked at part time job, past week"
                       3 "Has job or volunteer worker, did not work past wk"
                       4 "Unemployed/on layoff, looking for work"
                       5 "Disabled" 6 "Keeping house full-time"
                       7 "In school/training" 8 "Retired"
                       9 "Does not have a job, some other reason"
                       10 "MISSING" 11 "LEGITIMATE SKIP" ;
label define WRKHAVJB  1 "Yes" 2 "No" 4 "No LOGICALLY ASSIGNED"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WRKHRSWK  994 "DON'T KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define WRKINDU2  1 "Agriculture, Forestry, and Fisheries" 2 "Mining"
                       3 "Construction" 4 "Manufacturing - Nondurable Goods"
                       5 "Manufacturing - Durable Goods"
                       6 "Trans/Commun/and Other Public Utilities"
                       7 "Wholesale Trade - Durable Goods"
                       8 "Wholesale Trade - Nondurable Goods"
                       9 "Retail Trade"
                       10 "Finance, Insurance, and Real Estate"
                       11 "Business and Repair Services"
                       12 "Personal Services"
                       13 "Entertainment and Recreation Services"
                       14 "Professional and Related Services"
                       15 "Public Administration" 16 "Military Duty"
                       985 "BAD DATA Logically assigned"
                       992 "Last worked 1984 or earlier" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define WRKOCCU2  1 "Executive/Administrative/Managerial Occupations"
                       2 "Professional Specialty Occupations"
                       3 "Technicians and Related Support Occupations"
                       4 "Sales Occupations"
                       5 "Administrative Support Occupations, Inc Clerical"
                       6 "Private Household Occupations"
                       7 "Protective Service Occupations"
                       8 "Service Occups, Except Protective/Private Househol"
                       9 "Farming, Forestry, and Fishing occupations"
                       10 "Mechanics and repairers" 11 "Construction trades"
                       12 "Extractive Occupations"
                       13 "Machine Operators, Assemblers, and Inspectors"
                       14 "Transportation and Material Moving Occupations"
                       15 "Handlers/Equipment Cleaners/Helpers/Laborers"
                       16 "Military" 909 "Last worked 1984 or earlier"
                       985 "BAD DATA Logically assigned" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define WRKBZCA2  1 "Private for-profit company or business"
                       2 "Private not-for-profit company or business"
                       3 "Local government (city, county, etc.)"
                       4 "State government"
                       5 "Federal/Foreign government or international"
                       6 "Self-employed in an incorporated business"
                       7 "Self-employed in an unincorporated business"
                       8 "Working without pay in a family business/farm"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WRKEDYR   1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WRKSLFEM  1 "Yes" 2 "No"
                       3 "Yes LOGICALLY ASSIGNED (raw var not blank)"
                       5 "Yes LOGICALLY ASSIGNED (from skip pattern)"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WRKJOBS2  1 "One" 2 "Two" 3 "Three" 4 "Four or more"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WRKUNEMP  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WRKUNWKS  85 "BAD DATA Logically assigned" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WRKLSTY2  9985 "BAD DATA Logically assigned"
                       9991 "NEVER WORKED/DON'T KNOW" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define WRKINDY2  1 "Agriculture, Forestry, and Fisheries" 2 "Mining"
                       3 "Construction" 4 "Manufacturing - Nondurable Goods"
                       5 "Manufacturing - Durable Goods"
                       6 "Trans/Commun/and Other Public Utilities"
                       7 "Wholesale Trade - Durable Goods"
                       8 "Wholesale Trade - Nondurable Goods"
                       9 "Retail Trade"
                       10 "Finance, Insurance, and Real Estate"
                       11 "Business and Repair Services"
                       12 "Personal Services"
                       13 "Entertainment and Recreation Services"
                       14 "Professional and Related Services"
                       15 "Public Administration" 16 "Military Duty"
                       985 "BAD DATA Logically assigned"
                       992 "Last worked 1984 or earlier" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define WRKOCCY2  1 "Executive/Administrative/Managerial Occupations"
                       2 "Professional Specialty Occupations"
                       3 "Technicians and Related Support Occupations"
                       4 "Sales Occupations"
                       5 "Administrative Support Occupations, Inc Clerical"
                       6 "Private Household Occupations"
                       7 "Protective Service Occupations"
                       8 "Service Occups, Except Protective/Private Househol"
                       9 "Farming, Forestry, and Fishing occupations"
                       10 "Mechanics and repairers" 11 "Construction trades"
                       12 "Extractive Occupations"
                       13 "Machine Operators, Assemblers, and Inspectors"
                       14 "Transportation and Material Moving Occupations"
                       15 "Handlers/Equipment Cleaners/Helpers/Laborers"
                       16 "Military" 909 "Last worked 1984 or earlier"
                       985 "BAD DATA Logically assigned" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define WRKBZCY2  1 "Private for-profit company or business"
                       2 "Private not-for-profit company or business"
                       3 "Local government (city, county, etc.)"
                       4 "State government"
                       5 "Federal/Foreign government or international"
                       6 "Self-employed in an incorporated business"
                       7 "Self-employed in an unincorporated business"
                       8 "Working without pay in a family business/farm"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORKDAYS  0 "None" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORKBLAH  0 "None" 85 "BAD DATA Logically assigned"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define LOCSIZE   1 "Less than 10 people" 2 "10-24 people"
                       3 "25-99 people" 4 "100-499 people"
                       5 "500 people or more" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DRGPLCY   1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PLCYCOV   1 "Only alcohol" 2 "Only drugs"
                       3 "Both alcohol and drugs" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WKDRGED   1 "Yes" 2 "No" 3 "Don't remember" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DRGPRGM   1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define USALCTST  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define USDRGTST  1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TSTHIRE   1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TSTRAND   1 "Yes" 2 "No" 94 "DON'T KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define FIRSTPOS  1 "Handled on indiv basis/policy does not spec what"
                       2 "Employee is fired"
                       3 "Employee is referred for treatment or counseling"
                       4 "Nothing happens" 5 "Something else happens"
                       94 "DON'T KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WRKHIRE   1 "More likely" 2 "Less likely"
                       3 "Would it make no difference to you" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORKRAND  1 "More likely" 2 "Less likely"
                       3 "Would make no difference" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TELNO2    0 "None" 1 "One" 2 "Two or more" 94 "DON'T KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define COLLEGE2  -9 "Unknwn Enrollment, Aged 18-22 (ENROLED=94,97,98)"
                       1 "Full-Time College Student Aged 18-22"
                       2 "Part-Time College Student Aged 18-22"
                       3 "Not Enrolled (ENROLED=2)"
                       4 "Others Persons Aged 18-22"
                       5 "Persons Aged 12-17, or 23 or Older" ;
label define EMPSTATY  1 "Employed full time" 2 "Employed part time"
                       3 "Unemployed" 4 "Other (incl. not in labor force)"
                       5 "12-14 year olds" ;
label define IIEMPSTY  1 "Employment status from questionnaire"
                       3 "Employment statistically imputed"
                       4 "12-14 years old" ;
label define EMPSTAT4  1 "Employed full time" 2 "Employed part time"
                       3 "Unemployed" 4 "Other (incl. not in labor force)"
                       5 "12-17 year olds" ;
label define IIEMPST4  1 "Employment status from questionnaire"
                       3 "Employment statistically imputed"
                       4 "12-17 years old" ;
label define CATAGE    1 "12-17 Years Old" 2 "18-25 Years Old"
                       3 "26-34 Years Old" 4 "35 or Older" ;
label define CATAG2    1 "12-17 Years Old" 2 "18-25 Years Old"
                       3 "26 or Older" ;
label define CATAG3    1 "12-17 Years Old" 2 "18-25 Years Old"
                       3 "26-34 Years Old" 4 "35-49 Years Old"
                       5 "50 or Older" ;
label define CATAG7    1 "12-13 Years Old" 2 "14-15 Years Old"
                       3 "16-17 Years Old" 4 "18-20 Years Old"
                       5 "21-25 Years Old" 6 "26-34 Years Old"
                       7 "35 or Older" ;
label define PREGAGE2  1 "15-17 Years Old" 2 "18-25 Years Old"
                       3 "26-44 Years Old" 4 "Otherwise (12-14, 45 or Older)" ;
label define NEWRACE2  1 "NonHisp White" 2 "NonHisp Black/Afr Am"
                       3 "NonHisp Native Am/AK Native"
                       4 "NonHisp Native HI/Other Pac Isl" 5 "NonHisp Asian"
                       6 "NonHisp more than one race" 7 "Hispanic" ;
label define EDUCCAT2  1 "Less than high school" 2 "High school graduate"
                       3 "Some college" 4 "College graduate"
                       5 "12 to 17 year olds (1<=AGE2<=6)" ;
label define MRJYDAYS  1 "1-11 Days (IRMJFY=1-11)"
                       2 "12-49 Days (IRMJFY=12-49)"
                       3 "50-99 Days (IRMJFY=50-99)"
                       4 "100-299 Days (IRMJFY=100-299)"
                       5 "300-365 Days (IRMJFY=300-365)"
                       6 "No Past Year Use (IRMJFY=991,993)" ;
label define COCYDAYS  1 "1-11 Days (IRCOCFY=1-11)"
                       2 "12-49 Days (IRCOCFY=12-49)"
                       3 "50-99 Days (IRCOCFY=50-99)"
                       4 "100-299 Days (IRCOCFY=100-299)"
                       5 "300-365 Days (IRCOCFY=300-365)"
                       6 "No Past Year Use (IRCOCFY=991,993)" ;
label define HALYDAYS  1 "1-11 Days (IRHALFY=1-11)"
                       2 "12-49 Days (IRHALFY=12-49)"
                       3 "50-99 Days (IRHALFY=50-99)"
                       4 "100-299 Days (IRHALFY=100-299)"
                       5 "300-365 Days (IRHALFY=300-365)"
                       6 "No Past Year Use (IRHALFY=991,993)" ;
label define INHYDAYS  1 "1-11 Days (IRINHFY=1-11)"
                       2 "12-49 Days (IRINHFY=12-49)"
                       3 "50-99 Days (IRINHFY=50-99)"
                       4 "100-299 Days (IRINHFY=100-299)"
                       5 "300-365 Days (IRINHFY=300-365)"
                       6 "No Past Year Use (IRINHFY=991,993)" ;
label define ALCYDAYS  1 "1-11 Days (IRALCFY=1-11)"
                       2 "12-49 Days (IRALCFY=12-49)"
                       3 "50-99 Days (IRALCFY=50-99)"
                       4 "100-299 Days (IRALCFY=100-299)"
                       5 "300-365 Days (IRALCFY=300-365)"
                       6 "No Past Year Use (IRALCFY=991,993)" ;
label define MRJMDAYS  1 "1-2 Days (IRMJFM=1-2)" 2 "3-5 Days (IRMJFM=3-5)"
                       3 "6-19 Days (IRMJFM=6-19)"
                       4 "20-30 Days (IRMJFM=20-30)"
                       5 "No Past Month Use (IRMJFM=91,93)" ;
label define COCMDAYS  1 "1-2 Days (IRCOCFM=1-2)" 2 "3-5 Days (IRCOCFM=3-5)"
                       3 "6-19 Days (IRCOCFM=6-19)"
                       4 "20-30 Days (IRCOCFM=20-30)"
                       5 "No Past Month Use (IRCOCFM=91,93)" ;
label define HALMDAYS  1 "1-2 Days (IRHALFM=1-2)" 2 "3-5 Days (IRHALFM=3-5)"
                       3 "6-19 Days (IRHALFM=6-19)"
                       4 "20-30 Days (IRHALFM=20-30)"
                       5 "No Past Month Use (IRHALFM=91,93)" ;
label define INHMDAYS  1 "1-2 Days (IRINHFM=1-2)" 2 "3-5 Days (IRINHFM=3-5)"
                       3 "6-19 Days (IRINHFM=6-19)"
                       4 "20-30 Days (IRINHFM=20-30)"
                       5 "No Past Month Use (IRINHFM=91,93)" ;
label define ALCMDAYS  1 "1-2 Days (IRALCFM=1-2)" 2 "3-5 Days (IRALCFM=3-5)"
                       3 "6-19 Days (IRALCFM=6-19)"
                       4 "20-30 Days (IRALCFM=20-30)"
                       5 "No Past Month Use (IRALCFM=91,93)" ;
label define CIGMDAYS  1 "1-2 Days (IRCIGFM=1-2)" 2 "3-5 Days (IRCIGFM=3-5)"
                       3 "6-19 Days (IRCIGFM=6-19)"
                       4 "20-29 Days (IRCIGFM=20-29)"
                       5 "30 Days (IRCIGFM=30)"
                       6 "No Past Month Use (IRCIGFM=91,93)" ;
label define CIGPDAY   1 "Fewer Than 6 (CIG30AV=1,2,3 AND IRCIGFM=30)"
                       2 "6-15 (CIG30AV=4 AND IRCIGFM=30)"
                       3 "16-25 (CIG30AV=5 AND IRCIGFM=30)"
                       4 "26 or More (CIG30AV=6,7 AND IRCIGFM=30)"
                       5 "Not Reported (CIG30AV=85,94,97,98 AND IRCIGFM=30)"
                       6 "No Daily Use(CIG30AV=91,93 OR IRCIGFM=1-29,91,93)" ;
label define PDEN      1 "Segment in a MSA with 1 million or more persons"
                       2 "Segment in a MSA with fewer than 1 million persons"
                       3 "Segment not in a MSA" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace CIGOFRSM = . if (CIGOFRSM >= 81 )
replace CIGWILYR = . if (CIGWILYR >= 81 )
replace CIGTRY = . if (CIGTRY >= 981 )
replace CIGYFU = . if (CIGYFU >= 9981 )
replace CIGMFU = . if (CIGMFU >= 81 )
replace CIGREC = . if (CIGREC >= 81 )
replace CIG30USE = . if (CIG30USE >= 81 )
replace CG30EST = . if (CG30EST >= 81 )
replace CIG30AV = . if (CIG30AV >= 81 )
replace CIG30BR2 = . if (CIG30BR2 >= 9981 )
replace CIG30TYP = . if (CIG30TYP >= 81 )
replace CIG30MEN = . if (CIG30MEN >= 81 )
replace CIG30RO2 = . if (CIG30RO2 >= 81 )
replace CIGDLYMO = . if (CIGDLYMO >= 81 )
replace CIGAGE = . if (CIGAGE >= 981 )
replace CIG100LF = . if (CIG100LF >= 81 )
replace SNFEVER = . if (SNFEVER >= 81 )
replace SNUFTRY = . if (SNUFTRY >= 981 )
replace SNUFYFU = . if (SNUFYFU >= 9981 )
replace SNUFMFU = . if (SNUFMFU >= 81 )
replace SNFREC = . if (SNFREC >= 81 )
replace SNF30USE = . if (SNF30USE >= 81 )
replace SN30EST = . if (SN30EST >= 81 )
replace SNF30BR2 = . if (SNF30BR2 >= 9981 )
replace CHEWEVER = . if (CHEWEVER >= 81 )
replace CHEWTRY = . if (CHEWTRY >= 981 )
replace CHEWYFU = . if (CHEWYFU >= 9981 )
replace CHEWMFU = . if (CHEWMFU >= 81 )
replace CHEWREC = . if (CHEWREC >= 81 )
replace CHW30USE = . if (CHW30USE >= 81 )
replace CH30EST = . if (CH30EST >= 81 )
replace CHW30BR2 = . if (CHW30BR2 >= 9981 )
replace SLTTRY = . if (SLTTRY >= 981 )
replace SLTYFU = . if (SLTYFU >= 9981 )
replace SLTMFU = . if (SLTMFU >= 81 )
replace SLTREC = . if (SLTREC >= 81 )
replace SLT30BR2 = . if (SLT30BR2 >= 9981 )
replace SLT30FAV = . if (SLT30FAV >= 81 )
replace CIGAREVR = . if (CIGAREVR >= 81 )
replace CIGARTRY = . if (CIGARTRY >= 981 )
replace CIGARYFU = . if (CIGARYFU >= 9981 )
replace CIGARMFU = . if (CIGARMFU >= 81 )
replace CIGARREC = . if (CIGARREC >= 81 )
replace CGR30USE = . if (CGR30USE >= 81 )
replace CI30EST = . if (CI30EST >= 81 )
replace CGR30BR2 = . if (CGR30BR2 >= 9981 )
replace PIPEVER = . if (PIPEVER >= 81 )
replace PIPE30DY = . if (PIPE30DY >= 81 )
replace ALCEVER = . if (ALCEVER >= 81 )
replace ALCTRY = . if (ALCTRY >= 981 )
replace ALCYFU = . if (ALCYFU >= 9981 )
replace ALCMFU = . if (ALCMFU >= 81 )
replace ALCREC = . if (ALCREC >= 81 )
replace ALCYRTOT = . if (ALCYRTOT >= 981 )
replace ALTOTFG = . if (ALTOTFG >= 81 )
replace ALFQFLG = . if (ALFQFLG >= 81 )
replace ALBSTWAY = . if (ALBSTWAY >= 81 )
replace ALDAYPYR = . if (ALDAYPYR >= 981 )
replace ALDAYPMO = . if (ALDAYPMO >= 81 )
replace ALDAYPWK = . if (ALDAYPWK >= 81 )
replace ALCDAYS = . if (ALCDAYS >= 81 )
replace AL30EST = . if (AL30EST >= 81 )
replace ALDYSFG = . if (ALDYSFG >= 81 )
replace NODR30A = . if (NODR30A >= 975 )
replace DR5DAY = . if (DR5DAY >= 80 )
replace MJEVER = . if (MJEVER >= 81 )
replace MJAGE = . if (MJAGE >= 981 )
replace MJYFU = . if (MJYFU >= 9981 )
replace MJMFU = . if (MJMFU >= 81 )
replace MJREC = . if (MJREC >= 81 )
replace MJYRTOT = . if (MJYRTOT >= 981 )
replace MRTOTFG = . if (MRTOTFG >= 81 )
replace MJFQFLG = . if (MJFQFLG >= 81 )
replace MRBSTWAY = . if (MRBSTWAY >= 81 )
replace MRDAYPYR = . if (MRDAYPYR >= 981 )
replace MRDAYPMO = . if (MRDAYPMO >= 81 )
replace MRDAYPWK = . if (MRDAYPWK >= 81 )
replace MJDAY30A = . if (MJDAY30A >= 81 )
replace MR30EST = . if (MR30EST >= 81 )
replace COCEVER = . if (COCEVER >= 81 )
replace COCAGE = . if (COCAGE >= 981 )
replace COCYFU = . if (COCYFU >= 9981 )
replace COCMFU = . if (COCMFU >= 81 )
replace COCREC = . if (COCREC >= 81 )
replace COCYRTOT = . if (COCYRTOT >= 981 )
replace CCTOTFG = . if (CCTOTFG >= 81 )
replace CCFQFLG = . if (CCFQFLG >= 81 )
replace CCBSTWAY = . if (CCBSTWAY >= 81 )
replace CCDAYPYR = . if (CCDAYPYR >= 981 )
replace CCDAYPMO = . if (CCDAYPMO >= 81 )
replace CCDAYPWK = . if (CCDAYPWK >= 81 )
replace COCUS30A = . if (COCUS30A >= 81 )
replace CC30EST = . if (CC30EST >= 81 )
replace CRKEVER = . if (CRKEVER >= 81 )
replace CRKAGE = . if (CRKAGE >= 981 )
replace CRKYFU = . if (CRKYFU >= 9981 )
replace CRKMFU = . if (CRKMFU >= 81 )
replace CRAKREC = . if (CRAKREC >= 81 )
replace CRKYRTOT = . if (CRKYRTOT >= 981 )
replace CRTOTFG = . if (CRTOTFG >= 81 )
replace CRFQFLG = . if (CRFQFLG >= 81 )
replace CRBSTWAY = . if (CRBSTWAY >= 81 )
replace CRDAYPYR = . if (CRDAYPYR >= 981 )
replace CRDAYPMO = . if (CRDAYPMO >= 81 )
replace CRDAYPWK = . if (CRDAYPWK >= 81 )
replace CRKUS30A = . if (CRKUS30A >= 81 )
replace CR30EST = . if (CR30EST >= 81 )
replace HEREVER = . if (HEREVER >= 81 )
replace HERAGE = . if (HERAGE >= 981 )
replace HERYFU = . if (HERYFU >= 9981 )
replace HERMFU = . if (HERMFU >= 81 )
replace HERREC = . if (HERREC >= 81 )
replace HERYRTOT = . if (HERYRTOT >= 981 )
replace HRTOTFG = . if (HRTOTFG >= 81 )
replace HRFQFLG = . if (HRFQFLG >= 81 )
replace HRBSTWAY = . if (HRBSTWAY >= 81 )
replace HRDAYPYR = . if (HRDAYPYR >= 981 )
replace HRDAYPMO = . if (HRDAYPMO >= 81 )
replace HRDAYPWK = . if (HRDAYPWK >= 81 )
replace HER30USE = . if (HER30USE >= 81 )
replace HR30EST = . if (HR30EST >= 81 )
replace LSD = . if (LSD >= 81 )
replace PCP = . if (PCP >= 81 )
replace PEYOTE = . if (PEYOTE >= 81 )
replace MESC = . if (MESC >= 81 )
replace PSILCY = . if (PSILCY >= 81 )
replace ECSTASY = . if (ECSTASY >= 81 )
replace HALNOLST = . if (HALNOLST >= 81 )
replace HALNEWA = . if (HALNEWA >= 9981 )
replace HALNEWB = . if (HALNEWB >= 9981 )
replace HALNEWC = . if (HALNEWC >= 9981 )
replace HALNEWD = . if (HALNEWD >= 9981 )
replace HALNEWE = . if (HALNEWE >= 9981 )
replace HALLAGE = . if (HALLAGE >= 981 )
replace HALYFU = . if (HALYFU >= 9981 )
replace HALMFU = . if (HALMFU >= 81 )
replace HALLREC = . if (HALLREC >= 81 )
replace HALYRTOT = . if (HALYRTOT >= 981 )
replace HLTOTFG = . if (HLTOTFG >= 81 )
replace HLFQFLG = . if (HLFQFLG >= 81 )
replace HLBSTWAY = . if (HLBSTWAY >= 81 )
replace HLDAYPYR = . if (HLDAYPYR >= 981 )
replace HLDAYPMO = . if (HLDAYPMO >= 81 )
replace HLDAYPWK = . if (HLDAYPWK >= 81 )
replace HAL30USE = . if (HAL30USE >= 81 )
replace HL30EST = . if (HL30EST >= 81 )
replace LSDAGE = . if (LSDAGE >= 981 )
replace LSDYFU = . if (LSDYFU >= 9981 )
replace LSDMFU = . if (LSDMFU >= 81 )
replace LSDREC = . if (LSDREC >= 81 )
replace PCPAGE = . if (PCPAGE >= 981 )
replace PCPYFU = . if (PCPYFU >= 9981 )
replace PCPMFU = . if (PCPMFU >= 81 )
replace PCPREC = . if (PCPREC >= 81 )
replace ECSAGE = . if (ECSAGE >= 985 )
replace ECSYFU = . if (ECSYFU >= 9985 )
replace ECSMFU = . if (ECSMFU >= 81 )
replace ECSREC = . if (ECSREC >= 81 )
replace AMYLNIT = . if (AMYLNIT >= 81 )
replace CLEFLU = . if (CLEFLU >= 81 )
replace GAS = . if (GAS >= 81 )
replace GLUE = . if (GLUE >= 81 )
replace ETHER = . if (ETHER >= 81 )
replace SOLVENT = . if (SOLVENT >= 81 )
replace LGAS = . if (LGAS >= 81 )
replace NITOXID = . if (NITOXID >= 81 )
replace SPPAINT = . if (SPPAINT >= 81 )
replace AEROS = . if (AEROS >= 81 )
replace INHNOLST = . if (INHNOLST >= 81 )
replace INHNEWA = . if (INHNEWA >= 9981 )
replace INHNEWB = . if (INHNEWB >= 9981 )
replace INHNEWC = . if (INHNEWC >= 9981 )
replace INHNEWD = . if (INHNEWD >= 9981 )
replace INHNEWE = . if (INHNEWE >= 9981 )
replace INHEVER = . if (INHEVER >= 81 )
replace INHAGE = . if (INHAGE >= 981 )
replace INHYFU = . if (INHYFU >= 9981 )
replace INHMFU = . if (INHMFU >= 81 )
replace INHREC = . if (INHREC >= 81 )
replace INHYRTOT = . if (INHYRTOT >= 981 )
replace INTOTFG = . if (INTOTFG >= 81 )
replace INFQFLG = . if (INFQFLG >= 81 )
replace INBSTWAY = . if (INBSTWAY >= 81 )
replace INDAYPYR = . if (INDAYPYR >= 981 )
replace INDAYPMO = . if (INDAYPMO >= 81 )
replace INDAYPWK = . if (INDAYPWK >= 81 )
replace INHDY30A = . if (INHDY30A >= 81 )
replace IN30EST = . if (IN30EST >= 81 )
replace DARVTYLC = . if (DARVTYLC >= 81 )
replace PERCTYLX = . if (PERCTYLX >= 81 )
replace VICOLOR = . if (VICOLOR >= 81 )
replace ANLCARD = . if (ANLCARD >= 81 )
replace CODEINE = . if (CODEINE >= 81 )
replace DEMEROL = . if (DEMEROL >= 81 )
replace DILAUD = . if (DILAUD >= 81 )
replace FIORICET = . if (FIORICET >= 81 )
replace FIORINAL = . if (FIORINAL >= 81 )
replace HYDROCOD = . if (HYDROCOD >= 81 )
replace METHDON = . if (METHDON >= 81 )
replace MORPHINE = . if (MORPHINE >= 81 )
replace OXYCONTN = . if (OXYCONTN >= 81 )
replace PHENCOD = . if (PHENCOD >= 81 )
replace PROPOXY = . if (PROPOXY >= 81 )
replace SK65A = . if (SK65A >= 81 )
replace STADOL = . if (STADOL >= 81 )
replace TALACEN = . if (TALACEN >= 81 )
replace TALWIN = . if (TALWIN >= 81 )
replace TALWINNX = . if (TALWINNX >= 81 )
replace TRAMADOL = . if (TRAMADOL >= 81 )
replace ULTRAM = . if (ULTRAM >= 81 )
replace ANLNOLST = . if (ANLNOLST >= 81 )
replace ANALNEWA = . if (ANALNEWA >= 9981 )
replace ANALNEWB = . if (ANALNEWB >= 9981 )
replace ANALNEWC = . if (ANALNEWC >= 9981 )
replace ANALNEWD = . if (ANALNEWD >= 9981 )
replace ANALNEWE = . if (ANALNEWE >= 9981 )
replace ANLEVER = . if (ANLEVER >= 81 )
replace ANALAGE = . if (ANALAGE >= 981 )
replace ANALYFU = . if (ANALYFU >= 9981 )
replace ANALMFU = . if (ANALMFU >= 81 )
replace ANALREC = . if (ANALREC >= 81 )
replace ANLYRTOT = . if (ANLYRTOT >= 981 )
replace PRTOTFG = . if (PRTOTFG >= 81 )
replace PRFQFLG = . if (PRFQFLG >= 81 )
replace PRBSTWAY = . if (PRBSTWAY >= 81 )
replace PRDAYPYR = . if (PRDAYPYR >= 981 )
replace PRDAYPMO = . if (PRDAYPMO >= 81 )
replace PRDAYPWK = . if (PRDAYPWK >= 81 )
replace KLONOPIN = . if (KLONOPIN >= 81 )
replace XNAXATVN = . if (XNAXATVN >= 81 )
replace VALMDIAZ = . if (VALMDIAZ >= 81 )
replace TRNCARD = . if (TRNCARD >= 81 )
replace ATARAX = . if (ATARAX >= 81 )
replace BUSPAR = . if (BUSPAR >= 81 )
replace EQUANIL = . if (EQUANIL >= 81 )
replace FLEXERIL = . if (FLEXERIL >= 81 )
replace LIBRIUM = . if (LIBRIUM >= 81 )
replace LIMBTROL = . if (LIMBTROL >= 81 )
replace MEPROB = . if (MEPROB >= 81 )
replace MILTOWN = . if (MILTOWN >= 81 )
replace ROHYPNOL = . if (ROHYPNOL >= 81 )
replace SERAX = . if (SERAX >= 81 )
replace SOMA = . if (SOMA >= 81 )
replace TRANXENE = . if (TRANXENE >= 81 )
replace VISTAR = . if (VISTAR >= 81 )
replace TRNOLST = . if (TRNOLST >= 81 )
replace TRNEWA = . if (TRNEWA >= 9981 )
replace TRNEWB = . if (TRNEWB >= 9981 )
replace TRNEWC = . if (TRNEWC >= 9981 )
replace TRNEWD = . if (TRNEWD >= 9981 )
replace TRNEWE = . if (TRNEWE >= 9981 )
replace TRNEVER = . if (TRNEVER >= 81 )
replace TRANAGE = . if (TRANAGE >= 981 )
replace TRANYFU = . if (TRANYFU >= 9981 )
replace TRANMFU = . if (TRANMFU >= 81 )
replace TRANREC = . if (TRANREC >= 81 )
replace TRNYRTOT = . if (TRNYRTOT >= 981 )
replace TRTOTFG = . if (TRTOTFG >= 81 )
replace TRFQFLG = . if (TRFQFLG >= 81 )
replace TRBSTWAY = . if (TRBSTWAY >= 81 )
replace TRDAYPYR = . if (TRDAYPYR >= 981 )
replace TRDAYPMO = . if (TRDAYPMO >= 81 )
replace TRDAYPWK = . if (TRDAYPWK >= 81 )
replace METHDES = . if (METHDES >= 81 )
replace DIETPILS = . if (DIETPILS >= 81 )
replace RITMPHEN = . if (RITMPHEN >= 81 )
replace STMCARD = . if (STMCARD >= 81 )
replace CYLERT = . if (CYLERT >= 81 )
replace DEXED = . if (DEXED >= 81 )
replace DETAMP = . if (DETAMP >= 81 )
replace DIDREX = . if (DIDREX >= 81 )
replace ESKAT = . if (ESKAT >= 81 )
replace IONAMIN = . if (IONAMIN >= 81 )
replace MAZANOR = . if (MAZANOR >= 81 )
replace OBLA = . if (OBLA >= 81 )
replace PLEGINE = . if (PLEGINE >= 81 )
replace PRELUDIN = . if (PRELUDIN >= 81 )
replace SANOREX = . if (SANOREX >= 81 )
replace TENUATE = . if (TENUATE >= 81 )
replace STMNOLST = . if (STMNOLST >= 81 )
replace STIMNEWA = . if (STIMNEWA >= 9981 )
replace STIMNEWB = . if (STIMNEWB >= 9981 )
replace STIMNEWC = . if (STIMNEWC >= 9981 )
replace STIMNEWD = . if (STIMNEWD >= 9981 )
replace STIMNEWE = . if (STIMNEWE >= 9981 )
replace STMEVER = . if (STMEVER >= 81 )
replace STIMAGE = . if (STIMAGE >= 981 )
replace STIMYFU = . if (STIMYFU >= 9981 )
replace STIMMFU = . if (STIMMFU >= 81 )
replace STIMREC = . if (STIMREC >= 81 )
replace STMYRTOT = . if (STMYRTOT >= 981 )
replace STTOTFG = . if (STTOTFG >= 81 )
replace STFQFLG = . if (STFQFLG >= 81 )
replace STBSTWAY = . if (STBSTWAY >= 81 )
replace STDAYPYR = . if (STDAYPYR >= 981 )
replace STDAYPMO = . if (STDAYPMO >= 81 )
replace STDAYPWK = . if (STDAYPWK >= 81 )
replace METHAGE = . if (METHAGE >= 981 )
replace METHYFU = . if (METHYFU >= 9981 )
replace METHMFU = . if (METHMFU >= 81 )
replace METHREC = . if (METHREC >= 81 )
replace MTHYRTOT = . if (MTHYRTOT >= 981 )
replace MTBSTWAY = . if (MTBSTWAY >= 81 )
replace MTDAYPYR = . if (MTDAYPYR >= 981 )
replace MTDAYPMO = . if (MTDAYPMO >= 81 )
replace MTDAYPWK = . if (MTDAYPWK >= 81 )
replace METHAQ = . if (METHAQ >= 81 )
replace NEMBBARB = . if (NEMBBARB >= 81 )
replace RESTTMAZ = . if (RESTTMAZ >= 81 )
replace SEDCARD = . if (SEDCARD >= 81 )
replace AMYTAL = . if (AMYTAL >= 81 )
replace BUTISOL = . if (BUTISOL >= 81 )
replace CHHYD = . if (CHHYD >= 81 )
replace DALMANE = . if (DALMANE >= 81 )
replace HALCION = . if (HALCION >= 81 )
replace PHENOBAR = . if (PHENOBAR >= 81 )
replace PLACIDYL = . if (PLACIDYL >= 81 )
replace TUINAL = . if (TUINAL >= 81 )
replace SEDNOLST = . if (SEDNOLST >= 81 )
replace SEDNEWA = . if (SEDNEWA >= 9981 )
replace SEDNEWB = . if (SEDNEWB >= 9981 )
replace SEDNEWC = . if (SEDNEWC >= 9981 )
replace SEDNEWD = . if (SEDNEWD >= 9981 )
replace SEDNEWE = . if (SEDNEWE >= 9981 )
replace SEDEVER = . if (SEDEVER >= 81 )
replace SEDAGE = . if (SEDAGE >= 981 )
replace SEDYFU = . if (SEDYFU >= 9981 )
replace SEDMFU = . if (SEDMFU >= 81 )
replace SEDREC = . if (SEDREC >= 81 )
replace SEDYRTOT = . if (SEDYRTOT >= 981 )
replace SVTOTFG = . if (SVTOTFG >= 81 )
replace SVFQFLG = . if (SVFQFLG >= 81 )
replace SVBSTWAY = . if (SVBSTWAY >= 81 )
replace SVDAYPYR = . if (SVDAYPYR >= 981 )
replace SVDAYPMO = . if (SVDAYPMO >= 81 )
replace SVDAYPWK = . if (SVDAYPWK >= 81 )
replace IIMJRC = . if (IIMJRC == 9)
replace IRCOCRC = . if (IRCOCRC == 9)
replace IRCRKRC = . if (IRCRKRC == 9)
replace IRHERRC = . if (IRHERRC == 9)
replace IRHALRC = . if (IRHALRC == 9)
replace IRLSDRC = . if (IRLSDRC == 9)
replace IRPCPRC = . if (IRPCPRC == 9)
replace IRECSRC = . if (IRECSRC == 9)
replace IRINHRC = . if (IRINHRC == 9)
replace IRANLRC = . if (IRANLRC == 9)
replace IRTRNRC = . if (IRTRNRC == 9)
replace IRSTMRC = . if (IRSTMRC == 9)
replace IRMTHRC = . if (IRMTHRC == 9)
replace IRSEDRC = . if (IRSEDRC == 9)
replace IRALCFY = . if (IRALCFY >= 981 )
replace IRMJFY = . if (IRMJFY >= 981 )
replace IRCOCFY = . if (IRCOCFY >= 981 )
replace IRCRKFY = . if (IRCRKFY >= 981 )
replace IRHERFY = . if (IRHERFY >= 981 )
replace IRHALFY = . if (IRHALFY >= 981 )
replace IRINHFY = . if (IRINHFY >= 981 )
replace IRANLFY = . if (IRANLFY >= 981 )
replace IRTRNFY = . if (IRTRNFY >= 981 )
replace IRSTMFY = . if (IRSTMFY >= 981 )
replace IRMTHFY = . if (IRMTHFY >= 981 )
replace IRSEDFY = . if (IRSEDFY >= 981 )
replace IRCIGFM = . if (IRCIGFM >= 81.00 )
replace IRCGRFM = . if (IRCGRFM >= 81.00 )
replace IRCHWFM = . if (IRCHWFM >= 81.00 )
replace IRSNFFM = . if (IRSNFFM >= 81.00 )
replace IRALCFM = . if (IRALCFM >= 81.00 )
replace IRALCD5 = . if (IRALCD5 >= 81 )
replace IRMJFM = . if (IRMJFM >= 81.00 )
replace IRCOCFM = . if (IRCOCFM >= 81 )
replace IRCRKFM = . if (IRCRKFM >= 81 )
replace IRHERFM = . if (IRHERFM >= 81 )
replace IRHALFM = . if (IRHALFM >= 81.00 )
replace IRINHFM = . if (IRINHFM >= 81.00 )
replace IRCIGAGE = . if (IRCIGAGE >= 981 )
replace IRCIGYFU = . if (IRCIGYFU >= 9981 )
replace IRCDUAGE = . if (IRCDUAGE >= 981 )
replace IRCDUYFU = . if (IRCDUYFU >= 9981 )
replace IRCGRAGE = . if (IRCGRAGE >= 981 )
replace IRCGRYFU = . if (IRCGRYFU >= 9981 )
replace IRSNFAGE = . if (IRSNFAGE >= 981 )
replace IRSNFYFU = . if (IRSNFYFU >= 9981 )
replace IRCHWAGE = . if (IRCHWAGE >= 981 )
replace IRCHWYFU = . if (IRCHWYFU >= 9981 )
replace IRSLTAGE = . if (IRSLTAGE >= 981 )
replace IRSLTYFU = . if (IRSLTYFU >= 9981 )
replace IRALCAGE = . if (IRALCAGE >= 981 )
replace IRALCYFU = . if (IRALCYFU >= 9981 )
replace IRMJAGE = . if (IRMJAGE >= 981 )
replace IRMJYFU = . if (IRMJYFU >= 9981 )
replace IRCOCAGE = . if (IRCOCAGE >= 981 )
replace IRCOCYFU = . if (IRCOCYFU >= 9981 )
replace IRCRKAGE = . if (IRCRKAGE >= 981 )
replace IRCRKYFU = . if (IRCRKYFU >= 9981 )
replace IRHERAGE = . if (IRHERAGE >= 981 )
replace IRHERYFU = . if (IRHERYFU >= 9981 )
replace IRHALAGE = . if (IRHALAGE >= 981 )
replace IRHALYFU = . if (IRHALYFU >= 9981 )
replace IRLSDAGE = . if (IRLSDAGE >= 981 )
replace IRLSDYFU = . if (IRLSDYFU >= 9981 )
replace IRPCPAGE = . if (IRPCPAGE >= 981 )
replace IRPCPYFU = . if (IRPCPYFU >= 9981 )
replace IRECSAGE = . if (IRECSAGE >= 981 )
replace IRECSYFU = . if (IRECSYFU >= 9981 )
replace IRINHAGE = . if (IRINHAGE >= 981 )
replace IRINHYFU = . if (IRINHYFU >= 9981 )
replace IRANLAGE = . if (IRANLAGE >= 981 )
replace IRANLYFU = . if (IRANLYFU >= 9981 )
replace IRTRNAGE = . if (IRTRNAGE >= 981 )
replace IRTRNYFU = . if (IRTRNYFU >= 9981 )
replace IRSTMAGE = . if (IRSTMAGE >= 981 )
replace IRSTMYFU = . if (IRSTMYFU >= 9981 )
replace IRMTHAGE = . if (IRMTHAGE >= 981 )
replace IRMTHYFU = . if (IRMTHYFU >= 9981 )
replace IRSEDAGE = . if (IRSEDAGE >= 981 )
replace IRSEDYFU = . if (IRSEDYFU >= 9981 )
replace CIGBRND3 = . if (CIGBRND3 == -9)
replace CIGBRND3 = . if (CIGBRND3 >= 81 )
replace CGRBRND3 = . if (CGRBRND3 == -9)
replace CGRBRND3 = . if (CGRBRND3 >= 81 )
replace SMKBRND3 = . if (SMKBRND3 == -9)
replace SMKBRND3 = . if (SMKBRND3 >= 81 )
replace CIGCMPNY = . if (CIGCMPNY >= 81 )
replace CG05 = . if (CG05 >= 81 )
replace CG06 = . if (CG06 >= 81 )
replace CG06DK = . if (CG06DK >= 81 )
replace CG06RE = . if (CG06RE >= 81 )
replace CG27 = . if (CG27 >= 81 )
replace CG28 = . if (CG28 >= 81 )
replace CG28DK = . if (CG28DK >= 81 )
replace CG28RE = . if (CG28RE >= 81 )
replace CG19 = . if (CG19 >= 81 )
replace CG20 = . if (CG20 >= 81 )
replace CG20DK = . if (CG20DK >= 81 )
replace CG20RE = . if (CG20RE >= 81 )
replace CG36 = . if (CG36 >= 81 )
replace CG37 = . if (CG37 >= 81 )
replace CG37DK = . if (CG37DK >= 81 )
replace CG37RE = . if (CG37RE >= 81 )
replace CG43 = . if (CG43 >= 81 )
replace ALLAST3 = . if (ALLAST3 >= 81 )
replace ALRECDK = . if (ALRECDK >= 81 )
replace ALRECRE = . if (ALRECRE >= 81 )
replace TOTDRINK = . if (TOTDRINK >= 981 )
replace ALFRAME3 = . if (ALFRAME3 >= 81 )
replace ALYRAVE = . if (ALYRAVE >= 981 )
replace ALMONAVE = . if (ALMONAVE >= 81 )
replace ALWKAVE = . if (ALWKAVE >= 81 )
replace MJLAST3 = . if (MJLAST3 >= 81 )
replace MJRECDK = . if (MJRECDK >= 81 )
replace MJRECRE = . if (MJRECRE >= 81 )
replace TOTMJ = . if (TOTMJ >= 981 )
replace MJFRAME3 = . if (MJFRAME3 >= 81 )
replace MJYRAVE = . if (MJYRAVE >= 981 )
replace MJMONAVE = . if (MJMONAVE >= 81 )
replace MJWKAVE = . if (MJWKAVE >= 81 )
replace CCLAST3 = . if (CCLAST3 >= 81 )
replace CCRECDK = . if (CCRECDK >= 81 )
replace CCRECRE = . if (CCRECRE >= 81 )
replace TOTCOKE = . if (TOTCOKE >= 981 )
replace CCFRAME3 = . if (CCFRAME3 >= 81 )
replace CCYRAVE = . if (CCYRAVE >= 981 )
replace CCMONAVE = . if (CCMONAVE >= 81 )
replace CCWKAVE = . if (CCWKAVE >= 81 )
replace CKLAST3 = . if (CKLAST3 >= 81 )
replace CKRECDK = . if (CKRECDK >= 81 )
replace CKRECRE = . if (CKRECRE >= 81 )
replace TOTCRACK = . if (TOTCRACK >= 981 )
replace CKFRAME3 = . if (CKFRAME3 >= 81 )
replace CKYRAVE = . if (CKYRAVE >= 981 )
replace CKMONAVE = . if (CKMONAVE >= 81 )
replace CKWKAVE = . if (CKWKAVE >= 81 )
replace HELAST3 = . if (HELAST3 >= 81 )
replace HERECDK = . if (HERECDK >= 81 )
replace HERECRE = . if (HERECRE >= 81 )
replace TOTHERO = . if (TOTHERO >= 981 )
replace HEFRAME3 = . if (HEFRAME3 >= 81 )
replace HEYRAVE = . if (HEYRAVE >= 981 )
replace HEMONAVE = . if (HEMONAVE >= 81 )
replace HEWKAVE = . if (HEWKAVE >= 81 )
replace LSLAST = . if (LSLAST >= 81 )
replace LSRECDK = . if (LSRECDK >= 81 )
replace LSRECRE = . if (LSRECRE >= 81 )
replace TOTHALL = . if (TOTHALL >= 981 )
replace LSFRAME3 = . if (LSFRAME3 >= 81 )
replace LSYRAVE = . if (LSYRAVE >= 981 )
replace LSMONAVE = . if (LSMONAVE >= 81 )
replace LSWKAVE = . if (LSWKAVE >= 81 )
replace LS10 = . if (LS10 >= 81 )
replace LS16 = . if (LS16 >= 81 )
replace LS22 = . if (LS22 >= 81 )
replace INLAST = . if (INLAST >= 81 )
replace INRECDK = . if (INRECDK >= 81 )
replace INRECRE = . if (INRECRE >= 81 )
replace TOTINHAL = . if (TOTINHAL >= 981 )
replace INFRAME3 = . if (INFRAME3 >= 81 )
replace INYRAVE = . if (INYRAVE >= 981 )
replace INMONAVE = . if (INMONAVE >= 81 )
replace INWKAVE = . if (INWKAVE >= 81 )
replace PR09 = . if (PR09 >= 81 )
replace PRRECDK = . if (PRRECDK >= 81 )
replace PRRECRE = . if (PRRECRE >= 81 )
replace PR10 = . if (PR10 >= 81 )
replace PR11 = . if (PR11 >= 981 )
replace PR12 = . if (PR12 >= 81 )
replace PR13 = . if (PR13 >= 81 )
replace TR09 = . if (TR09 >= 81 )
replace TRRECDK = . if (TRRECDK >= 81 )
replace TRRECRE = . if (TRRECRE >= 81 )
replace TR10 = . if (TR10 >= 81 )
replace TR11 = . if (TR11 >= 981 )
replace TR12 = . if (TR12 >= 81 )
replace TR13 = . if (TR13 >= 81 )
replace ST09 = . if (ST09 >= 81 )
replace STRECDK = . if (STRECDK >= 81 )
replace STRECRE = . if (STRECRE >= 81 )
replace ST10 = . if (ST10 >= 81 )
replace ST11 = . if (ST11 >= 981 )
replace ST12 = . if (ST12 >= 81 )
replace ST13 = . if (ST13 >= 81 )
replace ST19 = . if (ST19 >= 81 )
replace ST20 = . if (ST20 >= 81 )
replace ST21 = . if (ST21 >= 981 )
replace ST22 = . if (ST22 >= 81 )
replace ST23 = . if (ST23 >= 81 )
replace SV09 = . if (SV09 >= 81 )
replace SVRECDK = . if (SVRECDK >= 81 )
replace SVRECRE = . if (SVRECRE >= 81 )
replace SV10 = . if (SV10 >= 81 )
replace SV11 = . if (SV11 >= 981 )
replace SV12 = . if (SV12 >= 81 )
replace SV13 = . if (SV13 >= 81 )
replace HERSMOKE = . if (HERSMOKE >= 81 )
replace HRSMKREC = . if (HRSMKREC >= 81 )
replace HERSNIFF = . if (HERSNIFF >= 81 )
replace HRSNFREC = . if (HRSNFREC >= 81 )
replace HERNEEDL = . if (HERNEEDL >= 81 )
replace HEOTSMK = . if (HEOTSMK >= 81 )
replace HEOTSNF = . if (HEOTSNF >= 81 )
replace HEOTNDL = . if (HEOTNDL >= 81 )
replace HEOTOTH = . if (HEOTOTH >= 81 )
replace HEOTSP = . if (HEOTSP >= 81 )
replace HRNDLREC = . if (HRNDLREC >= 81 )
replace MTHNEEDL = . if (MTHNEEDL >= 81 )
replace MTNDLREC = . if (MTNDLREC >= 81 )
replace OSTNEEDL = . if (OSTNEEDL >= 81 )
replace OSTNLREC = . if (OSTNLREC >= 81 )
replace COCNEEDL = . if (COCNEEDL >= 81 )
replace CONDLREC = . if (CONDLREC >= 81 )
replace OTDGNEDL = . if (OTDGNEDL >= 81 )
replace OTDGNDLA = . if (OTDGNDLA >= 9981 )
replace OTDGNDLB = . if (OTDGNDLB >= 9981 )
replace OTDGNDLC = . if (OTDGNDLC >= 9981 )
replace OTDGNDLD = . if (OTDGNDLD >= 9981 )
replace OTDGNDLE = . if (OTDGNDLE >= 9981 )
replace GNNDREUS = . if (GNNDREUS >= 81 )
replace GNNDLSH1 = . if (GNNDLSH1 >= 81 )
replace GNNDCLEN = . if (GNNDCLEN >= 81 )
replace GNNDLSH2 = . if (GNNDLSH2 >= 81 )
replace GNNDGET2 = . if (GNNDGET2 >= 81 )
replace STNEEDLR = . if (STNEEDLR >= 81 )
replace STNLRECR = . if (STNLRECR >= 81 )
replace NEDLRECR = . if (NEDLRECR >= 81 )
replace NEDFLG01 = . if (NEDFLG01 >= 81 )
replace NEDMTH = . if (NEDMTH >= 81 )
replace RSKPKCIG = . if (RSKPKCIG >= 81 )
replace RSKMJOCC = . if (RSKMJOCC >= 81 )
replace RSKMJREG = . if (RSKMJREG >= 81 )
replace RKTRYLSD = . if (RKTRYLSD >= 81 )
replace RKLSDREG = . if (RKLSDREG >= 81 )
replace RKTRYHER = . if (RKTRYHER >= 81 )
replace RKHERREG = . if (RKHERREG >= 81 )
replace RKCOCOCC = . if (RKCOCOCC >= 81 )
replace RKCOCREG = . if (RKCOCREG >= 81 )
replace RK5ALDLY = . if (RK5ALDLY >= 81 )
replace RK5ALWK = . if (RK5ALWK >= 81 )
replace RSKDIFMJ = . if (RSKDIFMJ >= 81 )
replace RKDIFLSD = . if (RKDIFLSD >= 81 )
replace RKDIFCOC = . if (RKDIFCOC >= 81 )
replace RKDIFCRK = . if (RKDIFCRK >= 81 )
replace RKDIFHER = . if (RKDIFHER >= 81 )
replace RSKSELL = . if (RSKSELL >= 81 )
replace RKFQDNGR = . if (RKFQDNGR >= 81 )
replace RKFQRSKY = . if (RKFQRSKY >= 81 )
replace RKFQPBLT = . if (RKFQPBLT >= 81 )
replace RKFQDBLT = . if (RKFQDBLT >= 81 )
replace RKLISALL = . if (RKLISALL >= 81 )
replace RKLISRA1 = . if (RKLISRA1 >= 81 )
replace RKLISRA2 = . if (RKLISRA2 >= 81 )
replace RKLISRB2 = . if (RKLISRB2 >= 81 )
replace RKLISRB1 = . if (RKLISRB1 >= 81 )
replace GRSKPKCG = . if (GRSKPKCG == -9)
replace GRSKPKCG = . if (GRSKPKCG >= 81 )
replace GRSKCREG = . if (GRSKCREG == -9)
replace GRSKCREG = . if (GRSKCREG >= 81 )
replace GRSKCOCC = . if (GRSKCOCC == -9)
replace GRSKCOCC = . if (GRSKCOCC >= 81 )
replace GRSKMREG = . if (GRSKMREG == -9)
replace GRSKMREG = . if (GRSKMREG >= 81 )
replace GRSKMOCC = . if (GRSKMOCC == -9)
replace GRSKMOCC = . if (GRSKMOCC >= 81 )
replace GRSKHTRY = . if (GRSKHTRY == -9)
replace GRSKHTRY = . if (GRSKHTRY >= 81 )
replace GRSKHREG = . if (GRSKHREG == -9)
replace GRSKHREG = . if (GRSKHREG >= 81 )
replace GRSKLTRY = . if (GRSKLTRY == -9)
replace GRSKLTRY = . if (GRSKLTRY >= 81 )
replace GRSKLREG = . if (GRSKLREG == -9)
replace GRSKLREG = . if (GRSKLREG >= 81 )
replace GRSKD4_5 = . if (GRSKD4_5 == -9)
replace GRSKD4_5 = . if (GRSKD4_5 >= 81 )
replace GRSKD5WK = . if (GRSKD5WK == -9)
replace GRSKD5WK = . if (GRSKD5WK >= 81 )
replace RDIFMJ = . if (RDIFMJ == -9)
replace RDIFMJ = . if (RDIFMJ >= 81 )
replace RDIFCOC = . if (RDIFCOC == -9)
replace RDIFCOC = . if (RDIFCOC >= 81 )
replace RDIFHER = . if (RDIFHER == -9)
replace RDIFHER = . if (RDIFHER >= 81 )
replace RDIFLSD = . if (RDIFLSD == -9)
replace RDIFLSD = . if (RDIFLSD >= 81 )
replace RDIFCRK = . if (RDIFCRK == -9)
replace RDIFCRK = . if (RDIFCRK >= 81 )
replace APPSELDG = . if (APPSELDG == -9)
replace APPSELDG = . if (APPSELDG >= 81 )
replace BIDIEVER = . if (BIDIEVER >= 81 )
replace BIDIREC = . if (BIDIREC >= 81 )
replace BIDI30US = . if (BIDI30US >= 81 )
replace CLOVEVER = . if (CLOVEVER >= 81 )
replace CLOVREC = . if (CLOVREC >= 81 )
replace CLOV30US = . if (CLOV30US >= 81 )
replace CIGIRTBL = . if (CIGIRTBL >= 81 )
replace CIGCRAVE = . if (CIGCRAVE >= 81 )
replace CIGCRAGP = . if (CIGCRAGP >= 81 )
replace CIGINCTL = . if (CIGINCTL >= 81 )
replace CIGAVOID = . if (CIGAVOID >= 81 )
replace CIGFNSMK = . if (CIGFNSMK >= 81 )
replace CIGFNLKE = . if (CIGFNLKE >= 81 )
replace CIGPLANE = . if (CIGPLANE >= 81 )
replace CIGRNOUT = . if (CIGRNOUT >= 81 )
replace CIGREGDY = . if (CIGREGDY >= 81 )
replace CIGREGWK = . if (CIGREGWK >= 81 )
replace CIGREGNM = . if (CIGREGNM >= 81 )
replace CIGNMCHG = . if (CIGNMCHG >= 81 )
replace CIGSVLHR = . if (CIGSVLHR >= 81 )
replace CIGINFLU = . if (CIGINFLU >= 81 )
replace CIGNOINF = . if (CIGNOINF >= 81 )
replace CIGINCRS = . if (CIGINCRS >= 81 )
replace CIGSATIS = . if (CIGSATIS >= 81 )
replace CIGLOTMR = . if (CIGLOTMR >= 81 )
replace CIGWAKE = . if (CIGWAKE >= 81 )
replace CIG30PKC = . if (CIG30PKC >= 81 )
replace CIG30PPK = . if (CIG30PPK >= 81 )
replace CIG30PCR = . if (CIG30PCR >= 81 )
replace ALCLOTTM = . if (ALCLOTTM >= 81 )
replace ALCGTOVR = . if (ALCGTOVR >= 81 )
replace ALCLIMIT = . if (ALCLIMIT >= 81 )
replace ALCKPLMT = . if (ALCKPLMT >= 81 )
replace ALCNDMOR = . if (ALCNDMOR >= 81 )
replace ALCLSEFX = . if (ALCLSEFX >= 81 )
replace ALCCUTDN = . if (ALCCUTDN >= 81 )
replace ALCCUTEV = . if (ALCCUTEV >= 81 )
replace ALCCUT1X = . if (ALCCUT1X >= 81 )
replace ALCWD2SX = . if (ALCWD2SX >= 81 )
replace ALCWDSMT = . if (ALCWDSMT >= 81 )
replace ALCEMOPB = . if (ALCEMOPB >= 81 )
replace ALCEMCTD = . if (ALCEMCTD >= 81 )
replace ALCPHLPB = . if (ALCPHLPB >= 81 )
replace ALCPHCTD = . if (ALCPHCTD >= 81 )
replace ALCLSACT = . if (ALCLSACT >= 81 )
replace ALCSERPB = . if (ALCSERPB >= 81 )
replace ALCPDANG = . if (ALCPDANG >= 81 )
replace ALCLAWTR = . if (ALCLAWTR >= 81 )
replace ALCFMFPB = . if (ALCFMFPB >= 81 )
replace ALCFMCTD = . if (ALCFMCTD >= 81 )
replace MRJLOTTM = . if (MRJLOTTM >= 81 )
replace MRJGTOVR = . if (MRJGTOVR >= 81 )
replace MRJLIMIT = . if (MRJLIMIT >= 81 )
replace MRJKPLMT = . if (MRJKPLMT >= 81 )
replace MRJNDMOR = . if (MRJNDMOR >= 81 )
replace MRJLSEFX = . if (MRJLSEFX >= 81 )
replace MRJCUTDN = . if (MRJCUTDN >= 81 )
replace MRJCUTEV = . if (MRJCUTEV >= 81 )
replace MRJEMOPB = . if (MRJEMOPB >= 81 )
replace MRJEMCTD = . if (MRJEMCTD >= 81 )
replace MRJPHLPB = . if (MRJPHLPB >= 81 )
replace MRJPHCTD = . if (MRJPHCTD >= 81 )
replace MRJLSACT = . if (MRJLSACT >= 81 )
replace MRJSERPB = . if (MRJSERPB >= 81 )
replace MRJPDANG = . if (MRJPDANG >= 81 )
replace MRJLAWTR = . if (MRJLAWTR >= 81 )
replace MRJFMFPB = . if (MRJFMFPB >= 81 )
replace MRJFMCTD = . if (MRJFMCTD >= 81 )
replace COCLOTTM = . if (COCLOTTM >= 81 )
replace COCGTOVR = . if (COCGTOVR >= 81 )
replace COCLIMIT = . if (COCLIMIT >= 81 )
replace COCKPLMT = . if (COCKPLMT >= 81 )
replace COCNDMOR = . if (COCNDMOR >= 81 )
replace COCLSEFX = . if (COCLSEFX >= 81 )
replace COCCUTDN = . if (COCCUTDN >= 81 )
replace COCCUTEV = . if (COCCUTEV >= 81 )
replace COCCUT1X = . if (COCCUT1X >= 81 )
replace COCFLBLU = . if (COCFLBLU >= 81 )
replace COCWD2SX = . if (COCWD2SX >= 81 )
replace COCWDSMT = . if (COCWDSMT >= 81 )
replace COCEMOPB = . if (COCEMOPB >= 81 )
replace COCEMCTD = . if (COCEMCTD >= 81 )
replace COCPHLPB = . if (COCPHLPB >= 81 )
replace COCPHCTD = . if (COCPHCTD >= 81 )
replace COCLSACT = . if (COCLSACT >= 81 )
replace COCSERPB = . if (COCSERPB >= 81 )
replace COCPDANG = . if (COCPDANG >= 81 )
replace COCLAWTR = . if (COCLAWTR >= 81 )
replace COCFMFPB = . if (COCFMFPB >= 81 )
replace COCFMCTD = . if (COCFMCTD >= 81 )
replace HERLOTTM = . if (HERLOTTM >= 81 )
replace HERGTOVR = . if (HERGTOVR >= 81 )
replace HERLIMIT = . if (HERLIMIT >= 81 )
replace HERKPLMT = . if (HERKPLMT >= 81 )
replace HERNDMOR = . if (HERNDMOR >= 81 )
replace HERLSEFX = . if (HERLSEFX >= 81 )
replace HERCUTDN = . if (HERCUTDN >= 81 )
replace HERCUTEV = . if (HERCUTEV >= 81 )
replace HERCUT1X = . if (HERCUT1X >= 81 )
replace HERWD3SX = . if (HERWD3SX >= 81 )
replace HERWDSMT = . if (HERWDSMT >= 81 )
replace HEREMOPB = . if (HEREMOPB >= 81 )
replace HEREMCTD = . if (HEREMCTD >= 81 )
replace HERPHLPB = . if (HERPHLPB >= 81 )
replace HERPHCTD = . if (HERPHCTD >= 81 )
replace HERLSACT = . if (HERLSACT >= 81 )
replace HERSERPB = . if (HERSERPB >= 81 )
replace HERPDANG = . if (HERPDANG >= 81 )
replace HERLAWTR = . if (HERLAWTR >= 81 )
replace HERFMFPB = . if (HERFMFPB >= 81 )
replace HERFMCTD = . if (HERFMCTD >= 81 )
replace HALLOTTM = . if (HALLOTTM >= 81 )
replace HALGTOVR = . if (HALGTOVR >= 81 )
replace HALLIMIT = . if (HALLIMIT >= 81 )
replace HALKPLMT = . if (HALKPLMT >= 81 )
replace HALNDMOR = . if (HALNDMOR >= 81 )
replace HALLSEFX = . if (HALLSEFX >= 81 )
replace HALCUTDN = . if (HALCUTDN >= 81 )
replace HALCUTEV = . if (HALCUTEV >= 81 )
replace HALEMOPB = . if (HALEMOPB >= 81 )
replace HALEMCTD = . if (HALEMCTD >= 81 )
replace HALPHLPB = . if (HALPHLPB >= 81 )
replace HALPHCTD = . if (HALPHCTD >= 81 )
replace HALLSACT = . if (HALLSACT >= 81 )
replace HALSERPB = . if (HALSERPB >= 81 )
replace HALPDANG = . if (HALPDANG >= 81 )
replace HALLAWTR = . if (HALLAWTR >= 81 )
replace HALFMFPB = . if (HALFMFPB >= 81 )
replace HALFMCTD = . if (HALFMCTD >= 81 )
replace INHLOTTM = . if (INHLOTTM >= 81 )
replace INHGTOVR = . if (INHGTOVR >= 81 )
replace INHLIMIT = . if (INHLIMIT >= 81 )
replace INHKPLMT = . if (INHKPLMT >= 81 )
replace INHNDMOR = . if (INHNDMOR >= 81 )
replace INHLSEFX = . if (INHLSEFX >= 81 )
replace INHCUTDN = . if (INHCUTDN >= 81 )
replace INHCUTEV = . if (INHCUTEV >= 81 )
replace INHEMOPB = . if (INHEMOPB >= 81 )
replace INHEMCTD = . if (INHEMCTD >= 81 )
replace INHPHLPB = . if (INHPHLPB >= 81 )
replace INHPHCTD = . if (INHPHCTD >= 81 )
replace INHLSACT = . if (INHLSACT >= 81 )
replace INHSERPB = . if (INHSERPB >= 81 )
replace INHPDANG = . if (INHPDANG >= 81 )
replace INHLAWTR = . if (INHLAWTR >= 81 )
replace INHFMFPB = . if (INHFMFPB >= 81 )
replace INHFMCTD = . if (INHFMCTD >= 81 )
replace ANLLOTTM = . if (ANLLOTTM >= 81 )
replace ANLGTOVR = . if (ANLGTOVR >= 81 )
replace ANLLIMIT = . if (ANLLIMIT >= 81 )
replace ANLKPLMT = . if (ANLKPLMT >= 81 )
replace ANLNDMOR = . if (ANLNDMOR >= 81 )
replace ANLLSEFX = . if (ANLLSEFX >= 81 )
replace ANLCUTDN = . if (ANLCUTDN >= 81 )
replace ANLCUTEV = . if (ANLCUTEV >= 81 )
replace ANLCUT1X = . if (ANLCUT1X >= 81 )
replace ANLWD3SX = . if (ANLWD3SX >= 81 )
replace ANLWDSMT = . if (ANLWDSMT >= 81 )
replace ANLEMOPB = . if (ANLEMOPB >= 81 )
replace ANLEMCTD = . if (ANLEMCTD >= 81 )
replace ANLPHLPB = . if (ANLPHLPB >= 81 )
replace ANLPHCTD = . if (ANLPHCTD >= 81 )
replace ANLLSACT = . if (ANLLSACT >= 81 )
replace ANLSERPB = . if (ANLSERPB >= 81 )
replace ANLPDANG = . if (ANLPDANG >= 81 )
replace ANLLAWTR = . if (ANLLAWTR >= 81 )
replace ANLFMFPB = . if (ANLFMFPB >= 81 )
replace ANLFMCTD = . if (ANLFMCTD >= 81 )
replace TRNLOTTM = . if (TRNLOTTM >= 81 )
replace TRNGTOVR = . if (TRNGTOVR >= 81 )
replace TRNLIMIT = . if (TRNLIMIT >= 81 )
replace TRNKPLMT = . if (TRNKPLMT >= 81 )
replace TRNNDMOR = . if (TRNNDMOR >= 81 )
replace TRNLSEFX = . if (TRNLSEFX >= 81 )
replace TRNCUTDN = . if (TRNCUTDN >= 81 )
replace TRNCUTEV = . if (TRNCUTEV >= 81 )
replace TRNEMOPB = . if (TRNEMOPB >= 81 )
replace TRNEMCTD = . if (TRNEMCTD >= 81 )
replace TRNPHLPB = . if (TRNPHLPB >= 81 )
replace TRNPHCTD = . if (TRNPHCTD >= 81 )
replace TRNLSACT = . if (TRNLSACT >= 81 )
replace TRNSERPB = . if (TRNSERPB >= 81 )
replace TRNPDANG = . if (TRNPDANG >= 81 )
replace TRNLAWTR = . if (TRNLAWTR >= 81 )
replace TRNFMFPB = . if (TRNFMFPB >= 81 )
replace TRNFMCTD = . if (TRNFMCTD >= 81 )
replace STMLOTTM = . if (STMLOTTM >= 81 )
replace STMGTOVR = . if (STMGTOVR >= 81 )
replace STMLIMIT = . if (STMLIMIT >= 81 )
replace STMKPLMT = . if (STMKPLMT >= 81 )
replace STMNDMOR = . if (STMNDMOR >= 81 )
replace STMLSEFX = . if (STMLSEFX >= 81 )
replace STMCUTDN = . if (STMCUTDN >= 81 )
replace STMCUTEV = . if (STMCUTEV >= 81 )
replace STMCUT1X = . if (STMCUT1X >= 81 )
replace STMFLBLU = . if (STMFLBLU >= 81 )
replace STMWD2SX = . if (STMWD2SX >= 81 )
replace STMWDSMT = . if (STMWDSMT >= 81 )
replace STMEMOPB = . if (STMEMOPB >= 81 )
replace STMEMCTD = . if (STMEMCTD >= 81 )
replace STMPHLPB = . if (STMPHLPB >= 81 )
replace STMPHCTD = . if (STMPHCTD >= 81 )
replace STMLSACT = . if (STMLSACT >= 81 )
replace STMSERPB = . if (STMSERPB >= 81 )
replace STMPDANG = . if (STMPDANG >= 81 )
replace STMLAWTR = . if (STMLAWTR >= 81 )
replace STMFMFPB = . if (STMFMFPB >= 81 )
replace STMFMCTD = . if (STMFMCTD >= 81 )
replace SEDLOTTM = . if (SEDLOTTM >= 81 )
replace SEDGTOVR = . if (SEDGTOVR >= 81 )
replace SEDLIMIT = . if (SEDLIMIT >= 81 )
replace SEDKPLMT = . if (SEDKPLMT >= 81 )
replace SEDNDMOR = . if (SEDNDMOR >= 81 )
replace SEDLSEFX = . if (SEDLSEFX >= 81 )
replace SEDCUTDN = . if (SEDCUTDN >= 81 )
replace SEDCUTEV = . if (SEDCUTEV >= 81 )
replace SEDCUT1X = . if (SEDCUT1X >= 81 )
replace SEDWD1SX = . if (SEDWD1SX >= 81 )
replace SEDWDSMT = . if (SEDWDSMT >= 81 )
replace SEDEMOPB = . if (SEDEMOPB >= 81 )
replace SEDEMCTD = . if (SEDEMCTD >= 81 )
replace SEDPHLPB = . if (SEDPHLPB >= 81 )
replace SEDPHCTD = . if (SEDPHCTD >= 81 )
replace SEDLSACT = . if (SEDLSACT >= 81 )
replace SEDSERPB = . if (SEDSERPB >= 81 )
replace SEDPDANG = . if (SEDPDANG >= 81 )
replace SEDLAWTR = . if (SEDLAWTR >= 81 )
replace SEDFMFPB = . if (SEDFMFPB >= 81 )
replace SEDFMCTD = . if (SEDFMCTD >= 81 )
replace IRCGIRTB = . if (IRCGIRTB >= 81.00 )
replace IICGIRTB = . if (IICGIRTB >= 81 )
replace IRCGCRV = . if (IRCGCRV >= 81.00 )
replace IICGCRV = . if (IICGCRV >= 81 )
replace IRCGCRGP = . if (IRCGCRGP >= 81.00 )
replace IICGCRGP = . if (IICGCRGP >= 81 )
replace IRCGNCTL = . if (IRCGNCTL >= 81.00 )
replace IICGNCTL = . if (IICGNCTL >= 81 )
replace IRCGAVD = . if (IRCGAVD >= 81.00 )
replace IICGAVD = . if (IICGAVD >= 81 )
replace IRCGPLN = . if (IRCGPLN >= 81.00 )
replace IICGPLN = . if (IICGPLN >= 81 )
replace IRCGROUT = . if (IRCGROUT >= 81.00 )
replace IICGROUT = . if (IICGROUT >= 81 )
replace IRCGRGDY = . if (IRCGRGDY >= 81.00 )
replace IICGRGDY = . if (IICGRGDY >= 81 )
replace IRCGRGWK = . if (IRCGRGWK >= 81.00 )
replace IICGRGWK = . if (IICGRGWK >= 81 )
replace IRCGRGNM = . if (IRCGRGNM >= 81.00 )
replace IICGRGNM = . if (IICGRGNM >= 81 )
replace IRCGNCG = . if (IRCGNCG >= 81.00 )
replace IICGNCG = . if (IICGNCG >= 81 )
replace IRCGSLHR = . if (IRCGSLHR >= 81.00 )
replace IICGSLHR = . if (IICGSLHR >= 81 )
replace IRCGINFL = . if (IRCGINFL >= 81.00 )
replace IICGINFL = . if (IICGINFL >= 81 )
replace IRCGNINF = . if (IRCGNINF >= 81.00 )
replace IICGNINF = . if (IICGNINF >= 81 )
replace IRCGINCR = . if (IRCGINCR >= 81.00 )
replace IICGINCR = . if (IICGINCR >= 81 )
replace IRCGSAT = . if (IRCGSAT >= 81.00 )
replace IICGSAT = . if (IICGSAT >= 81 )
replace IRCGLMR = . if (IRCGLMR >= 81.00 )
replace IICGLMR = . if (IICGLMR >= 81 )
replace NDSSAVG = . if (NDSSAVG == -9.00)
replace BOOKED = . if (BOOKED >= 81 )
replace NOBOOKY2 = . if (NOBOOKY2 >= 981 )
replace BKMVTHFT = . if (BKMVTHFT >= 81 )
replace BKLARCNY = . if (BKLARCNY >= 81 )
replace BKBURGL = . if (BKBURGL >= 81 )
replace BKAGASLT = . if (BKAGASLT >= 81 )
replace BKSMASLT = . if (BKSMASLT >= 81 )
replace BKROB = . if (BKROB >= 81 )
replace BKRAPE = . if (BKRAPE >= 81 )
replace BKMURDER = . if (BKMURDER >= 81 )
replace BKARSON = . if (BKARSON >= 81 )
replace BKDRVINF = . if (BKDRVINF >= 81 )
replace BKDRUNK = . if (BKDRUNK >= 81 )
replace BKPOSTOB = . if (BKPOSTOB >= 81 )
replace BKDRUG = . if (BKDRUG >= 81 )
replace BKPROS = . if (BKPROS >= 81 )
replace BKSEXOFF = . if (BKSEXOFF >= 81 )
replace BKFRAUD = . if (BKFRAUD >= 81 )
replace BKOTH = . if (BKOTH >= 81 )
replace BKOTHOF2 = . if (BKOTHOF2 >= 81 )
replace PROBATON = . if (PROBATON >= 81 )
replace PAROLREL = . if (PAROLREL >= 81 )
replace DRVALDR = . if (DRVALDR >= 81 )
replace DRVAONLY = . if (DRVAONLY >= 81 )
replace DRVDONLY = . if (DRVDONLY >= 81 )
replace DRIVALC = . if (DRIVALC >= 3 )
replace DRIVDRG = . if (DRIVDRG >= 3 )
replace DRIVALD = . if (DRIVALD >= 3 )
replace PAROL = . if (PAROL == -9)
replace PAROL = . if (PAROL >= 81 )
replace PROB = . if (PROB == -9)
replace PROB = . if (PROB >= 81 )
replace MMGETMJ = . if (MMGETMJ >= 81 )
replace MMBTREC1 = . if (MMBTREC1 >= 81 )
replace MMBTPYR = . if (MMBTPYR >= 81 )
replace MMBTREC2 = . if (MMBTREC2 >= 81 )
replace MMBT30DY = . if (MMBT30DY >= 81 )
replace MMJNTLOO = . if (MMJNTLOO >= 81 )
replace MMJNTNUM = . if (MMJNTNUM >= 981 )
replace MMJNPCTB = . if (MMJNPCTB >= 81 )
replace MMJNPCAT = . if (MMJNPCAT >= 981 )
replace MMLSUNIT = . if (MMLSUNIT >= 81 )
replace MMLSGMS = . if (MMLSGMS >= 81 )
replace MMLS10GM = . if (MMLS10GM >= 981 )
replace MMLSOZS = . if (MMLSOZS >= 81 )
replace MMLSLBS = . if (MMLSLBS >= 81 )
replace MMLS5LBS = . if (MMLS5LBS >= 981 )
replace MMLSPCTB = . if (MMLSPCTB >= 81 )
replace MMLSPCAT = . if (MMLSPCAT >= 981 )
replace MMBUYWHO = . if (MMBUYWHO >= 81 )
replace MMBPLACE = . if (MMBPLACE >= 81 )
replace MMBATJOB = . if (MMBATJOB >= 81 )
replace MMBCLOSE = . if (MMBCLOSE >= 81 )
replace MMBSELL = . if (MMBSELL >= 81 )
replace MMBGIVE = . if (MMBGIVE >= 81 )
replace MMTRADE = . if (MMTRADE >= 81 )
replace MMTRD30D = . if (MMTRD30D >= 81 )
replace MMTRDREC = . if (MMTRDREC >= 81 )
replace MMT30FRQ = . if (MMT30FRQ >= 81 )
replace MMTJNTLS = . if (MMTJNTLS >= 81 )
replace MMTJNTNM = . if (MMTJNTNM >= 981 )
replace MMTJWRCB = . if (MMTJWRCB >= 81 )
replace MMTJWRTH = . if (MMTJWRTH >= 981 )
replace MMTLUNIT = . if (MMTLUNIT >= 81 )
replace MMTLGMS = . if (MMTLGMS >= 81 )
replace MMTLOZS = . if (MMTLOZS >= 81 )
replace MMTLWRCB = . if (MMTLWRCB >= 81 )
replace MMTLWRTH = . if (MMTLWRTH >= 981 )
replace MMTRDWHO = . if (MMTRDWHO >= 81 )
replace MMTPLACE = . if (MMTPLACE >= 81 )
replace MMTCLOSE = . if (MMTCLOSE >= 81 )
replace MMTKEEP = . if (MMTKEEP >= 81 )
replace MMTSELL = . if (MMTSELL >= 81 )
replace MMTGIVE = . if (MMTGIVE >= 81 )
replace MMGKEEP = . if (MMGKEEP >= 81 )
replace MMGSELL = . if (MMGSELL >= 81 )
replace MMGGIVE = . if (MMGGIVE >= 81 )
replace MMFREWHO = . if (MMFREWHO >= 81 )
replace MMFPLACE = . if (MMFPLACE >= 81 )
replace MMFCLOSE = . if (MMFCLOSE >= 81 )
replace MMFKEEP = . if (MMFKEEP >= 81 )
replace MMFSELL = . if (MMFSELL >= 81 )
replace MMFGIVE = . if (MMFGIVE >= 81 )
replace TXEVER = . if (TXEVER >= 81 )
replace TXYREVER = . if (TXYREVER >= 81 )
replace TXYRADG = . if (TXYRADG >= 81 )
replace TXYRHOSP = . if (TXYRHOSP >= 81 )
replace TXYRHPAD = . if (TXYRHPAD >= 81 )
replace TXYRRFIN = . if (TXYRRFIN >= 81 )
replace TXYRINAD = . if (TXYRINAD >= 81 )
replace TXYRRFOP = . if (TXYRRFOP >= 81 )
replace TXYRPOAD = . if (TXYRPOAD >= 81 )
replace TXYRMHC = . if (TXYRMHC >= 81 )
replace TXYRMHAD = . if (TXYRMHAD >= 81 )
replace TXYRTXER = . if (TXYRTXER >= 81 )
replace TXYRERAD = . if (TXYRERAD >= 81 )
replace TXYRDOC = . if (TXYRDOC >= 81 )
replace TXYRDCAD = . if (TXYRDCAD >= 81 )
replace TXYRJAIL = . if (TXYRJAIL >= 81 )
replace TXYRJLAD = . if (TXYRJLAD >= 81 )
replace TXYRSHG = . if (TXYRSHG >= 81 )
replace TXYRSGAD = . if (TXYRSGAD >= 81 )
replace TXYRSOP = . if (TXYRSOP >= 81 )
replace TXYROTS2 = . if (TXYROTS2 >= 981 )
replace TXYROTAD = . if (TXYROTAD >= 81 )
replace TXYRVSER = . if (TXYRVSER >= 81 )
replace TXYRNME2 = . if (TXYRNME2 >= 981 )
replace TXRCVNOW = . if (TXRCVNOW >= 81 )
replace NDTXNEDR = . if (NDTXNEDR >= 81 )
replace NDTXMORE = . if (NDTXMORE >= 81 )
replace NDTMRALC = . if (NDTMRALC >= 81 )
replace NDTMRMJ = . if (NDTMRMJ >= 81 )
replace NDTMRCOC = . if (NDTMRCOC >= 81 )
replace NDTMRHER = . if (NDTMRHER >= 81 )
replace NDTMRHAL = . if (NDTMRHAL >= 81 )
replace NDTMRINH = . if (NDTMRINH >= 81 )
replace NDTMRANL = . if (NDTMRANL >= 81 )
replace NDTMRTRN = . if (NDTMRTRN >= 81 )
replace NDTMRSTM = . if (NDTMRSTM >= 81 )
replace NDTMRSED = . if (NDTMRSED >= 81 )
replace NDTMROTH = . if (NDTMROTH >= 81 )
replace NDTXALCR = . if (NDTXALCR >= 81 )
replace NDTXMJR = . if (NDTXMJR >= 81 )
replace NDTXCOCR = . if (NDTXCOCR >= 81 )
replace NDTXHERR = . if (NDTXHERR >= 81 )
replace NDTXHALR = . if (NDTXHALR >= 81 )
replace NDTXINHR = . if (NDTXINHR >= 81 )
replace NDTXANLR = . if (NDTXANLR >= 81 )
replace NDTXTRNR = . if (NDTXTRNR >= 81 )
replace NDTXSTMR = . if (NDTXSTMR >= 81 )
replace NDTXSEDR = . if (NDTXSEDR >= 81 )
replace NDTXSODR = . if (NDTXSODR >= 81 )
replace NDTXDG1R = . if (NDTXDG1R >= 9981 )
replace NDTXDG2R = . if (NDTXDG2R >= 9981 )
replace NDTXDG3R = . if (NDTXDG3R >= 9981 )
replace NDTXDG4R = . if (NDTXDG4R >= 9981 )
replace NDTXDG5R = . if (NDTXDG5R >= 9981 )
replace NDTXEFTR = . if (NDTXEFTR >= 81 )
replace NDTMREFT = . if (NDTMREFT >= 81 )
replace TXLASREC = . if (TXLASREC >= 81 )
replace TXLTYMN2 = . if (TXLTYMN2 >= 981 )
replace TXLTYALC = . if (TXLTYALC >= 81 )
replace TXLTYMJ = . if (TXLTYMJ >= 81 )
replace TXLTYCOC = . if (TXLTYCOC >= 81 )
replace TXLTYHER = . if (TXLTYHER >= 81 )
replace TXLTYHAL = . if (TXLTYHAL >= 81 )
replace TXLTYINH = . if (TXLTYINH >= 81 )
replace TXLTYANL = . if (TXLTYANL >= 81 )
replace TXLTYTRN = . if (TXLTYTRN >= 81 )
replace TXLTYSTM = . if (TXLTYSTM >= 81 )
replace TXLTYSED = . if (TXLTYSED >= 81 )
replace TXLTYSOD = . if (TXLTYSOD >= 81 )
replace TXLTYOU2 = . if (TXLTYOU2 >= 81 )
replace TXLTYDU2 = . if (TXLTYDU2 >= 99981 )
replace TXPYINS = . if (TXPYINS >= 81 )
replace TXPYCARE = . if (TXPYCARE >= 81 )
replace TXPYCAID = . if (TXPYCAID >= 81 )
replace TXPYPUBP = . if (TXPYPUBP >= 81 )
replace TXPYSAVE = . if (TXPYSAVE >= 81 )
replace TXPYFMLY = . if (TXPYFMLY >= 81 )
replace TXPYCORT = . if (TXPYCORT >= 81 )
replace TXPYMILC = . if (TXPYMILC >= 81 )
replace TXPYEMPL = . if (TXPYEMPL >= 81 )
replace TXPYSOS = . if (TXPYSOS >= 81 )
replace TXPYSP2 = . if (TXPYSP2 >= 81 )
replace TXPYFRE = . if (TXPYFRE >= 81 )
replace TXENROLL = . if (TXENROLL >= 81 )
replace TXYRDTXO = . if (TXYRDTXO >= 81 )
replace PREGNANT = . if (PREGNANT >= 81 )
replace NMERTMT2 = . if (NMERTMT2 >= 981 )
replace INHOSPYR = . if (INHOSPYR >= 81 )
replace NMNGTHS2 = . if (NMNGTHS2 >= 981 )
replace DOMOSTYR = . if (DOMOSTYR >= 81 )
replace PBLMWORK = . if (PBLMWORK >= 81 )
replace LIMITWRK = . if (LIMITWRK >= 81 )
replace TYPEPBLM = . if (TYPEPBLM >= 81 )
replace PREG2 = . if (PREG2 == -9)
replace PREG2 = . if (PREG2 >= 81 )
replace TRIMEST = . if (TRIMEST == -9)
replace TRIMEST = . if (TRIMEST >= 81 )
replace AUINPYR = . if (AUINPYR >= 81 )
replace AUINPSYH = . if (AUINPSYH >= 81 )
replace AUINPGEN = . if (AUINPGEN >= 81 )
replace AUINMEDU = . if (AUINMEDU >= 81 )
replace AUINAHSP = . if (AUINAHSP >= 81 )
replace AUINRESD = . if (AUINRESD >= 81 )
replace AUINSFAC = . if (AUINSFAC >= 81 )
replace AUNMPSY2 = . if (AUNMPSY2 >= 981 )
replace AUNMPGE2 = . if (AUNMPGE2 >= 981 )
replace AUNMMED2 = . if (AUNMMED2 >= 981 )
replace AUNMAHSP = . if (AUNMAHSP >= 981 )
replace AUNMRES2 = . if (AUNMRES2 >= 981 )
replace AUNMSFA2 = . if (AUNMSFA2 >= 981 )
replace AUPINSLF = . if (AUPINSLF >= 81 )
replace AUPINOFM = . if (AUPINOFM >= 81 )
replace AUPINPHI = . if (AUPINPHI >= 81 )
replace AUPINMCR = . if (AUPINMCR >= 81 )
replace AUPINMCD = . if (AUPINMCD >= 81 )
replace AUPINREH = . if (AUPINREH >= 81 )
replace AUPINEMP = . if (AUPINEMP >= 81 )
replace AUPINMIL = . if (AUPINMIL >= 81 )
replace AUPINPUB = . if (AUPINPUB >= 81 )
replace AUPINPRV = . if (AUPINPRV >= 81 )
replace AUPINFRE = . if (AUPINFRE >= 81 )
replace AUPINAMT = . if (AUPINAMT >= 81 )
replace AUOPTYR = . if (AUOPTYR >= 81 )
replace AUOPMENT = . if (AUOPMENT >= 81 )
replace AUOPTHER = . if (AUOPTHER >= 81 )
replace AUOPDOC = . if (AUOPDOC >= 81 )
replace AUOPCLNC = . if (AUOPCLNC >= 81 )
replace AUOPDTMT = . if (AUOPDTMT >= 81 )
replace AUOPOTOP = . if (AUOPOTOP >= 81 )
replace AUOPYRS2 = . if (AUOPYRS2 >= 81 )
replace AUNMMEN2 = . if (AUNMMEN2 >= 981 )
replace AUNMTHE2 = . if (AUNMTHE2 >= 981 )
replace AUNMDOC2 = . if (AUNMDOC2 >= 981 )
replace AUNMCLN2 = . if (AUNMCLN2 >= 981 )
replace AUNMDTM2 = . if (AUNMDTM2 >= 981 )
replace AUNMOTO2 = . if (AUNMOTO2 >= 981 )
replace AUPOPSLF = . if (AUPOPSLF >= 81 )
replace AUPOPOFM = . if (AUPOPOFM >= 81 )
replace AUPOPPHI = . if (AUPOPPHI >= 81 )
replace AUPOPMCR = . if (AUPOPMCR >= 81 )
replace AUPOPMCD = . if (AUPOPMCD >= 81 )
replace AUPOPREH = . if (AUPOPREH >= 81 )
replace AUPOPEMP = . if (AUPOPEMP >= 81 )
replace AUPOPMIL = . if (AUPOPMIL >= 81 )
replace AUPOPPUB = . if (AUPOPPUB >= 81 )
replace AUPOPPRV = . if (AUPOPPRV >= 81 )
replace AUPOPFRE = . if (AUPOPFRE >= 81 )
replace AUPOPMOS = . if (AUPOPMOS >= 81 )
replace AUPOPAMT = . if (AUPOPAMT >= 81 )
replace AURXYR = . if (AURXYR >= 81 )
replace AUUNMTYR = . if (AUUNMTYR >= 81 )
replace AUUNCOST = . if (AUUNCOST >= 81 )
replace AUUNNBR = . if (AUUNNBR >= 81 )
replace AUUNJOB = . if (AUUNJOB >= 81 )
replace AUUNNCOV = . if (AUUNNCOV >= 81 )
replace AUUNENUF = . if (AUUNENUF >= 81 )
replace AUUNWHER = . if (AUUNWHER >= 81 )
replace AUUNCFID = . if (AUUNCFID >= 81 )
replace AUUNCMIT = . if (AUUNCMIT >= 81 )
replace AUUNSOR = . if (AUUNSOR >= 81 )
replace AMHINP = . if (AMHINP >= 3 )
replace AMHOUTP = . if (AMHOUTP >= 3 )
replace AMHRX = . if (AMHRX >= 3 )
replace AMHTXREC = . if (AMHTXREC >= 3 )
replace AMHTRTND = . if (AMHTRTND >= 3 )
replace RECNEED = . if (RECNEED == -9)
replace RECNEED = . if (RECNEED >= 81 )
replace NORECNED = . if (NORECNED == -9)
replace NORECNED = . if (NORECNED >= 81 )
replace SNAPKCIG = . if (SNAPKCIG >= 81 )
replace SNAMJEVR = . if (SNAMJEVR >= 81 )
replace SNAALDLY = . if (SNAALDLY >= 81 )
replace SNAALDRV = . if (SNAALDRV >= 81 )
replace SNMOV5Y2 = . if (SNMOV5Y2 >= 981 )
replace SNPPHHLD = . if (SNPPHHLD >= 81 )
replace SNINSULT = . if (SNINSULT >= 81 )
replace SNSRARGU = . if (SNSRARGU >= 81 )
replace SNSMARGU = . if (SNSMARGU >= 81 )
replace SNSPOUSE = . if (SNSPOUSE >= 81 )
replace SNSPACTV = . if (SNSPACTV >= 81 )
replace SNSPANGR = . if (SNSPANGR >= 81 )
replace SNSPHITU = . if (SNSPHITU >= 81 )
replace SNYHITSP = . if (SNYHITSP >= 81 )
replace SNSPCRIT = . if (SNSPCRIT >= 81 )
replace SNSPCONC = . if (SNSPCONC >= 81 )
replace SNFRCONC = . if (SNFRCONC >= 81 )
replace SNFRACTV = . if (SNFRACTV >= 81 )
replace SNFRCARE = . if (SNFRCARE >= 81 )
replace SNYSELL = . if (SNYSELL >= 81 )
replace SNYSTOLE = . if (SNYSTOLE >= 81 )
replace SNYATTAK = . if (SNYATTAK >= 81 )
replace SNYDFAST = . if (SNYDFAST >= 81 )
replace SNY50LBS = . if (SNY50LBS >= 81 )
replace SNYINJUR = . if (SNYINJUR >= 81 )
replace SNYSTERD = . if (SNYSTERD >= 81 )
replace SNYRRXNG = . if (SNYRRXNG >= 81 )
replace SNYLAXTV = . if (SNYLAXTV >= 81 )
replace SNYPASNS = . if (SNYPASNS >= 81 )
replace SNYFIRE = . if (SNYFIRE >= 81 )
replace SNFACIG = . if (SNFACIG >= 81 )
replace SNFAMJEV = . if (SNFAMJEV >= 81 )
replace SNFAALDY = . if (SNFAALDY >= 81 )
replace SNFAALDV = . if (SNFAALDV >= 81 )
replace SNFDCIG = . if (SNFDCIG >= 81 )
replace SNFDMJ = . if (SNFDMJ >= 81 )
replace SNFDALC = . if (SNFDALC >= 81 )
replace SNFDDRNK = . if (SNFDDRNK >= 81 )
replace SNRLGSVC = . if (SNRLGSVC >= 81 )
replace SNRLGIMP = . if (SNRLGIMP >= 81 )
replace SNRLDCSN = . if (SNRLDCSN >= 81 )
replace SNRLFRND = . if (SNRLFRND >= 81 )
replace YEMOV5Y2 = . if (YEMOV5Y2 >= 981 )
replace YEATNDYR = . if (YEATNDYR >= 81 )
replace YEHMSLYR = . if (YEHMSLYR >= 81 )
replace YESCHFLT = . if (YESCHFLT >= 81 )
replace YESCHWRK = . if (YESCHWRK >= 81 )
replace YESCHIMP = . if (YESCHIMP >= 81 )
replace YESCHINT = . if (YESCHINT >= 81 )
replace YETCGJOB = . if (YETCGJOB >= 81 )
replace YELSTGRD = . if (YELSTGRD >= 81 )
replace YESTSCIG = . if (YESTSCIG >= 81 )
replace YESTSMJ = . if (YESTSMJ >= 81 )
replace YESTSALC = . if (YESTSALC >= 81 )
replace YESTSDNK = . if (YESTSDNK >= 81 )
replace YEPCHKHW = . if (YEPCHKHW >= 81 )
replace YEPHLPHW = . if (YEPHLPHW >= 81 )
replace YEPCHORE = . if (YEPCHORE >= 81 )
replace YEPLMTTV = . if (YEPLMTTV >= 81 )
replace YEPLMTSN = . if (YEPLMTSN >= 81 )
replace YEPGDJOB = . if (YEPGDJOB >= 81 )
replace YEPPROUD = . if (YEPPROUD >= 81 )
replace YEYARGUP = . if (YEYARGUP >= 81 )
replace YEYFGTSW = . if (YEYFGTSW >= 81 )
replace YEYFGTGP = . if (YEYFGTGP >= 81 )
replace YEYHGUN = . if (YEYHGUN >= 81 )
replace YEYSELL = . if (YEYSELL >= 81 )
replace YEYSTOLE = . if (YEYSTOLE >= 81 )
replace YEYATTAK = . if (YEYATTAK >= 81 )
replace YEYRNAWY = . if (YEYRNAWY >= 81 )
replace YEY50LBS = . if (YEY50LBS >= 81 )
replace YEYINJUR = . if (YEYINJUR >= 81 )
replace YEYSTERD = . if (YEYSTERD >= 81 )
replace YEYRRXNG = . if (YEYRRXNG >= 81 )
replace YEYLAXTV = . if (YEYLAXTV >= 81 )
replace YEYHACK = . if (YEYHACK >= 81 )
replace YEYFIRE = . if (YEYFIRE >= 81 )
replace YEPPKCIG = . if (YEPPKCIG >= 81 )
replace YEPMJEVR = . if (YEPMJEVR >= 81 )
replace YEPMJMO = . if (YEPMJMO >= 81 )
replace YEPALDLY = . if (YEPALDLY >= 81 )
replace YEGPKCIG = . if (YEGPKCIG >= 81 )
replace YEGMJEVR = . if (YEGMJEVR >= 81 )
replace YEGMJMO = . if (YEGMJMO >= 81 )
replace YEGALDLY = . if (YEGALDLY >= 81 )
replace YEFPKCIG = . if (YEFPKCIG >= 81 )
replace YEFMJEVR = . if (YEFMJEVR >= 81 )
replace YEFMJMO = . if (YEFMJMO >= 81 )
replace YEFALDLY = . if (YEFALDLY >= 81 )
replace YETLKNON = . if (YETLKNON >= 81 )
replace YETLKPAR = . if (YETLKPAR >= 81 )
replace YETLKBGF = . if (YETLKBGF >= 81 )
replace YETLKOTA = . if (YETLKOTA >= 81 )
replace YETLKSOP = . if (YETLKSOP >= 81 )
replace YEPRTDNG = . if (YEPRTDNG >= 81 )
replace YEPRBSLV = . if (YEPRBSLV >= 81 )
replace YEVIOPRV = . if (YEVIOPRV >= 81 )
replace YEDGPRGP = . if (YEDGPRGP >= 81 )
replace YESLFHLP = . if (YESLFHLP >= 81 )
replace YEPRGSTD = . if (YEPRGSTD >= 81 )
replace YESCHACT = . if (YESCHACT >= 81 )
replace YECOMACT = . if (YECOMACT >= 81 )
replace YEFAIACT = . if (YEFAIACT >= 81 )
replace YEOTHACT = . if (YEOTHACT >= 81 )
replace YEDECLAS = . if (YEDECLAS >= 81 )
replace YEDERGLR = . if (YEDERGLR >= 81 )
replace YEDESPCL = . if (YEDESPCL >= 81 )
replace YEPVNTYR = . if (YEPVNTYR >= 81 )
replace YERLGSVC = . if (YERLGSVC >= 81 )
replace YERLGIMP = . if (YERLGIMP >= 81 )
replace YERLDCSN = . if (YERLDCSN >= 81 )
replace YERLFRND = . if (YERLFRND >= 81 )
replace YECGFRND = . if (YECGFRND >= 81 )
replace YECGVEND = . if (YECGVEND >= 81 )
replace YECGMAI2 = . if (YECGMAI2 >= 81 )
replace YECGCHKO = . if (YECGCHKO >= 81 )
replace YECGCLRK = . if (YECGCLRK >= 81 )
replace YECGINET = . if (YECGINET >= 81 )
replace YECGSMKT = . if (YECGSMKT >= 81 )
replace YECGDSTO = . if (YECGDSTO >= 81 )
replace YECGCONV = . if (YECGCONV >= 81 )
replace YECGINDV = . if (YECGINDV >= 81 )
replace YECGPRUF = . if (YECGPRUF >= 81 )
replace YECGSUCC = . if (YECGSUCC >= 81 )
replace YEPKCRTN = . if (YEPKCRTN >= 81 )
replace YEPDPACK = . if (YEPDPACK >= 81 )
replace YEPDCRTN = . if (YEPDCRTN >= 81 )
replace YEBLNTEV = . if (YEBLNTEV >= 81 )
replace YEBLNT30 = . if (YEBLNT30 >= 81 )
replace YEBL30FQ = . if (YEBL30FQ >= 81 )
replace YECGRWMJ = . if (YECGRWMJ >= 81 )
replace MVIN5YR2 = . if (MVIN5YR2 == -9)
replace MVIN5YR2 = . if (MVIN5YR2 >= 81 )
replace PRPKCIG2 = . if (PRPKCIG2 == -9)
replace PRPKCIG2 = . if (PRPKCIG2 >= 81 )
replace PRMJEVR2 = . if (PRMJEVR2 == -9)
replace PRMJEVR2 = . if (PRMJEVR2 >= 81 )
replace PRALDLY2 = . if (PRALDLY2 == -9)
replace PRALDLY2 = . if (PRALDLY2 >= 81 )
replace PRTALK3 = . if (PRTALK3 == -9)
replace PRTALK3 = . if (PRTALK3 >= 81 )
replace YOFIGHT2 = . if (YOFIGHT2 == -9)
replace YOFIGHT2 = . if (YOFIGHT2 >= 81 )
replace YOGRPFT2 = . if (YOGRPFT2 == -9)
replace YOGRPFT2 = . if (YOGRPFT2 >= 81 )
replace YOHGUN2 = . if (YOHGUN2 == -9)
replace YOHGUN2 = . if (YOHGUN2 >= 81 )
replace YOSELL2 = . if (YOSELL2 == -9)
replace YOSELL2 = . if (YOSELL2 >= 81 )
replace YOSTOLE2 = . if (YOSTOLE2 == -9)
replace YOSTOLE2 = . if (YOSTOLE2 >= 81 )
replace YOATTAK2 = . if (YOATTAK2 == -9)
replace YOATTAK2 = . if (YOATTAK2 >= 81 )
replace YFLPKCG2 = . if (YFLPKCG2 == -9)
replace YFLPKCG2 = . if (YFLPKCG2 >= 81 )
replace YFLTMRJ2 = . if (YFLTMRJ2 == -9)
replace YFLTMRJ2 = . if (YFLTMRJ2 >= 81 )
replace YFLADLY2 = . if (YFLADLY2 == -9)
replace YFLADLY2 = . if (YFLADLY2 >= 81 )
replace PRBSOLV2 = . if (PRBSOLV2 == -9)
replace PRBSOLV2 = . if (PRBSOLV2 >= 81 )
replace PREVIOL2 = . if (PREVIOL2 == -9)
replace PREVIOL2 = . if (PREVIOL2 >= 81 )
replace PRVDRGO2 = . if (PRVDRGO2 == -9)
replace PRVDRGO2 = . if (PRVDRGO2 >= 81 )
replace GRPCNSL2 = . if (GRPCNSL2 == -9)
replace GRPCNSL2 = . if (GRPCNSL2 >= 81 )
replace PREGPGM2 = . if (PREGPGM2 == -9)
replace PREGPGM2 = . if (PREGPGM2 >= 81 )
replace DGSPCLS2 = . if (DGSPCLS2 == -9)
replace DGSPCLS2 = . if (DGSPCLS2 >= 81 )
replace DGRGCLS2 = . if (DGRGCLS2 == -9)
replace DGRGCLS2 = . if (DGRGCLS2 >= 81 )
replace DRGLECT2 = . if (DRGLECT2 == -9)
replace DRGLECT2 = . if (DRGLECT2 >= 81 )
replace DRPRVME3 = . if (DRPRVME3 == -9)
replace DRPRVME3 = . if (DRPRVME3 >= 81 )
replace ANYEDUC3 = . if (ANYEDUC3 == -9)
replace ANYEDUC3 = . if (ANYEDUC3 >= 81 )
replace CIGFRND = . if (CIGFRND == -9)
replace CIGVEND = . if (CIGVEND == -9)
replace CIGMAIL = . if (CIGMAIL == -9)
replace CIGCKOUT = . if (CIGCKOUT == -9)
replace CIGCLERK = . if (CIGCLERK == -9)
replace CIGINET = . if (CIGINET == -9)
replace CIGSMKT = . if (CIGSMKT == -9)
replace CIGDSTO = . if (CIGDSTO == -9)
replace CIGCONV = . if (CIGCONV == -9)
replace CIGINDIV = . if (CIGINDIV == -9)
replace YTHBGHT = . if (YTHBGHT == -9)
replace RLGATTD = . if (RLGATTD == -9)
replace RLGATTD = . if (RLGATTD >= 81 )
replace RLGIMPT = . if (RLGIMPT == -9)
replace RLGIMPT = . if (RLGIMPT >= 81 )
replace RLGDCSN = . if (RLGDCSN == -9)
replace RLGDCSN = . if (RLGDCSN >= 81 )
replace RLGFRND = . if (RLGFRND == -9)
replace RLGFRND = . if (RLGFRND >= 81 )
replace SCHFELT = . if (SCHFELT == -9)
replace SCHFELT = . if (SCHFELT >= 81 )
replace SCHWORK = . if (SCHWORK == -9)
replace SCHWORK = . if (SCHWORK >= 81 )
replace SCHIMPT = . if (SCHIMPT == -9)
replace SCHIMPT = . if (SCHIMPT >= 81 )
replace SCHINTST = . if (SCHINTST == -9)
replace SCHINTST = . if (SCHINTST >= 81 )
replace TCHGJOB = . if (TCHGJOB == -9)
replace TCHGJOB = . if (TCHGJOB >= 81 )
replace STNDSCIG = . if (STNDSCIG == -9)
replace STNDSCIG = . if (STNDSCIG >= 81 )
replace STNDSMJ = . if (STNDSMJ == -9)
replace STNDSMJ = . if (STNDSMJ >= 81 )
replace STNDALC = . if (STNDALC == -9)
replace STNDALC = . if (STNDALC >= 81 )
replace STNDDNK = . if (STNDDNK == -9)
replace STNDDNK = . if (STNDDNK >= 81 )
replace PARCHKHW = . if (PARCHKHW == -9)
replace PARCHKHW = . if (PARCHKHW >= 81 )
replace PARHLPHW = . if (PARHLPHW == -9)
replace PARHLPHW = . if (PARHLPHW >= 81 )
replace PRCHORE2 = . if (PRCHORE2 == -9)
replace PRCHORE2 = . if (PRCHORE2 >= 81 )
replace PRLMTTV2 = . if (PRLMTTV2 == -9)
replace PRLMTTV2 = . if (PRLMTTV2 >= 81 )
replace PARLMTSN = . if (PARLMTSN == -9)
replace PARLMTSN = . if (PARLMTSN >= 81 )
replace PRGDJOB2 = . if (PRGDJOB2 == -9)
replace PRGDJOB2 = . if (PRGDJOB2 >= 81 )
replace PRPROUD2 = . if (PRPROUD2 == -9)
replace PRPROUD2 = . if (PRPROUD2 >= 81 )
replace ARGUPAR = . if (ARGUPAR == -9)
replace ARGUPAR = . if (ARGUPAR >= 81 )
replace PRMJMO = . if (PRMJMO == -9)
replace PRMJMO = . if (PRMJMO >= 81 )
replace YFLMJMO = . if (YFLMJMO == -9)
replace YFLMJMO = . if (YFLMJMO >= 81 )
replace FRDPCIG2 = . if (FRDPCIG2 == -9)
replace FRDPCIG2 = . if (FRDPCIG2 >= 81 )
replace FRDMEVR2 = . if (FRDMEVR2 == -9)
replace FRDMEVR2 = . if (FRDMEVR2 >= 81 )
replace FRDMJMON = . if (FRDMJMON == -9)
replace FRDMJMON = . if (FRDMJMON >= 81 )
replace FRDADLY2 = . if (FRDADLY2 == -9)
replace FRDADLY2 = . if (FRDADLY2 >= 81 )
replace YTHACT2 = . if (YTHACT2 == -9)
replace YTHACT2 = . if (YTHACT2 >= 81 )
replace PANATAK = . if (PANATAK >= 81 )
replace PANREAC = . if (PANREAC >= 81 )
replace PANATKN2 = . if (PANATKN2 >= 981 )
replace MDEDP2WK = . if (MDEDP2WK >= 81 )
replace MDEDPWKR = . if (MDEDPWKR >= 81 )
replace MDEDAYFQ = . if (MDEDAYFQ >= 81 )
replace MDEDAYLN = . if (MDEDAYLN >= 81 )
replace MDECHNGS = . if (MDECHNGS >= 81 )
replace MDELOSIN = . if (MDELOSIN >= 81 )
replace MDELIWK2 = . if (MDELIWK2 >= 81 )
replace MDELIFQ = . if (MDELIFQ >= 81 )
replace MDELILN = . if (MDELILN >= 81 )
replace MDELICHG = . if (MDELICHG >= 81 )
replace MNCHYPER = . if (MNCHYPER >= 81 )
replace MNCNOSLP = . if (MNCNOSLP >= 81 )
replace MNCSPWRS = . if (MNCSPWRS >= 81 )
replace MNCEVER = . if (MNCEVER >= 81 )
replace MNCMEDS = . if (MNCMEDS >= 81 )
replace PHBSOCL = . if (PHBSOCL >= 81 )
replace PHBLEVEL = . if (PHBLEVEL >= 81 )
replace PHBAVOID = . if (PHBAVOID >= 81 )
replace PHBINTFR = . if (PHBINTFR >= 81 )
replace PHBCRWDS = . if (PHBCRWDS >= 81 )
replace PHBPUBPL = . if (PHBPUBPL >= 81 )
replace PHBTRAVL = . if (PHBTRAVL >= 81 )
replace PHBAWYHM = . if (PHBAWYHM >= 81 )
replace PHBWRSFR = . if (PHBWRSFR >= 81 )
replace PHBWRSST = . if (PHBWRSST >= 81 )
replace PHBWRSAV = . if (PHBWRSAV >= 81 )
replace PHBWRSIN = . if (PHBWRSIN >= 81 )
replace GADWORMR = . if (GADWORMR >= 81 )
replace GADWORLT = . if (GADWORLT >= 81 )
replace GADNRVOS = . if (GADNRVOS >= 81 )
replace GADNRVLT = . if (GADNRVLT >= 81 )
replace GADWKS2 = . if (GADWKS2 >= 81 )
replace GADNMWOR = . if (GADNMWOR >= 81 )
replace GADSTRON = . if (GADSTRON >= 81 )
replace GADOPROB = . if (GADOPROB >= 81 )
replace PTSEVER = . if (PTSEVER >= 81 )
replace PTSPYEAR = . if (PTSPYEAR >= 81 )
replace PTSWRSFQ = . if (PTSWRSFQ >= 81 )
replace PTSWKS2 = . if (PTSWKS2 >= 81 )
replace DELVOICE = . if (DELVOICE >= 81 )
replace DELFORCE = . if (DELFORCE >= 81 )
replace DELXRAY = . if (DELXRAY >= 81 )
replace DELTHOTS = . if (DELTHOTS >= 81 )
replace DELSIGNL = . if (DELSIGNL >= 81 )
replace DELPLOT = . if (DELPLOT >= 81 )
replace DELVISON = . if (DELVISON >= 81 )
replace MHSEEDR = . if (MHSEEDR >= 81 )
replace MHHOSPOV = . if (MHHOSPOV >= 81 )
replace MHOPNUM2 = . if (MHOPNUM2 >= 981 )
replace MHMEDS = . if (MHMEDS >= 81 )
replace MHMEDWK2 = . if (MHMEDWK2 >= 81 )
replace DSTNRVOS = . if (DSTNRVOS >= 81 )
replace DSTNCALM = . if (DSTNCALM >= 81 )
replace DSTTIRE = . if (DSTTIRE >= 81 )
replace DSTHOPLS = . if (DSTHOPLS >= 81 )
replace DSTRSTLS = . if (DSTRSTLS >= 81 )
replace DSTSITST = . if (DSTSITST >= 81 )
replace DSTDEPRS = . if (DSTDEPRS >= 81 )
replace DSTCHEER = . if (DSTCHEER >= 81 )
replace DSTEFFRT = . if (DSTEFFRT >= 81 )
replace DSTNGOOD = . if (DSTNGOOD >= 81 )
replace IMPTHINK = . if (IMPTHINK >= 81 )
replace IMPUNDST = . if (IMPUNDST >= 81 )
replace IMPREMBR = . if (IMPREMBR >= 81 )
replace IMPCONC = . if (IMPCONC >= 81 )
replace IMPMONY = . if (IMPMONY >= 81 )
replace IMPMONYM = . if (IMPMONYM >= 81 )
replace IMPLERN = . if (IMPLERN >= 81 )
replace IMPLERNM = . if (IMPLERNM >= 81 )
replace IMPWASH = . if (IMPWASH >= 81 )
replace IMPWASHM = . if (IMPWASHM >= 81 )
replace IMPGO = . if (IMPGO >= 81 )
replace IMPGOM = . if (IMPGOM >= 81 )
replace IMPDLPP = . if (IMPDLPP >= 81 )
replace IMPDLPPM = . if (IMPDLPPM >= 81 )
replace IMPSOCL = . if (IMPSOCL >= 81 )
replace IMPSOCLM = . if (IMPSOCLM >= 81 )
replace IMPGTALG = . if (IMPGTALG >= 81 )
replace IMPCTRLE = . if (IMPCTRLE >= 81 )
replace IMPRELAX = . if (IMPRELAX >= 81 )
replace IMPHRSP = . if (IMPHRSP >= 81 )
replace IMPHRSPM = . if (IMPHRSPM >= 81 )
replace IMPDLRSP = . if (IMPDLRSP >= 81 )
replace IMPDLWRK = . if (IMPDLWRK >= 81 )
replace IMPWKS2 = . if (IMPWKS2 >= 81 )
replace IMPDAYFQ = . if (IMPDAYFQ >= 81 )
replace MHSVCHLP = . if (MHSVCHLP >= 81 )
replace SMI_SUM = . if (SMI_SUM == -9)
replace SMI_SUM = . if (SMI_SUM >= 81 )
replace SMI = . if (SMI == -9)
replace SMI = . if (SMI >= 81 )
replace YUHOSPYR = . if (YUHOSPYR >= 81 )
replace YUHOSPN2 = . if (YUHOSPN2 >= 981 )
replace YUHOSUIC = . if (YUHOSUIC >= 81 )
replace YUHODEPR = . if (YUHODEPR >= 81 )
replace YUHOFEAR = . if (YUHOFEAR >= 81 )
replace YUHOBKRU = . if (YUHOBKRU >= 81 )
replace YUHOEATP = . if (YUHOEATP >= 81 )
replace YUHOSOR = . if (YUHOSOR >= 81 )
replace YURSIDYR = . if (YURSIDYR >= 81 )
replace YURSIDN2 = . if (YURSIDN2 >= 981 )
replace YURSSUIC = . if (YURSSUIC >= 81 )
replace YURSDEPR = . if (YURSDEPR >= 81 )
replace YURSFEAR = . if (YURSFEAR >= 81 )
replace YURSBKRU = . if (YURSBKRU >= 81 )
replace YURSEATP = . if (YURSEATP >= 81 )
replace YURSSOR = . if (YURSSOR >= 81 )
replace YUFCARYR = . if (YUFCARYR >= 81 )
replace YUFCARN2 = . if (YUFCARN2 >= 981 )
replace YUFCSUIC = . if (YUFCSUIC >= 81 )
replace YUFCDEPR = . if (YUFCDEPR >= 81 )
replace YUFCFEAR = . if (YUFCFEAR >= 81 )
replace YUFCBKRU = . if (YUFCBKRU >= 81 )
replace YUFCEATP = . if (YUFCEATP >= 81 )
replace YUFCSOR = . if (YUFCSOR >= 81 )
replace YUDYTXYR = . if (YUDYTXYR >= 81 )
replace YUDYTXN2 = . if (YUDYTXN2 >= 981 )
replace YUDYSUIC = . if (YUDYSUIC >= 81 )
replace YUDYDEPR = . if (YUDYDEPR >= 81 )
replace YUDYFEAR = . if (YUDYFEAR >= 81 )
replace YUDYBKRU = . if (YUDYBKRU >= 81 )
replace YUDYEATP = . if (YUDYEATP >= 81 )
replace YUDYSOR = . if (YUDYSOR >= 81 )
replace YUMHCRYR = . if (YUMHCRYR >= 81 )
replace YUMHCRN2 = . if (YUMHCRN2 >= 981 )
replace YUMHSUIC = . if (YUMHSUIC >= 81 )
replace YUMHDEPR = . if (YUMHDEPR >= 81 )
replace YUMHFEAR = . if (YUMHFEAR >= 81 )
replace YUMHBKRU = . if (YUMHBKRU >= 81 )
replace YUMHEATP = . if (YUMHEATP >= 81 )
replace YUMHSOR = . if (YUMHSOR >= 81 )
replace YUTPSTYR = . if (YUTPSTYR >= 81 )
replace YUTPSTN2 = . if (YUTPSTN2 >= 981 )
replace YUTPSUIC = . if (YUTPSUIC >= 81 )
replace YUTPDEPR = . if (YUTPDEPR >= 81 )
replace YUTPFEAR = . if (YUTPFEAR >= 81 )
replace YUTPBKRU = . if (YUTPBKRU >= 81 )
replace YUTPEATP = . if (YUTPEATP >= 81 )
replace YUTPSOR = . if (YUTPSOR >= 81 )
replace YUIHTPYR = . if (YUIHTPYR >= 81 )
replace YUIHTPN2 = . if (YUIHTPN2 >= 981 )
replace YUIHSUIC = . if (YUIHSUIC >= 81 )
replace YUIHDEPR = . if (YUIHDEPR >= 81 )
replace YUIHFEAR = . if (YUIHFEAR >= 81 )
replace YUIHBKRU = . if (YUIHBKRU >= 81 )
replace YUIHEATP = . if (YUIHEATP >= 81 )
replace YUIHSOR = . if (YUIHSOR >= 81 )
replace YUFDOCYR = . if (YUFDOCYR >= 81 )
replace YUFDOCN2 = . if (YUFDOCN2 >= 981 )
replace YUFDSUIC = . if (YUFDSUIC >= 81 )
replace YUFDDEPR = . if (YUFDDEPR >= 81 )
replace YUFDFEAR = . if (YUFDFEAR >= 81 )
replace YUFDBKRU = . if (YUFDBKRU >= 81 )
replace YUFDEATP = . if (YUFDEATP >= 81 )
replace YUFDSOR = . if (YUFDSOR >= 81 )
replace YUSPEDYR = . if (YUSPEDYR >= 81 )
replace YUSHCNYR = . if (YUSHCNYR >= 81 )
replace YUSHSUIC = . if (YUSHSUIC >= 81 )
replace YUSHDEPR = . if (YUSHDEPR >= 81 )
replace YUSHFEAR = . if (YUSHFEAR >= 81 )
replace YUSHBKRU = . if (YUSHBKRU >= 81 )
replace YUSHEATP = . if (YUSHEATP >= 81 )
replace YUSHSOR = . if (YUSHSOR >= 81 )
replace YUJAILEV = . if (YUJAILEV >= 81 )
replace YUFCAREV = . if (YUFCAREV >= 81 )
replace YHOSP = . if (YHOSP == -9)
replace YHOSP = . if (YHOSP >= 81 )
replace YRESID = . if (YRESID == -9)
replace YRESID = . if (YRESID >= 81 )
replace YFOST = . if (YFOST == -9)
replace YFOST = . if (YFOST >= 81 )
replace YDAYTRT = . if (YDAYTRT == -9)
replace YDAYTRT = . if (YDAYTRT >= 81 )
replace YCLIN = . if (YCLIN == -9)
replace YCLIN = . if (YCLIN >= 81 )
replace YTHER = . if (YTHER == -9)
replace YTHER = . if (YTHER >= 81 )
replace YHOME = . if (YHOME == -9)
replace YHOME = . if (YHOME >= 81 )
replace YPED = . if (YPED == -9)
replace YPED = . if (YPED >= 81 )
replace YSPED = . if (YSPED == -9)
replace YSPED = . if (YSPED >= 81 )
replace YSCHL = . if (YSCHL == -9)
replace YSCHL = . if (YSCHL >= 81 )
replace ANYTRT10 = . if (ANYTRT10 == -9)
replace ANYTRT10 = . if (ANYTRT10 >= 81 )
replace ANYTRT9 = . if (ANYTRT9 == -9)
replace ANYTRT9 = . if (ANYTRT9 >= 81 )
replace REASSUIC = . if (REASSUIC == -9)
replace REASSUIC = . if (REASSUIC >= 81 )
replace REASDEPR = . if (REASDEPR == -9)
replace REASDEPR = . if (REASDEPR >= 81 )
replace REASFEAR = . if (REASFEAR == -9)
replace REASFEAR = . if (REASFEAR >= 81 )
replace REASBRAK = . if (REASBRAK == -9)
replace REASBRAK = . if (REASBRAK >= 81 )
replace REASEATP = . if (REASEATP == -9)
replace REASEATP = . if (REASEATP >= 81 )
replace REASFAM = . if (REASFAM == -9)
replace REASFAM = . if (REASFAM >= 81 )
replace REASSOC = . if (REASSOC == -9)
replace REASSOC = . if (REASSOC >= 81 )
replace REASSCH = . if (REASSCH == -9)
replace REASSCH = . if (REASSCH >= 81 )
replace REASOTH = . if (REASOTH == -9)
replace REASOTH = . if (REASOTH >= 81 )
replace NRCH17_2 = . if (NRCH17_2 == -9)
replace NRCH17_2 = . if (NRCH17_2 >= 81 )
replace PROXANS2 = . if (PROXANS2 >= 81 )
replace IRWELMOS = . if (IRWELMOS >= 81 )
replace IIWELMOS = . if (IIWELMOS == 9)
replace MEDICARE = . if (MEDICARE >= 81 )
replace CAIDCHIP = . if (CAIDCHIP >= 81 )
replace CHAMPUS = . if (CHAMPUS >= 81 )
replace PRVHLTIN = . if (PRVHLTIN >= 81 )
replace GRPHLTIN = . if (GRPHLTIN >= 81 )
replace HLTINALC = . if (HLTINALC >= 81 )
replace HLTINDRG = . if (HLTINDRG >= 81 )
replace HLTINMNT = . if (HLTINMNT >= 81 )
replace HLTINNOS = . if (HLTINNOS >= 81 )
replace HLCNOTYR = . if (HLCNOTYR >= 81 )
replace HLCNOTMO = . if (HLCNOTMO >= 81 )
replace HLCLAST = . if (HLCLAST >= 81 )
replace HLLOSRSN = . if (HLLOSRSN >= 81 )
replace HLNVCOST = . if (HLNVCOST >= 81 )
replace HLNVOFFR = . if (HLNVOFFR >= 81 )
replace HLNVREF = . if (HLNVREF >= 81 )
replace HLNVNEED = . if (HLNVNEED >= 81 )
replace HLNVSOR = . if (HLNVSOR >= 81 )
replace HLCALLFG = . if (HLCALLFG >= 81 )
replace HLCALL99 = . if (HLCALL99 >= 81 )
replace ANYHLTI2 = . if (ANYHLTI2 >= 81 )
replace LANGVER = . if (LANGVER >= 81 )
replace GQTYPE = . if (GQTYPE == -9)
replace AGE2 = . if (AGE2 >= 81 )
replace NOMARR2 = . if (NOMARR2 >= 81 )
replace SERVICE = . if (SERVICE >= 81 )
replace MILSTAT = . if (MILSTAT >= 81 )
replace HEALTH = . if (HEALTH >= 81 )
replace IRMARIT = . if (IRMARIT >= 81 )
replace IREDUC2 = . if (IREDUC2 >= 81 )
replace MOVESPY2 = . if (MOVESPY2 >= 981 )
replace SCHENRL = . if (SCHENRL >= 81 )
replace EDUCATN2 = . if (EDUCATN2 >= 12 )
replace STUDNT = . if (STUDNT >= 81 )
replace SCHDSICK = . if (SCHDSICK >= 81 )
replace SCHDSKIP = . if (SCHDSKIP >= 81 )
replace HSDIPLMA = . if (HSDIPLMA >= 81 )
replace HSGED = . if (HSGED >= 81 )
replace LFSCHWH2 = . if (LFSCHWH2 >= 981 )
replace LFTSCHA2 = . if (LFTSCHA2 >= 981 )
replace JBSTATR2 = . if (JBSTATR2 >= 10 )
replace WRKHAVJB = . if (WRKHAVJB >= 81 )
replace WRKHRSWK = . if (WRKHRSWK >= 981 )
replace WRKINDU2 = . if (WRKINDU2 >= 981 )
replace WRKOCCU2 = . if (WRKOCCU2 >= 981 )
replace WRKBZCA2 = . if (WRKBZCA2 >= 81 )
replace WRKEDYR = . if (WRKEDYR >= 81 )
replace WRKSLFEM = . if (WRKSLFEM >= 81 )
replace WRKJOBS2 = . if (WRKJOBS2 >= 81 )
replace WRKUNEMP = . if (WRKUNEMP >= 81 )
replace WRKUNWKS = . if (WRKUNWKS >= 81 )
replace WRKLSTY2 = . if (WRKLSTY2 >= 9981 )
replace WRKINDY2 = . if (WRKINDY2 >= 981 )
replace WRKOCCY2 = . if (WRKOCCY2 >= 981 )
replace WRKBZCY2 = . if (WRKBZCY2 >= 81 )
replace WORKDAYS = . if (WORKDAYS >= 81 )
replace WORKBLAH = . if (WORKBLAH >= 81 )
replace LOCSIZE = . if (LOCSIZE >= 81 )
replace DRGPLCY = . if (DRGPLCY >= 81 )
replace PLCYCOV = . if (PLCYCOV >= 81 )
replace WKDRGED = . if (WKDRGED >= 81 )
replace DRGPRGM = . if (DRGPRGM >= 81 )
replace USALCTST = . if (USALCTST >= 81 )
replace USDRGTST = . if (USDRGTST >= 81 )
replace TSTHIRE = . if (TSTHIRE >= 81 )
replace TSTRAND = . if (TSTRAND >= 81 )
replace FIRSTPOS = . if (FIRSTPOS >= 81 )
replace WRKHIRE = . if (WRKHIRE >= 81 )
replace WORKRAND = . if (WORKRAND >= 81 )
replace TELNO2 = . if (TELNO2 >= 81 )
replace COLLEGE2 = . if (COLLEGE2 == -9)
replace COLLEGE2 = . if (COLLEGE2 >= 81 )
replace VESTR = . if (VESTR >= 99981 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

